@@ -92,7 +92,7 @@ OC.L10N.register(
     "Circle Invite" : "Покана за Circle/кръг/",
     "Federated" : "Федериран",
     "Mount point" : "Точка на монтиране",
-    "Nextcloud User" : "Потребител на Nextcloud",
+    "Nextcloud Account" : "Nextcloud профил",
     "Nextcloud Group" : "Nextcloud Група",
     "Email Address" : "Имейл адрес",
     "Contact" : "Контакт",
@@ -131,7 +131,7 @@ OC.L10N.register(
     "A circle with that name exists" : "Съществува кръг с това име",
     "You cannot use the Circles Application until your administrator has allowed at least one type of circles" : "Не можете да използвате Приложението Кръгове, докато вашият администратор не е разрешил поне един тип от кръгове",
     "This member does not exist" : "Този член не съществува",
-    "This user is already a member of the circle" : "Този потребител вече е член на кръга",
+    "This account is already a member of the circle" : "Този профил вече е член на кръга",
     "Federated link not found" : "Федерираната връзка не е намерена",
     "This feature is not available for personal circles" : "Тази функция не е налична за лични кръгове",
     "The circle is not federated" : "Кръгът не е федериран",
@@ -142,8 +142,8 @@ OC.L10N.register(
     "Level cannot be changed for this type of member" : "Нивото не може да се променя за член от този тип ",
     "You are already a member of this circle" : "Вече сте член на този кръг",
     "You have been blocked from this circle" : "Бяхте блокиран от този кръг",
-    "The user is already a member of this circle" : "Потребителят вече е член на този кръг",
-    "The user has already been invited into this circle" : "Потребителят вече е поканен в този кръг",
+    "The account is already a member of this circle" : "Този профил вече е член на този кръг",
+    "The account has already been invited into this circle" : "Този профил вече е бил поканен в този кръг",
     "%s (Circle owned by %s)" : "%s (Кръг, притежаван от %s)",
     "You are now a member of the Circle \"%2$s\"" : " \nВече сте член на Кръга \"%2$s\"",
     "You have been invited by %1$s into the Circle \"%2$s\"" : "Вие сте поканени от %1$s в Кръга \"%2$s\"",
@@ -163,7 +163,7 @@ OC.L10N.register(
     "You cannot edit level in a personal circle" : "Не можете да редактирате ниво в личен кръг",
     "Group cannot be set as owner of a circle" : "Група не може да бъде зададена като собственик на кръг",
     "now" : "сега",
-    "This user does not exist" : "Този потребител не съществува",
+    "This account does not exist" : "Този профил не съществува",
     "Email format is not valid" : "Невалиден Имейл формат",
     "This contact is not available" : "Този контакт е недостъпен",
     "You have no permission to create a new circle" : "Нямате право да създавате нов кръг /circle/",
@@ -176,11 +176,17 @@ OC.L10N.register(
     "This item is already shared with this circle" : "Елементът вече е споделен с този кръг",
     "Could not find share" : "Споделянето не можа да се намери",
     "Bring cloud-users closer together." : "Доближете потребителите на облака по-близо.",
-    "Circles allows your users to create their own groups of users/colleagues/friends.\nThose groups of users (or \"circles\") can then be used by any other app for sharing purpose." : "Circles позволява на вашите потребители да създават свои собствени групи потребители/колеги/приятели.\nТези групи потребители (или „кръгове“) след това могат да бъдат използвани от всяко друго приложение за споделяне.",
+    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "Приложението Circles /Кръгове/, позволява на хората да създават свои собствени групи от хора/колеги/приятели.\nТези групи от хора (или \"кръгове\") след това могат да се използват от всяко друго приложение за споделяне.",
     "No files in here" : "Няма файлове",
     "No entries found in this folder" : "Папката е празна",
     "Name" : "Име",
     "Size" : "Размер",
-    "Modified" : "Променен на"
+    "Modified" : "Променен на",
+    "Nextcloud User" : "Потребител на Nextcloud",
+    "This user is already a member of the circle" : "Този потребител вече е член на кръга",
+    "The user is already a member of this circle" : "Потребителят вече е член на този кръг",
+    "The user has already been invited into this circle" : "Потребителят вече е поканен в този кръг",
+    "This user does not exist" : "Този потребител не съществува",
+    "Circles allows your users to create their own groups of users/colleagues/friends.\nThose groups of users (or \"circles\") can then be used by any other app for sharing purpose." : "Circles позволява на вашите потребители да създават свои собствени групи потребители/колеги/приятели.\nТези групи потребители (или „кръгове“) след това могат да бъдат използвани от всяко друго приложение за споделяне."
 },
 "nplurals=2; plural=(n != 1);");
