@@ -1,17 +1,11 @@
 OC.L10N.register(
     "federatedfilesharing",
     {
-    "Federated sharing" : "Partage fédéré",
     "Do you want to add the remote share {name} from {owner}@{remote}?" : "Voulez-vous ajouter le partage distant {name} depuis {owner}@{remote} ?",
     "Remote share" : "Partage distant",
     "Remote share password" : "Mot de passe du partage distant",
     "Cancel" : "Annuler",
     "Add remote share" : "Ajouter un partage distant",
-    "Copy" : "Copier",
-    "Copied!" : "Copié !",
-    "Not supported!" : "Non supporté!",
-    "Press ⌘-C to copy." : "Appuyez sur ⌘-C pour copier.",
-    "Press Ctrl-C to copy." : "Appuyez sur Ctrl-C pour copier.",
     "Invalid Federated Cloud ID" : "ID de Cloud Fédéré incorrect",
     "Server to server sharing is not enabled on this server" : "Le partage de serveur à serveur n'est pas activé sur ce serveur",
     "Couldn't establish a federated share." : "Impossible d'établir un partage fédéré.",
@@ -19,47 +13,49 @@ OC.L10N.register(
     "Federated Share request sent, you will receive an invitation. Check your notifications." : "Demande de partage fédéré envoyée, vous allez recevoir une invitation. Vérifiez vos notifications.",
     "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Impossible d'établir un partage fédére, il semble que le serveur avec lequel fédérer est trop vieux (Nextcloud <=9)",
     "It is not allowed to send federated group shares from this server." : "Il n'est pas autorisé d'envoyer des partages à des groupes fédérés depuis ce serveur.",
-    "Sharing %1$s failed, because this item is already shared with %2$s" : "Le partage de %1$s a échoué car cet élément est déjà partagé avec %2$s",
+    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Le partage de %1$s a échoué, parce que cet élément est déjà partagé avec l'utilisateur %2$s",
     "Not allowed to create a federated share with the same user" : "Non autorisé à créer un partage fédéré avec le même utilisateur",
+    "Federated shares require read permissions" : "Les partages fédérés nécessitent des permissions de lecture.",
     "File is already shared with %s" : "Le fichier est déjà partagé avec %s",
     "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Le partage de %1$s a échoué, impossible de trouver %2$s, le serveur est peut-être momentanément injoignable ou utilise un certificat auto-signé.",
     "Could not find share" : "Impossible de trouver le partage",
-    "You received \"%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Vous avez reçu \"%3$s\" en tant que partage distant de %1$s (de la part de %2$s)",
+    "Federated sharing" : "Partage fédéré",
+    "You received \"%3$s\" as a remote share from %4$s (%1$s) (on behalf of %5$s (%2$s))" : "Vous avez reçu \"%3$s\" en tant que partage distant de%4$s(%1$s) (par le biais de%5$s (%2$s))",
     "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Vous avez reçu {share} comme partage distant de la part de {user} (de la part de {behalf})",
-    "You received \"%3$s\" as a remote share from %1$s" : "Vous avez reçu \"%3$s\" comme partage distant de %1$s",
+    "You received \"%3$s\" as a remote share from %4$s (%1$s)" : "Vous avez reçu \"%3$s\" en tant que partage distant de %4$s (%1$s)",
     "You received {share} as a remote share from {user}" : "Vous avez reçu {share} comme partage distant de la part de {user}",
     "Accept" : "Accepter",
     "Decline" : "Refuser",
+    "Federated Cloud Sharing" : "Partage Cloud Fédéré",
     "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Partagez avec moi grâce à mon identifiant de Cloud Fédéré #Nextcloud %s",
     "Share with me through my #Nextcloud Federated Cloud ID" : "Partagez avec moi grâce à mon identifiant de Cloud Fédéré #Nextcloud",
     "Sharing" : "Partage",
     "Federated file sharing" : "Partage de fichiers fédéré",
     "Provide federated file sharing across servers" : "Fourni un partage de fichiers fédéré entre plusieurs serveurs",
-    "Federated Cloud Sharing" : "Partage Cloud Fédéré",
-    "Open documentation" : "Voir la documentation",
-    "Adjust how people can share between servers." : "Réglez comment les personnes peuvent partager entre les serveurs.",
-    "Allow users on this server to send shares to other servers" : "Autoriser les utilisateurs de ce serveur à envoyer des partages vers d'autres serveurs",
+    "Adjust how people can share between servers. This includes shares between users on this server as well if they are using federated sharing." : "Configurer comment les utilisateurs peuvent faire des partages entre serveurs. Cela inclut aussi les partages entre utilisateurs de ce serveur s'ils utilisent des partages fédérés.",
+    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Autoriser les utilisateurs de ce serveur à envoyer des partages vers d'autres serveurs (cette option permet aussi l'accès WebDAV aux partages publics)",
     "Allow users on this server to receive shares from other servers" : "Autoriser les utilisateurs de ce serveur à recevoir des partages d'autres serveurs",
     "Allow users on this server to send shares to groups on other servers" : "Autoriser les utilisateurs de ce serveur à envoyer des partages à des groupes sur d'autres serveurs",
     "Allow users on this server to receive group shares from other servers" : "Autoriser les utilisateurs de ce serveur à recevoir des partages de groupe depuis d'autres serveurs",
     "Search global and public address book for users" : "Rechercher dans le carnet d'adresse global et public pour les utilisateurs",
     "Allow users to publish their data to a global and public address book" : "Autoriser les utilisateurs à publier leurs données dans un carnet d'adresse global et public",
     "Federated Cloud" : "Cloud Fédéré",
-    "You can share with anyone who uses Nextcloud, ownCloud or Pydio! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Vous pouvez partager avec n'importe qui utilisant Nextcloud, ownCloud ou Pydio ! Renseignez simplement leur ID de Cloud Fédéré dans la boîte de dialogue de partage. Il ressemble à person@cloud.example.com",
+    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Vous pouvez partager avec quiconque utilise un serveur Nextcloud ou un serveur ou service compatible Open Cloud Mesh (OCM). Renseignez simplement son identifiant sur une instance fédérée dans la boîte de dialogue de partage. Cela prend la forme de utilisateur@cloud.exemple.com.",
     "Your Federated Cloud ID:" : "Votre identifiant de Cloud Fédéré :",
     "Share it so your friends can share files with you:" : "Partagez-le afin que vos amis puissent partager des fichiers avec vous :",
+    "Facebook" : "Facebook",
+    "Twitter" : "Twitter",
+    "Diaspora" : "Diaspora",
     "Add to your website" : "Ajouter à votre site web",
     "Share with me via Nextcloud" : "Partagez avec moi via Nextcloud",
     "HTML Code:" : "Code HTML :",
-    "The mountpoint name contains invalid characters." : "Le nom du point de montage contient des caractères invalides.",
-    "Not allowed to create a federated share with the owner." : "Vous n'êtes pas autorisé à créer un partage fédéré avec le propriétaire.",
-    "Invalid or untrusted SSL certificate" : "Certificat SSL invalide ou non approuvé",
-    "Could not authenticate to remote share, password might be wrong" : "Impossible de se connecter au partage distant, le mot de passe peut-être incorrect",
-    "Storage not valid" : "Support de stockage non valide",
-    "Federated share added" : "Partage fédéré ajouté",
-    "Couldn't add remote share" : "Impossible d'ajouter le partage distant",
-    "Sharing %s failed, because this item is already shared with %s" : "Le partage de %s a échoué car cet élément est déjà partagé avec %s",
-    "Sharing %s failed, could not find %s, maybe the server is currently unreachable or uses a self-signed certificate." : "Le partage de %s a échoué, impossible de trouver %s, le serveur est peut-être momentanément injoignable ou utilise un certificat auto-signé.",
-    "Search global and public address book for users and let local users publish their data" : "Rechercher dans le carnet d'adresse global et public pour les utilisateurs et laisser les utilisateurs publier leurs données"
+    "Copy to clipboard" : "Copier dans le presse-papiers",
+    "Copy" : "Copier",
+    "Copied!" : "Copié !",
+    "Not supported!" : "Non supporté!",
+    "Press ⌘-C to copy." : "Appuyez sur ⌘-C pour copier.",
+    "Press Ctrl-C to copy." : "Appuyez sur Ctrl-C pour copier.",
+    "Open documentation" : "Voir la documentation",
+    "Adjust how people can share between servers." : "Réglez comment les personnes peuvent partager entre les serveurs."
 },
-"nplurals=2; plural=(n > 1);");
+"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
