@@ -8,6 +8,9 @@ OC.L10N.register(
     "Move or copy" : "Přesunout nebo zkopírovat",
     "Download" : "Stáhnout",
     "Delete" : "Smazat",
+    "Tags" : "Štítky",
+    "Show list view" : "Zobrazit v seznamu",
+    "Show grid view" : "Zobrazit v mřížce",
     "Home" : "Domů",
     "Close" : "Zavřít",
     "Favorites" : "Oblíbené",
@@ -30,8 +33,10 @@ OC.L10N.register(
     "Error when assembling chunks, status code {status}" : "Chyba při kompletaci shluků, kód chyby {status}",
     "Actions" : "Akce",
     "Rename" : "Přejmenovat",
+    "Move" : "Přesunout",
     "Copy" : "Kopírovat",
     "Choose target folder" : "Zvolte cílovou složku",
+    "Edit locally" : "Upravit lokálně",
     "Open" : "Otevřít",
     "Delete file" : "Smazat soubor",
     "Delete folder" : "Smazat složku",
@@ -40,8 +45,6 @@ OC.L10N.register(
     "Could not load info for file \"{file}\"" : "Nepodařilo se načíst informace pro soubor „{file}“",
     "Files" : "Soubory",
     "Details" : "Podrobnosti",
-    "Show list view" : "Zobrazit v seznamu",
-    "Show grid view" : "Zobrazit v mřížce",
     "Please select tag(s) to add to the selection" : "Vyberte štítky které přidat do výběru",
     "Apply tag(s) to selection" : "Uplatnit štítky na výběr",
     "Select directory \"{dirName}\"" : "Vybrat složku „{dirName}“",
@@ -66,7 +69,7 @@ OC.L10N.register(
     "Could not create folder \"{dir}\" because it already exists" : "Složku „{dir}“ nelze vytvořit, protože už existuje",
     "Could not fetch file details \"{file}\"" : "Nedaří se získat podrobnosti o souboru „{file}“",
     "Error deleting file \"{fileName}\"." : "Chyba při mazání souboru „{fileName}“.",
-    "No search results in other folders for {tag}{filter}{endtag}" : "Žádné výsledky hledání v ostatních složkách pro {tag}{filter}{endtag}",
+    "No search results in other folders for {tag}{filter}{endtag}" : "Žádné výsledky hledání v ostatních složkách pro {tag}{filter}{endtag}",
     "Enter more than two characters to search in other folders" : "Pokud chcete hledat v ostatních složkách, zadejte více než dva znaky",
     "Name" : "Název",
     "Size" : "Velikost",
@@ -79,6 +82,7 @@ OC.L10N.register(
     "_Uploading %n file_::_Uploading %n files_" : ["Nahrává se %n soubor","Nahrávají se %n soubory","Nahrává se %n souborů","Nahrávají se %n soubory"],
     "New file/folder menu" : "Nabídka souboru/složky",
     "Select file range" : "Vybrat rozsah souborů",
+    "{used}%" : "{used}%",
     "{used} of {quota} used" : "Využito {used} z {quota} ",
     "{used} used" : "{used} využito",
     "\"{name}\" is an invalid file name." : "„{name}“ není platným názvem souboru.",
@@ -175,7 +179,6 @@ OC.L10N.register(
     "Invalid path selected" : "Vybrán neplatný popis umístění",
     "Ownership transfer request sent" : "Žádost o převedení vlastnictví zaslána",
     "Cannot transfer ownership of a file or folder you do not own" : "Není možné převést vlastnictví souboru či složky, kterých nejste vlastníky",
-    "Tags" : "Značky",
     "Unable to change the favourite state of the file" : "Nedaří se změnit stav „oblíbené“ souboru",
     "Error while loading the file data" : "Chyba při načítání dat souboru",
     "Pick a template for {name}" : "Vyberte si šablonu pro {name}",
@@ -189,7 +192,7 @@ OC.L10N.register(
     "Templates" : "Šablony",
     "Unable to initialize the templates directory" : "Nepodařilo se vytvořit složku pro šablony",
     "%s used" : "%s použito",
-    "%s%% of %s used" : "%s%% z %s použito",
+    "%s%%" : "%s%%",
     "%1$s of %2$s used" : "%1$s z %2$s použito",
     "Files settings" : "Nastavení pro Soubory",
     "Show hidden files" : "Zobrazit skryté soubory",
@@ -219,6 +222,7 @@ OC.L10N.register(
     "You don’t have permission to upload or create files here" : "Nemáte oprávnění sem nahrávat nebo zde vytvářet soubory",
     "New" : "Nový",
     "Cannot transfer ownership of a file or folder you don't own" : "Není možné převést vlastnictví souboru či složky, které nejste vlastníky",
+    "%s%% of %s used" : "%s%% z %s použito",
     "Settings" : "Nastavení"
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
