@@ -4,15 +4,14 @@ OC.L10N.register(
     "Storage is temporarily not available" : "Opslag is tijdelijk niet beschikbaar",
     "Storage invalid" : "Opslag ongeldig",
     "Unknown error" : "Onbekende fout",
-    "All files" : "Alle bestanden",
-    "Recent" : "Recent",
-    "Favorites" : "Favorieten",
     "File could not be found" : "Bestand kon niet worden gevonden",
     "Move or copy" : "Verplaats of kopieer",
     "Download" : "Downloaden",
     "Delete" : "Verwijderen",
+    "Tags" : "Tags",
     "Home" : "Thuis",
     "Close" : "Sluiten",
+    "Favorites" : "Favorieten",
     "Could not create folder \"{dir}\"" : "Kon map \"{dir}\" niet aanmaken",
     "This will stop your current uploads." : "Dit beëindigt onderhanden uploads",
     "Upload cancelled." : "Uploaden geannuleerd.",
@@ -27,27 +26,30 @@ OC.L10N.register(
     "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} van {totalSize} ({bitrate})",
     "Uploading that item is not supported" : "Uploaden van dat object is niet ondersteund",
     "Target folder does not exist any more" : "Doelmap bestaat niet meer",
+    "Operation is blocked by access control" : "De operatie werd tegengehouden door toegangscontrole",
     "Error when assembling chunks, status code {status}" : "Fout tijdens samenvoegen van brokken, status code {status}",
     "Actions" : "Acties",
     "Rename" : "Naam wijzigen",
+    "Move" : "Verplaatsen",
     "Copy" : "Kopiëren",
     "Choose target folder" : "Kies doelmap…",
     "Open" : "Openen",
     "Delete file" : "Verwijderen bestand",
     "Delete folder" : "Verwijderen map",
     "Disconnect storage" : "Verbinding met opslag verbreken",
-    "Unshare" : "Stop met delen",
+    "Leave this share" : "Verlaat deze gedeelde locatie",
     "Could not load info for file \"{file}\"" : "Kon geen informatie laden voor bestand \"{file}\"",
     "Files" : "Bestanden",
     "Details" : "Details",
-    "Select" : "Selecteer",
+    "Please select tag(s) to add to the selection" : "Selecteer alsjeblieft tag(s) om aan de selectie toe te voegen",
+    "Apply tag(s) to selection" : "Pas tag(s) toe voor selectie",
     "Pending" : "In behandeling",
     "Unable to determine date" : "Kon datum niet vaststellen",
     "This operation is forbidden" : "Deze taak is verboden",
     "This directory is unavailable, please check the logs or contact the administrator" : "Deze map is niet beschikbaar. Verifieer de logs of neem contact op met de beheerder",
     "Could not move \"{file}\", target exists" : "Kon \"{file}\" niet verplaatsen, doel bestaat al",
     "Could not move \"{file}\"" : "Kon \"{file}\" niet verplaatsen",
-    "copy" : "kopiëren",
+    "copy" : "kopie",
     "Could not copy \"{file}\", target exists" : "Kon \"{bestand}\" niet kopiëren, het doel bestaat",
     "Could not copy \"{file}\"" : "Kon \"{file}\" niet kopiëren",
     "Copied {origin} inside {destination}" : "Kopieerde {oorsprong} binnen {bestemming}",
@@ -59,8 +61,10 @@ OC.L10N.register(
     "Could not create file \"{file}\"" : "Kon \"{file}\" niet aanmaken",
     "Could not create file \"{file}\" because it already exists" : "Kon \"{file}\" niet aanmaken, omdat het al bestaat",
     "Could not create folder \"{dir}\" because it already exists" : "Kon map \"{dir}\" niet aanmaken, omdat die al bestaat",
+    "Could not fetch file details \"{file}\"" : "Kon details van \"{file}\" niet ophalen",
     "Error deleting file \"{fileName}\"." : "Fout bij verwijderen bestand \"{fileName}\".",
     "No search results in other folders for {tag}{filter}{endtag}" : "Geen zoekresultaten voor {tag}{filter}{endtag} in andere mappen",
+    "Enter more than two characters to search in other folders" : "Voer meer dan twee tekens in om in andere mappen te zoeken",
     "Name" : "Naam",
     "Size" : "Grootte",
     "Modified" : "Aangepast",
@@ -68,9 +72,7 @@ OC.L10N.register(
     "_%n file_::_%n files_" : ["%n bestand","%n bestanden"],
     "{dirs} and {files}" : "{dirs} en {files}",
     "_including %n hidden_::_including %n hidden_" : ["inclusief %n verborgen","inclusief %n verborgen"],
-    "You don’t have permission to upload or create files here" : "Je hebt geen toestemming om hier te uploaden of bestanden te maken",
     "_Uploading %n file_::_Uploading %n files_" : ["%n bestand aan het uploaden","%n bestanden aan het uploaden"],
-    "New" : "Nieuw",
     "Select file range" : "Kies een reeks bestanden",
     "{used} of {quota} used" : "{used} van {quota} gebruikt",
     "{used} used" : "{used} gebruikt",
@@ -78,11 +80,15 @@ OC.L10N.register(
     "File name cannot be empty." : "Bestandsnaam kan niet leeg zijn.",
     "\"/\" is not allowed inside a file name." : "\"/\" is niet toegestaan binnen een bestandsnaam.",
     "\"{name}\" is not an allowed filetype" : "\"{name}\" bestandstype is een niet toegestaande",
-    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Opslagruimte van {owner} zit vol, bestanden kunnen niet meer worden geüpload of gesynchroniseerd!",
-    "Your storage is full, files can not be updated or synced anymore!" : "Je opslagruimte zit vol. Bestanden kunnen niet meer worden gewijzigd of gesynchroniseerd!",
-    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Opslagruimte van {owner} zit bijna vol ({usedSpacePercent}%)",
-    "Your storage is almost full ({usedSpacePercent}%)" : "Je opslagruimte zit bijna vol ({usedSpacePercent}%)",
-    "_matches '{filter}'_::_match '{filter}'_" : ["komt overeen met '{filter}'","komen overeen met '{filter}'"],
+    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Opslagruimte van {owner} zit vol, bestanden kunnen niet meer worden geüpload of gesynchroniseerd!",
+    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Groepsmap \"{mountPoint}\" is vol, bestanden kunnen niet meer gewijzigd of gesynchroniseerd worden!",
+    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Externe opslag \"{mountPoint}\" is vol, bestanden kunnen niet meer gewijzigd of gesynchroniseerd worden!",
+    "Your storage is full, files cannot be updated or synced anymore!" : "Je opslagruimte zit vol. Bestanden kunnen niet meer worden gewijzigd of gesynchroniseerd!",
+    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Opslagruimte van {owner} zit bijna vol ({usedSpacePercent}%)",
+    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Groepsmap \"{mountPoint}\" is bijna vol ({usedSpacePercent}%).",
+    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Externe opslag \"{mountPoint}\" is bijna vol ({usedSpacePercent}%).",
+    "Your storage is almost full ({usedSpacePercent}%)." : "Je opslagruimte zit bijna vol ({usedSpacePercent}%)",
+    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["komt overeen met \"{filter}\"","komen overeen met \"{filter}\""],
     "View in folder" : "Bekijken in map",
     "Copied!" : "Gekopieerd!",
     "Copy direct link (only works for users who have access to this file/folder)" : "Kopieer de link direct (werkt alleen voor gebruikers met toegang tot map/bestand)",
@@ -93,12 +99,13 @@ OC.L10N.register(
     "You can only favorite a single file or folder at a time" : "Je kunt maar één bestand of map tegelijk favoriet maken",
     "New folder" : "Nieuwe map",
     "Upload file" : "Bestand uploaden",
+    "Recent" : "Recent",
     "Not favorited" : "Niet in favorieten",
     "Remove from favorites" : "Verwijderen uit favorieten",
     "Add to favorites" : "Aan favorieten toevoegen",
     "An error occurred while trying to update the tags" : "Er trad een fout op bij je poging om de tags bij te werken",
-    "Added to favorites" : "Toevoegen aan favorieten",
-    "Removed from favorites" : "Verwijderen uit favorieten",
+    "Added to favorites" : "Aan favorieten toegevoegd",
+    "Removed from favorites" : "Uit favorieten verwijderd",
     "You added {file} to your favorites" : "Je voegde {file} toe aan favorieten",
     "You removed {file} from your favorites" : "Je verwijderde {file} uit je favorieten",
     "File changes" : "Bestandswijzigingen",
@@ -124,54 +131,86 @@ OC.L10N.register(
     "{user} deleted an encrypted file in {file}" : "{user} heeft een versleuteld bestand gewist in {file}",
     "You restored {file}" : "Je herstelde {file}",
     "{user} restored {file}" : "{user} herstelde {file}",
+    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Je hernoemde {oldfile} (verborgen) naar {newfile}",
+    "You renamed {oldfile} (hidden) to {newfile}" : "Je hernoemde {oldfile} (verborgen) naar {newfile}",
+    "You renamed {oldfile} to {newfile} (hidden)" : "Je hernoemde {oldfile} naar {newfile} (verborgen)",
     "You renamed {oldfile} to {newfile}" : "Je hernoemde {oldfile} naar {newfile}",
+    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} hernoemde {oldfile} (verborgen) naar {newfile} (verborgen)",
+    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} hernoemde {oldfile} (verborgen) naar {newfile}",
+    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} hernoemde {oldfile} naar {newfile} (verborgen)",
     "{user} renamed {oldfile} to {newfile}" : "{user} hernoemde {oldfile} naar {newfile}",
     "You moved {oldfile} to {newfile}" : "Je verplaatste {oldfile} naar {newfile}",
     "{user} moved {oldfile} to {newfile}" : "{user} verplaatste {oldfile} naar {newfile}",
     "A file has been added to or removed from your <strong>favorites</strong>" : "Een bestand werd toegevoegd of verwijderd van je <strong>favorieten</strong>",
-    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Een bestand of map is <strong>gewijzigd</strong> of <strong>hernoemd</strong>",
-    "A new file or folder has been <strong>created</strong>" : "Een nieuw bestand of map is <strong>aangemaakt</strong>",
-    "A file or folder has been <strong>deleted</strong>" : "Een bestand of map is <strong>verwijderd</strong>",
-    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Beperk meldingen over aanmaken en wijzigen aan je <strong>favoriete bestanden</strong> <em>(Alleen stream)</em>",
-    "A file or folder has been <strong>restored</strong>" : "Een bestand of een map is <strong>hersteld</strong>",
+    "A file or folder has been <strong>changed</strong>" : "Een bestand of map is <strong>gewijzigd</strong>",
+    "A favorite file or folder has been <strong>changed</strong>" : "Een favoriet bestand of map is <strong>gewijzigd</strong>",
+    "All files" : "Alle bestanden",
     "Unlimited" : "Ongelimiteerd",
     "Upload (max. %s)" : "Upload (max. %s)",
+    "Accept" : "Accepteren",
+    "Reject" : "Afwijzen",
+    "Incoming ownership transfer from {user}" : "Inkomend verzoek voor eigendomsoverdracht van {user}",
+    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Wil je {path} aanvaarden? \n\nOpmerking: het overdrachtsproces kan na acceptatie tot 1 uur duren.",
+    "Ownership transfer failed" : "Eigendomsoverdracht mislukt",
+    "Your ownership transfer of {path} to {user} failed." : "Eigendomsoverdracht van {path} naar {user} is mislukt.",
+    "The ownership transfer of {path} from {user} failed." : "Eigendomsoverdracht van {path} van {user} is mislukt.",
+    "Ownership transfer done" : "Eigendomsoverdracht geslaagd",
+    "Your ownership transfer of {path} to {user} has completed." : "Eigendomsoverdracht van {path} naar {user} is gereed.",
+    "The ownership transfer of {path} from {user} has completed." : "Eigendomsoverdracht van {path} van {user} is gereed.",
+    "in %s" : "in %s",
     "File Management" : "Bestandsbeheer",
+    "Transfer ownership of a file or folder" : "Overdragen eigendom bestand of map ",
+    "Choose file or folder to transfer" : "Kies over te dragen bestand of map",
+    "Change" : "Pas aan",
+    "New owner" : "Nieuwe eigenaar",
+    "Search users" : "Gebruikers zoeken",
+    "Choose a file or folder to transfer" : "Kies een bestand of map om over te dragen",
+    "Transfer" : "Overdragen",
+    "Transfer {path} to {userid}" : "Draag {path} over aan {userid}",
+    "Invalid path selected" : "Ongeldig pad geselecteerd",
+    "Ownership transfer request sent" : "Aanvraag eigendomsoverdracht verstuurd",
+    "Unable to change the favourite state of the file" : "Niet mogelijk om favoriet status van het bestand te wijzigen",
     "Error while loading the file data" : "Fout bij het lezen van de bestandsgegevens",
-    "Unable to change the favourite state of the file" : "Niet mogelijk om voorkeurtoestand van het bestand te wijzigen",
+    "Pick a template for {name}" : "Kies een sjabloon voor {name}",
+    "Cancel" : "Annuleren",
+    "Create" : "Aanmaken",
+    "Create a new file with the selected template" : "Maak een nieuw bestand met het geselecteerde sjabloon",
+    "Creating file" : "Maken bestand",
+    "Blank" : "Blanco",
+    "Unable to create new file from template" : "Kan geen nieuw bestand maken vanuit het sjabloon",
+    "Set up templates folder" : "Instellen sjablonenmap",
+    "Templates" : "Sjablonen",
+    "Unable to initialize the templates directory" : "Kon de sjablonenmap niet instellen",
     "%s used" : "%s gebruikt",
-    "%s%% of %s used" : "%s%% van %s gebruikt",
     "%1$s of %2$s used" : "%1$s van %2$s gebruikt",
-    "Settings" : "Instellingen",
-    "Show hidden files" : "Verborgen bestanden tonen",
+    "Show hidden files" : "Toon verborgen bestanden",
+    "Crop image previews" : "Snij afbeeldingvoorbeelden bij",
     "WebDAV" : "WebDAV",
-    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Gebruik deze link <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">om je bestanden te benaderen via WebDAV</a>",
+    "Use this address to access your Files via WebDAV" : "Gebruik dit adres om je bestanden via WebDAV te benaderen",
+    "Toggle %1$s sublist" : "Omschakelen%1$s sublijsten",
     "Toggle grid view" : "Omschakelen roosterweergave",
     "No files in here" : "Hier geen bestanden",
     "Upload some content or sync with your devices!" : "Upload je inhoud of synchroniseer met je apparaten!",
-    "No entries found in this folder" : "Niets",
+    "No entries found in this folder" : "Niets gevonden in deze map",
     "Select all" : "Alles selecteren",
     "Upload too large" : "Upload is te groot",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "De bestanden die je probeert te uploaden zijn groter dan de maximaal toegestane  bestandsgrootte voor deze server.",
     "No favorites yet" : "Nog geen favorieten",
     "Files and folders you mark as favorite will show up here" : "Bestanden en mappen die je als favoriet aanmerkt, worden hier getoond",
-    "Tags" : "Tags",
     "Deleted files" : "Verwijderde bestanden",
     "Shares" : "Shares",
     "Shared with others" : "Gedeeld met anderen",
     "Shared with you" : "Gedeeld met jou",
     "Shared by link" : "Gedeeld via link",
     "Deleted shares" : "Verwijderde shares",
+    "Pending shares" : "Deellinks in behandeling",
     "Text file" : "Tekstbestand",
     "New text file.txt" : "Nieuw tekstbestand.txt",
-    "File handling" : "Bestand afhandeling",
-    "Maximum upload size" : "Maximale bestandsgrootte voor uploads",
-    "max. possible: " : "max. mogelijk: ",
-    "Save" : "Bewaren",
-    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Met PHP-FPM kan het 5 minuten duren voordat wijzigingen zijn doorgevoerd.",
-    "Missing permissions to edit from here." : "Ontbrekende rechten om vanaf hier te bewerken.",
-    "Cancel upload" : "Stop upload",
-    "%s of %s used" : "%s van %s gebruikt",
-    "%1$s%% of %2$s used" : "%1$s%% van %2$s gebruikt"
+    "Select" : "Selecteer",
+    "You don’t have permission to upload or create files here" : "Je hebt geen toestemming om hier te uploaden of bestanden te maken",
+    "New" : "Nieuw",
+    "Cannot transfer ownership of a file or folder you don't own" : "Kan de eigendom van een bestand of map waarvan u niet de eigenaar bent, niet overdragen",
+    "%s%% of %s used" : "%s%% van %s gebruikt",
+    "Settings" : "Instellingen"
 },
 "nplurals=2; plural=(n != 1);");
