@@ -4,46 +4,57 @@ OC.L10N.register(
     "Storage is temporarily not available" : "Хранилище временно недоступно",
     "Storage invalid" : "Хранилище неисправно",
     "Unknown error" : "Неизвестная ошибка",
-    "All files" : "Все файлы",
-    "Recent" : "Недавно изменённые",
-    "Favorites" : "Избранные",
     "File could not be found" : "Невозможно найти файл",
     "Move or copy" : "Переместить или копировать",
     "Download" : "Скачать",
     "Delete" : "Удалить",
+    "Tags" : "Метки",
+    "Show list view" : "Просмотр списком",
+    "Show grid view" : "Просмотр сеткой",
     "Home" : "Главная",
     "Close" : "Закрыть",
+    "Favorites" : "Избранные",
     "Could not create folder \"{dir}\"" : "Невозможно создать каталог «{dir}»",
     "This will stop your current uploads." : "Это действие остановит активные сеансы передачи файлов на сервер. ",
-    "Upload cancelled." : "Выгрузка отменена.",
-    "…" : "…",
+    "Upload cancelled." : "Отправка отменена.",
     "Processing files …" : "Обработка файлов…",
-    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Невозможно загрузить «{filename}», так как это либо каталог, либо файл нулевого размера",
-    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Недостаточно свободного места, вы загружаете {size1}, но только {size2} доступно",
+    "…" : "…",
+    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Невозможно передать «{filename}», так как это либо каталог, либо файл нулевого размера",
+    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Недостаточно свободного места, вы передаёте на сервер {size1}, но доступно только {size2}",
     "Target folder \"{dir}\" does not exist any more" : "Целевой каталог «{dir}» более не существует",
     "Not enough free space" : "Недостаточно свободного места",
     "An unknown error has occurred" : "Произошла неизвестная ошибка",
-    "Uploading …" : "Загрузка…",
+    "File could not be uploaded" : "Файл не может быть загружен",
+    "Uploading …" : "Передача…",
     "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} из {totalSize} ({bitrate})",
     "Uploading that item is not supported" : "Загрузка этого элемента не поддерживается",
     "Target folder does not exist any more" : "Каталог больше не существует",
+    "Operation is blocked by access control" : "Операция не разрешена модулем контроля доступа",
     "Error when assembling chunks, status code {status}" : "Ошибка при сборке чанков, код ошибки {status}",
     "Actions" : "Действия",
     "Rename" : "Переименовать",
+    "Move" : "Переместить",
     "Copy" : "Копировать",
-    "Choose target folder" : "Выберите каталога назначения",
+    "Choose target folder" : "Выбор папки назначения",
+    "Open" : "Открыть",
+    "Delete file" : "Удалить файл",
+    "Delete folder" : "Удалить каталог",
     "Disconnect storage" : "Отсоединить хранилище",
-    "Unshare" : "Закрыть доступ",
+    "Leave this share" : "Отказаться от совместного доступа к этому ресурсу",
     "Could not load info for file \"{file}\"" : "Не удаётся загрузить информацию для файла \"{file}\"",
     "Files" : "Файлы",
     "Details" : "Подробно",
-    "Select" : "Выбрать",
+    "Please select tag(s) to add to the selection" : "Выберите метки для назначения выбранным объектам",
+    "Apply tag(s) to selection" : "Назначить метки выбранным объектам",
+    "Select directory \"{dirName}\"" : "Выберите каталог \"{dirName}\"",
+    "Select file \"{fileName}\"" : "Выберите файл \"{fileName}\"",
     "Pending" : "Ожидается",
     "Unable to determine date" : "Невозможно определить дату",
     "This operation is forbidden" : "Операция запрещена",
     "This directory is unavailable, please check the logs or contact the administrator" : "Каталог недоступен. Проверьте журналы событий или свяжитесь с администратором",
     "Could not move \"{file}\", target exists" : "Невозможно переместить файл «{file}», он уже существует в каталоге назначения",
     "Could not move \"{file}\"" : "Невозможно переместить файл «{file}»",
+    "copy" : "копия",
     "Could not copy \"{file}\", target exists" : "Невозможно скопировать файл «{file}», он уже существует в каталоге назначения",
     "Could not copy \"{file}\"" : "Невозможно скопировать файл «{file}»",
     "Copied {origin} inside {destination}" : "{origin} скопирован в {destination}",
@@ -55,8 +66,10 @@ OC.L10N.register(
     "Could not create file \"{file}\"" : "Невозможно создать файл «{file}»",
     "Could not create file \"{file}\" because it already exists" : "Невозможно создать файл «{file}», он уже существует",
     "Could not create folder \"{dir}\" because it already exists" : "Невозможно создать каталог «{dir}», он уже существует",
+    "Could not fetch file details \"{file}\"" : "Не удалось получить сведения о файле «{file}»",
     "Error deleting file \"{fileName}\"." : "Ошибка удаления файла «{fileName}».",
     "No search results in other folders for {tag}{filter}{endtag}" : "Нет результатов поиска в других папках для {tag}{filter}{endtag}",
+    "Enter more than two characters to search in other folders" : "Введите более двух символов для поиска в других каталогах",
     "Name" : "Имя",
     "Size" : "Размер",
     "Modified" : "Изменён",
@@ -64,20 +77,24 @@ OC.L10N.register(
     "_%n file_::_%n files_" : ["%n файл","%n файла","%n файлов","%n файлов"],
     "{dirs} and {files}" : "{dirs} и {files}",
     "_including %n hidden_::_including %n hidden_" : ["включая %n скрытый","включая %n скрытых","включая %n скрытых","включая %n скрытых"],
-    "You don’t have permission to upload or create files here" : "У вас нет разрешений на создание или загрузку файлов в эту папку.",
-    "_Uploading %n file_::_Uploading %n files_" : ["Выгружа%nется  файл","Выгружаются %n файла","Выгружаются %n файлов","Загружаются %n файлов"],
-    "New" : "Новый",
+    "You do not have permission to upload or create files here" : "У вас нет разрешения на загрузку или создание файлов здесь",
+    "_Uploading %n file_::_Uploading %n files_" : ["Передача %n файла","Передача %n файлов","Передача %n файлов","Передача %n файлов"],
+    "Select file range" : "Выбор диапазона файлов",
     "{used} of {quota} used" : "использовано {used} из {quota}",
-    "{used} used" : "использовано {used}",
+    "{used} used" : "Использовано {used}",
     "\"{name}\" is an invalid file name." : "«{name}» — недопустимое имя файла.",
     "File name cannot be empty." : "Имя файла не может быть пустым.",
     "\"/\" is not allowed inside a file name." : "Символ «/» недопустим в имени файла.",
     "\"{name}\" is not an allowed filetype" : "«{name}» - недопустимый тип файла.",
-    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Хранилище {owner} переполнено, файлы больше не могут быть обновлены или синхронизированы!",
-    "Your storage is full, files can not be updated or synced anymore!" : "Ваше хранилище переполнено, файлы больше не могут быть обновлены или синхронизированы!",
-    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Хранилище {owner} практически заполнено ({usedSpacePercent}%)",
-    "Your storage is almost full ({usedSpacePercent}%)" : "Ваше хранилище почти заполнено ({usedSpacePercent}%)",
-    "_matches '{filter}'_::_match '{filter}'_" : ["соответствует '{filter}'","соответствуют '{filter}'","соответствуют '{filter}'","соответствуют '{filter}'"],
+    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Хранилище {owner} переполнено, файлы не могут быть обновлены или синхронизированы.",
+    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Папки группы «{mountPoint}» заполнена, файлы не могут быть обновлены или синхронизированы.",
+    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Внешнее хранилище «{mountPoint}» заполнено, файлы не могут быть обновлены или синхронизированы.",
+    "Your storage is full, files cannot be updated or synced anymore!" : "Ваше хранилище заполнено, файлы не могут быть обновлены или синхронизированы.",
+    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Хранилище пользователя {owner} почти заполнено (использовано {usedSpacePercent} %).",
+    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Папка группы «{mountPoint}» почти заполнена (использовано ({usedSpacePercent} %).",
+    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Внешнее хранилище «{mountPoint}» почти заполнено (использовано {usedSpacePercent} %).",
+    "Your storage is almost full ({usedSpacePercent}%)." : "Ваше хранилище почти заполнено (использовано {usedSpacePercent} %).",
+    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["соответствуют «{filter}»","соответствуют «{filter}»","соответствуют «{filter}»","соответствует «{filter}»"],
     "View in folder" : "Посмотреть в каталоге",
     "Copied!" : "Скопировано!",
     "Copy direct link (only works for users who have access to this file/folder)" : "Копировать прямую ссылку (работает только для пользователей с правами доступа к этому файлу или каталогу)",
@@ -85,8 +102,10 @@ OC.L10N.register(
     "_%n byte_::_%n bytes_" : ["%n байт","%n байта","%n байт","%n байт"],
     "Favorited" : "Избранное",
     "Favorite" : "Добавить в избранное",
+    "You can only favorite a single file or folder at a time" : "Одновременно можно выбрать только один файл или папку",
     "New folder" : "Новый каталог",
     "Upload file" : "Загрузить файл",
+    "Recent" : "Недавно изменённые",
     "Not favorited" : "Не избранное",
     "Remove from favorites" : "Удалить из избранных",
     "Add to favorites" : "Добавить в избранное",
@@ -118,55 +137,87 @@ OC.L10N.register(
     "{user} deleted an encrypted file in {file}" : " {user} удалил(а) зашифрованный файл в «{file}»",
     "You restored {file}" : "Вы восстановили «{file}»",
     "{user} restored {file}" : "{user} восстановил(а) «{file}»",
+    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Вы переименовали {oldfile} (скрытый) в {newfile} (скрытый)",
+    "You renamed {oldfile} (hidden) to {newfile}" : "Вы переименовали {oldfile} (скрытый) в {newfile}",
+    "You renamed {oldfile} to {newfile} (hidden)" : "Вы переименовали {oldfile} в {newfile} (скрытый)",
     "You renamed {oldfile} to {newfile}" : "Вы переименовали «{oldfile}» в «{newfile}»",
+    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} переименовал(а) {oldfile} (скрытый) в {newfile} (скрытый)",
+    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} переименовал(а) {oldfile} (скрытый) в {newfile}",
+    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} переименовал(а) {oldfile} в {newfile} (скрытый)",
     "{user} renamed {oldfile} to {newfile}" : "{user} переименовал(а) «{oldfile}» в «{newfile}»",
     "You moved {oldfile} to {newfile}" : "Вы переместили «{oldfile}» в «{newfile}»",
     "{user} moved {oldfile} to {newfile}" : "{user} переместил(а) «{oldfile}» в «{newfile}»",
-    "A file has been added to or removed from your <strong>favorites</strong>" : "Файл был добавлен или удален из вашего <strong>избранного</strong>",
-    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Файл или каталог был <strong>изменён</strong> или <strong>переименован</strong>",
-    "A new file or folder has been <strong>created</strong>" : "Был <strong>создан</strong> новый файл или каталог",
-    "A file or folder has been <strong>deleted</strong>" : "Файл или каталог был <strong>удалён</strong>",
-    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Ограничить уведомления о создании и изменении ваших <strong>избранных файлов</strong> <em>(отображать только в приложении события)</em>",
-    "A file or folder has been <strong>restored</strong>" : "Файл или каталог был <strong>восстановлен</strong>",
+    "A file has been added to or removed from your <strong>favorites</strong>" : "Файл добавлен в <strong>избранное</strong> или удалён оттуда",
+    "A file or folder has been <strong>changed</strong>" : "<strong>Изменён</strong> файл или каталог",
+    "A favorite file or folder has been <strong>changed</strong>" : "<strong>Изменён</strong> файл или папка отмеченные как избранное",
+    "All files" : "Все файлы",
     "Unlimited" : "Неограничено",
     "Upload (max. %s)" : "Загрузка (максимум %s)",
+    "Accept" : "Принять",
+    "Reject" : "Отклонить",
+    "Incoming ownership transfer from {user}" : "Запрос передачи владения от пользователя {user}",
+    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Принять владение {path}?\n\nПримечание: процесс переноса может занять до одного часа.",
+    "Ownership transfer failed" : "Не удалось передать владение",
+    "Your ownership transfer of {path} to {user} failed." : "Вам не удалось передать владение «{path}» пользователю {user}.",
+    "The ownership transfer of {path} from {user} failed." : "Пользователю {user} не удалось передать владение «{path}».",
+    "Ownership transfer done" : "Передача владения завершена",
+    "Your ownership transfer of {path} to {user} has completed." : "Завершена передача владения «{path}» от вас пользователю {user}.",
+    "The ownership transfer of {path} from {user} has completed." : "Завершена передача владения «{path}» от пользователя {user}.",
+    "in %s" : "в %s",
     "File Management" : "Управление файлами",
-    "File handling" : "Управление файлами",
-    "Maximum upload size" : "Максимальный размер загружаемого файла",
-    "max. possible: " : "макс. возможно: ",
-    "Save" : "Сохранить",
-    "With PHP-FPM it might take 5 minutes for changes to be applied." : "В режиме PHP-FPM применение изменений может занять до 5 минут.",
-    "Missing permissions to edit from here." : "Отсутствуют права на внесение здесь изменений.",
-    "%1$s of %2$s used" : "использовано %1$s из %2$s ",
+    "Transfer ownership of a file or folder" : "Изменение владельца файла или папки",
+    "Choose file or folder to transfer" : "Выберите файл или папку для передачи владения",
+    "Change" : "Изменить",
+    "New owner" : "Новый владелец",
+    "Search users" : "Поиск пользователей",
+    "Choose a file or folder to transfer" : "Выберите файл или папку для передачи",
+    "Transfer" : "Передать",
+    "Transfer {path} to {userid}" : "Передать {path} пользователю {userid}",
+    "Invalid path selected" : "Указан некорректный путь",
+    "Ownership transfer request sent" : "Запрос на передачу прав владения отправлен",
+    "Cannot transfer ownership of a file or folder you do not own" : "Невозможно передать право владения на файл или каталог, которые вам не принадлежат",
+    "Unable to change the favourite state of the file" : "Не удалось изменить состояние «избранный» этого файла.",
+    "Error while loading the file data" : "Не удалось загрузить данные файла",
+    "Pick a template for {name}" : "Выбрать шаблон для {name}",
+    "Cancel" : "Отменить",
+    "Create" : "Создать",
+    "Create a new file with the selected template" : "Создать файл на основе шаблона",
+    "Creating file" : "Создание файла",
+    "Blank" : "Пустой",
+    "Unable to create new file from template" : "Не удалось создать файл на основе шаблона",
+    "Set up templates folder" : "Указать папку шаблонов",
+    "Templates" : "Шаблоны",
+    "Unable to initialize the templates directory" : "Не удалось инициализировать каталог шаблонов",
     "%s used" : "%s использовано",
-    "Settings" : "Настройки",
+    "%1$s of %2$s used" : "использовано %1$s из %2$s ",
     "Show hidden files" : "Показывать скрытые файлы",
+    "Crop image previews" : "Обрезать пред. просмотр",
     "WebDAV" : "WebDAV",
-    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Используйте этот адрес для <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">доступа к вашим файлам через WebDAV</a>",
+    "Use this address to access your Files via WebDAV" : "Используйте этот адрес для подключения WebDAV",
+    "Toggle %1$s sublist" : "Переключить %1$s подсписок",
     "Toggle grid view" : "Включить или отключить режим просмотра сеткой",
-    "Cancel upload" : "Отменить загрузку",
     "No files in here" : "Здесь нет файлов",
     "Upload some content or sync with your devices!" : "Загрузите что-нибудь или синхронизируйте со своими устройствами!",
     "No entries found in this folder" : "В этом каталоге ничего не найдено",
-    "Select all" : "Выбрать все",
+    "Select all" : "Выбрать всё",
     "Upload too large" : "Файл слишком велик",
-    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Файлы, которые вы пытаетесь загрузить, превышают лимит максимального размера на этом сервере.",
+    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Файлы, которые вы пытаетесь передать, превышают лимит максимального размера на этом сервере.",
     "No favorites yet" : "В избранное ещё ничего не добавлено ",
     "Files and folders you mark as favorite will show up here" : "Здесь будут показаны файлы и каталоги, отмеченные как избранные",
-    "Tags" : "Метки",
     "Deleted files" : "Корзина",
     "Shares" : "Общие ресурсы",
     "Shared with others" : "Доступные для других",
     "Shared with you" : "Доступные для вас",
     "Shared by link" : "Доступные по ссылке",
-    "Deleted shares" : "Удаленные общие ресурсы",
+    "Deleted shares" : "Удалённые общие ресурсы",
+    "Pending shares" : "Ожидающие общие ресурсы",
     "Text file" : "Текстовый файл",
     "New text file.txt" : "Новый текстовый файл.txt",
-    "Move" : "Переместить",
-    "Target folder" : "Целевой каталог",
-    "A new file or folder has been <strong>deleted</strong>" : "Новый файл или каталог был <strong>удален</strong>",
-    "A new file or folder has been <strong>restored</strong>" : "Новый файл или каталог был <strong>восстановлен</strong>",
-    "%s of %s used" : "использовано %s из %s",
-    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Используйте этот адрес <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">для доступа по WebDAV</a>"
+    "Select" : "Выбрать",
+    "You don’t have permission to upload or create files here" : "У вас нет прав на создание или загрузку файлов в эту папку.",
+    "New" : "Новый",
+    "Cannot transfer ownership of a file or folder you don't own" : "Изменение владельца возможно только для своих файлов и папок",
+    "%s%% of %s used" : "использовано %s%% из %s",
+    "Settings" : "Настройки"
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
