@@ -8,19 +8,23 @@ OC.L10N.register(
     "Move or copy" : "Taşı ya da kopyala",
     "Download" : "İndir",
     "Delete" : "Sil",
+    "Tags" : "Etiketler",
+    "Show list view" : "Liste görünümüne geç",
+    "Show grid view" : "Tablo görünümüne geç",
     "Home" : "Giriş",
     "Close" : "Kapat",
-    "Favorites" : "Sık Kullanılanlar",
+    "Favorites" : "Sık kullanılanlar",
     "Could not create folder \"{dir}\"" : "\"{dir}\" klasörü oluşturulamadı",
     "This will stop your current uploads." : "Bu işlem geçerli yüklemeleri durduracak.",
     "Upload cancelled." : "Yükleme iptal edildi.",
     "Processing files …" : "Dosyalar işleniyor …",
     "…" : "…",
     "Unable to upload {filename} as it is a directory or has 0 bytes" : "{filename} bir klasör ya da 0 bayt boyutunda olduğundan yüklenemedi",
-    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Yeterli boş alan yok. Yüklemek istediğiniz boyut {size1} ancak yalnız {size2} boş alan var",
+    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Yeterli boş alan yok. Yüklemek istediğiniz boyut {size1} ancak yalnızca {size2} boş alan var",
     "Target folder \"{dir}\" does not exist any more" : "\"{dir}\" hedef klasörü artık yok",
     "Not enough free space" : "Yeterli boş alan yok",
     "An unknown error has occurred" : "Bilinmeyen bir sorun çıktı",
+    "File could not be uploaded" : "Dosya yüklenemedi",
     "Uploading …" : "Yükleniyor …",
     "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} / {totalSize} ({bitrate})",
     "Uploading that item is not supported" : "Bu ögenin yüklenmesi desteklenmiyor",
@@ -29,8 +33,10 @@ OC.L10N.register(
     "Error when assembling chunks, status code {status}" : "Kümeler oluşturulurken sorun çıktı, durum kodu {status}",
     "Actions" : "İşlemler",
     "Rename" : "Yeniden adlandır",
+    "Move" : "Taşı",
     "Copy" : "Kopyala",
     "Choose target folder" : "Hedef klasörü seçin",
+    "Edit locally" : "Yerel olarak düzenle",
     "Open" : "Aç",
     "Delete file" : "Dosyayı sil",
     "Delete folder" : "Klasörü sil",
@@ -39,7 +45,10 @@ OC.L10N.register(
     "Could not load info for file \"{file}\"" : "\"{file}\" dosyasının bilgileri alınamadı",
     "Files" : "Dosyalar",
     "Details" : "Ayrıntılar",
-    "Select" : "Seçin",
+    "Please select tag(s) to add to the selection" : "Seçime eklemek için etiketleri seçin",
+    "Apply tag(s) to selection" : "Etiketleri seçime uygula",
+    "Select directory \"{dirName}\"" : "\"{dirName}\" klasörünü seçin",
+    "Select file \"{fileName}\"" : "\"{fileName}\" dosyasını seçin",
     "Pending" : "Bekliyor",
     "Unable to determine date" : "Tarih belirlenemedi",
     "This operation is forbidden" : "Bu işleme izin verilmiyor",
@@ -68,56 +77,57 @@ OC.L10N.register(
     "_%n folder_::_%n folders_" : ["%n klasör","%n klasör"],
     "_%n file_::_%n files_" : ["%n dosya","%n dosya"],
     "{dirs} and {files}" : "{dirs} ve {files}",
-    "_including %n hidden_::_including %n hidden_" : ["%n gizli ile birlikte","%n gizli ile birlikte"],
-    "You don’t have permission to upload or create files here" : "Buraya dosya yükleme ya da ekleme izniniz yok",
+    "_including %n hidden_::_including %n hidden_" : ["%n gizli ile birlikte","%n gizli ile birlikte"],
+    "You do not have permission to upload or create files here" : "Buraya dosya yükleme ya da ekleme izniniz yok",
     "_Uploading %n file_::_Uploading %n files_" : ["%n dosya yükleniyor","%n dosya yükleniyor"],
-    "New" : "Yeni",
+    "New file/folder menu" : "Yeni dosya/klasör menüsü",
     "Select file range" : "Dosya aralığını seçin",
+    "{used}%" : "%{used}",
     "{used} of {quota} used" : "{used} / {quota} kullanılmış",
     "{used} used" : "{used} kullanılmış",
     "\"{name}\" is an invalid file name." : "\"{name}\" geçersiz bir dosya adı.",
     "File name cannot be empty." : "Dosya adı boş olamaz.",
     "\"/\" is not allowed inside a file name." : "Dosya adında \"/\" kullanılamaz.",
     "\"{name}\" is not an allowed filetype" : "\"{name}\" dosya türüne izin verilmiyor",
-    "Storage of {owner} is full, files can not be updated or synced anymore!" : "{owner} için boş depolama alanı kalmadı. Artık dosyalar güncellenmeyecek ya da eşitlenmeyecek!",
-    "Group folder \"{mountPoint}\" is full, files can not be updated or synced anymore!" : "\"{mountPoint}\" grup klasöründe boş alan kalmadı. Artık güncellenemeyecek ya da eşitlenemeyecek!",
-    "External storage \"{mountPoint}\" is full, files can not be updated or synced anymore!" : "\"{mountPoint}\" dış depolamasında boş alan kalmadı. Artık güncellenemeyecek ya da eşitlenemeyecek!",
-    "Your storage is full, files can not be updated or synced anymore!" : "Boş depolama alanınız kalmadı. Artık dosyalar güncellenmeyecek ya da eşitlenmeyecek!",
+    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "{owner} için boş depolama alanı kalmadı. Artık dosyalar güncellenmeyecek ya da eşitlenmeyecek!",
+    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "\"{mountPoint}\" grup klasöründe boş alan kalmadı. Artık güncellenemeyecek ya da eşitlenemeyecek!",
+    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "\"{mountPoint}\" dış depolamasında boş alan kalmadı. Artık güncellenemeyecek ya da eşitlenemeyecek!",
+    "Your storage is full, files cannot be updated or synced anymore!" : "Boş depolama alanınız kalmadı. Artık dosyalar güncellenmeyecek ya da eşitlenmeyecek!",
     "Storage of {owner} is almost full ({usedSpacePercent}%)." : "{owner} boş depolama alanı bitmek üzere ({usedSpacePercent}%).",
     "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "\"{mountPoint}\" grup klasöründeki boş alan bitmek üzere ({usedSpacePercent}%).",
     "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "\"{mountPoint}\" dış depolamasındaki boş alan bitmek üzere ({usedSpacePercent}%).",
     "Your storage is almost full ({usedSpacePercent}%)." : "Boş depolama alanınız bitmek üzere ({usedSpacePercent}%).",
-    "_matches '{filter}'_::_match '{filter}'_" : ["'{filter}' ile eşleşen","'{filter}' ile eşleşen"],
-    "View in folder" : "Klasörde görüntüle",
+    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["\"{filter}\" ile eşleşiyor","\"{filter}\" ile eşleşiyor"],
+    "View in folder" : "Klasörde görüntüle",
     "Copied!" : "Kopyalandı!",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Doğrudan bağlantıyı kopyala (yalnız bu dosya ya da klasöre erişim izni olan kullanıcılar için)",
+    "Copy direct link (only works for users who have access to this file/folder)" : "Doğrudan bağlantıyı kopyala (yalnızca bu dosya ya da klasöre erişim izni olan kullanıcılar için)",
     "Path" : "Yol",
     "_%n byte_::_%n bytes_" : ["%n bayt","%n bayt"],
     "Favorited" : "Sık kullanılanlara eklendi",
     "Favorite" : "Sık kullanılanlara ekle",
-    "You can only favorite a single file or folder at a time" : "Aynı anda yalnız bir dosya ya da bir klasör sık kullanılanlara eklenebilir",
+    "You can only favorite a single file or folder at a time" : "Aynı anda yalnızca bir dosya ya da bir klasör sık kullanılanlara eklenebilir",
     "New folder" : "Yeni klasör",
     "Upload file" : "Dosya yükle",
     "Recent" : "Son",
     "Not favorited" : "Sık kullanılanlarda değil",
     "Remove from favorites" : "Sık kullanılanlardan kaldır",
     "Add to favorites" : "Sık kullanılanlara ekle",
-    "An error occurred while trying to update the tags" : "Etiketler güncellenirken bir sorun çıktı",
+    "An error occurred while trying to update the tags" : "Etiketler güncellenirken bir sorun çıktı",
     "Added to favorites" : "Sık kullanılanlara eklendi",
     "Removed from favorites" : "Sık kullanılanlardan çıkarıldı",
-    "You added {file} to your favorites" : "{file} dosyasını sık kullandıklarınıza eklediniz",
-    "You removed {file} from your favorites" : "{file} dosyasını sık kullandıklarınızdan çıkardınız",
+    "You added {file} to your favorites" : "{file} dosyasını sık kullandıklarınıza eklediniz",
+    "You removed {file} from your favorites" : "{file} dosyasını sık kullandıklarınızdan çıkardınız",
     "File changes" : "Dosya değişikleri",
-    "Created by {user}" : "{user} tarafından eklendi",
+    "Created by {user}" : "{user} tarafından eklendi",
     "Changed by {user}" : "{user} tarafından değiştirildi",
     "Deleted by {user}" : "{user} tarafından silindi",
-    "Restored by {user}" : "{user} tarafından geri yüklendi",
-    "Renamed by {user}" : "{user} tarafından adı değiştirildi",
+    "Restored by {user}" : "{user} tarafından geri yüklendi",
+    "Renamed by {user}" : "{user} tarafından adı değiştirildi",
     "Moved by {user}" : "{user} tarafından taşındı",
     "\"remote user\"" : "\"uzak kullanıcı\"",
-    "You created {file}" : "{file} dosyasını eklediniz",
+    "You created {file}" : "{file} dosyasını eklediniz",
     "You created an encrypted file in {file}" : "{file} içinde şifrelenmiş bir dosya oluşturdunuz",
-    "{user} created {file}" : "{user}, {file} dosyasını ekledi",
+    "{user} created {file}" : "{user}, {file} dosyasını ekledi",
     "{user} created an encrypted file in {file}" : "{user} kullanıcısı {file} içinde şifrelenmiş bir dosya oluşturdu",
     "{file} was created in a public folder" : "{file} dosyası herkese açık klasör içine eklendi",
     "You changed {file}" : "{file} dosyasını değiştirdiniz",
@@ -126,21 +136,27 @@ OC.L10N.register(
     "{user} changed an encrypted file in {file}" : "{user} kullanıcısı {file} içindeki şifrelenmiş bir dosyayı değiştirdi",
     "You deleted {file}" : "{file} dosyasını sildiniz",
     "You deleted an encrypted file in {file}" : "{file} içindeki şifrelenmiş bir dosyayı sildiniz",
-    "{user} deleted {file}" : "{user}, {file} dosyasını sildi",
+    "{user} deleted {file}" : "{user}, {file} dosyasını sildi",
     "{user} deleted an encrypted file in {file}" : "{user} kullanıcısı {file} içindeki şifrelenmiş bir dosyayı sildi",
-    "You restored {file}" : "{file} dosyasını geri yüklediniz",
-    "{user} restored {file}" : "{user}, {file} dosyasını geri yükledi",
-    "You renamed {oldfile} to {newfile}" : "{oldfile} dosyasının adını {newfile} olarak değiştirdiniz",
-    "{user} renamed {oldfile} to {newfile}" : "{user}, {oldfile} dosyasının adını {newfile} olarak değiştirdi",
-    "You moved {oldfile} to {newfile}" : "{oldfile} dosyasını {newfile} klasörüne taşıdınız",
-    "{user} moved {oldfile} to {newfile}" : "{user}, {oldfile} dosyasının {newfile} dosyasına taşıdı",
-    "A file has been added to or removed from your <strong>favorites</strong>" : "<strong>Sık kullandıklarınıza</strong> bir dosya eklendi ya da silindi",
+    "You restored {file}" : "{file} dosyasını geri yüklediniz",
+    "{user} restored {file}" : "{user}, {file} dosyasını geri yükledi",
+    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "{oldfile} (gizli) dosyasını {newfile} (gizli) olarak yeniden adlandırdınız",
+    "You renamed {oldfile} (hidden) to {newfile}" : "{oldfile} (gizli) dosyasını {newfile} olarak yeniden adlandırdınız",
+    "You renamed {oldfile} to {newfile} (hidden)" : "{oldfile} dosyasını {newfile} (gizli) olarak yeniden adlandırdınız",
+    "You renamed {oldfile} to {newfile}" : "{oldfile} dosyasının adını {newfile} olarak değiştirdiniz",
+    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "[user], {oldfile} (gizli) dosyasını {newfile} (gizli) olarak yeniden adlandırdı",
+    "{user} renamed {oldfile} (hidden) to {newfile}" : "[user], {oldfile} (gizli) dosyasını {newfile} olarak yeniden adlandırdı",
+    "{user} renamed {oldfile} to {newfile} (hidden)" : "[user], {oldfile} dosyasını {newfile} (gizli) olarak yeniden adlandırdı",
+    "{user} renamed {oldfile} to {newfile}" : "{user}, {oldfile} dosyasının adını {newfile} olarak değiştirdi",
+    "You moved {oldfile} to {newfile}" : "{oldfile} dosyasını {newfile} klasörüne taşıdınız",
+    "{user} moved {oldfile} to {newfile}" : "{user}, {oldfile} dosyasının {newfile} dosyasına taşıdı",
+    "A file has been added to or removed from your <strong>favorites</strong>" : "<strong>Sık kullandıklarınıza</strong> bir dosya eklendi ya da silindi",
     "A file or folder has been <strong>changed</strong>" : "Bir dosya ya da klasör <strong>değiştirildi</strong>",
     "A favorite file or folder has been <strong>changed</strong>" : "Sık kullanılan bir dosya ya da klasör <strong>değiştirildi</strong>",
     "All files" : "Tüm dosyalar",
     "Unlimited" : "Sınırsız",
     "Upload (max. %s)" : "Yükle (en büyük: %s)",
-    "Accept" : "Kabul Et",
+    "Accept" : "Kabul et",
     "Reject" : "Reddet",
     "Incoming ownership transfer from {user}" : "{user} kullanıcısından gelen sahiplik aktarımı ",
     "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "{path} yolunu onaylamak istiyor musunuz?\n\nNot: Onay verdikten sonra aktarım işleminin tamamlanması 1 saat kadar sürebilir.",
@@ -151,19 +167,18 @@ OC.L10N.register(
     "Your ownership transfer of {path} to {user} has completed." : "{path} yolundaki sahipliğiniz {user} kullanıcısına aktarıldı.",
     "The ownership transfer of {path} from {user} has completed." : "{path} yolundaki {user} kullanıcısının sahipliği size aktarıldı.",
     "in %s" : "%s içinde",
-    "File Management" : "Dosya Yönetimi",
+    "File Management" : "Dosya yönetimi",
     "Transfer ownership of a file or folder" : "Bir dosya ya da klasörün sahipliğini aktar",
     "Choose file or folder to transfer" : "Sahipliği aktarılacak dosya ya da klasörü seçin",
     "Change" : "Değiştir",
     "New owner" : "Yeni sahip",
     "Search users" : "Kullanıcı arama",
     "Choose a file or folder to transfer" : "Sahipliği aktarılacak bir dosya ya da klasör seçin",
-    "Transfer" : "Sahipliği Aktar",
+    "Transfer" : "Sahipliği aktar",
     "Transfer {path} to {userid}" : "{path} yolunun sahipliğini {userid} kullanıcısına aktar",
     "Invalid path selected" : "Seçilen yol geçersiz",
     "Ownership transfer request sent" : "Sahiplik aktarımı isteği gönderildi",
-    "Cannot transfer ownership of a file or folder you don't own" : "Sahibi olmadığınız bir dosya ya da klasörün sahipliğini aktaramazsınız",
-    "Tags" : "Etiketler",
+    "Cannot transfer ownership of a file or folder you do not own" : "Sahibi olmadığınız bir dosya ya da klasörün sahipliğini aktaramazsınız",
     "Unable to change the favourite state of the file" : "Dosyanın sık kullanılan durumu değiştirilemedi",
     "Error while loading the file data" : "Dosya verileri yüklenirken sorun çıktı",
     "Pick a template for {name}" : "{name} için bir kalıp seçin",
@@ -177,13 +192,14 @@ OC.L10N.register(
     "Templates" : "Kalıplar",
     "Unable to initialize the templates directory" : "Kalıp klasörü hazırlanamadı",
     "%s used" : "%s kullanılıyor",
-    "%s%% of %s used" : "%s%%/%s kullanılmış",
+    "%s%%" : "%%%s",
     "%1$s of %2$s used" : "%1$s / %2$s kullanıldı",
-    "Settings" : "Ayarlar",
-    "Show hidden files" : "Gizli dosyaları görüntüle",
+    "Files settings" : "Dosyalar ayarları",
+    "Show hidden files" : "Gizli dosyaları görüntüle",
     "Crop image previews" : "Görsel ön izlemeleri kırpılsın",
     "WebDAV" : "WebDAV",
     "Use this address to access your Files via WebDAV" : "Dosyalarınıza WebDAV üzerinden erişmek için bu adresi kullanın",
+    "Toggle %1$s sublist" : "%1$s alt listesini aç/kapat",
     "Toggle grid view" : "Tablo görünümünü değiştir",
     "No files in here" : "Burada herhangi bir dosya yok",
     "Upload some content or sync with your devices!" : "Bir şeyler yükleyin ya da aygıtlarınızla eşitleyin!",
@@ -195,22 +211,18 @@ OC.L10N.register(
     "Files and folders you mark as favorite will show up here" : "Sık kullanılanlara eklediğiniz dosya ve klasörler burada görüntülenir",
     "Deleted files" : "Silinmiş dosyalar",
     "Shares" : "Paylaşımlar",
-    "Shared with others" : "Diğerleri ile paylaşılan",
+    "Shared with others" : "Başkalarıyla paylaşılan",
     "Shared with you" : "Sizinle paylaşılan",
     "Shared by link" : "Bağlantı ile paylaşılmış",
     "Deleted shares" : "Silinmiş paylaşımlar",
     "Pending shares" : "Bekleyen paylaşımlar",
     "Text file" : "Metin dosyası",
     "New text file.txt" : "Yeni metin dosyası.txt",
-    "Unshare" : "Paylaşımı kaldır",
-    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "{owner} boş depolama alanı bitmek üzere ({usedSpacePercent}%)",
-    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)" : "\"{mountPoint}\" grup klasöründeki boş alan bitmek üzere (%{usedSpacePercent}).",
-    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)" : "\"{mountPoint}\" dış depolamasındaki boş alan bitmek üzere (%{usedSpacePercent}%).",
-    "Your storage is almost full ({usedSpacePercent}%)" : "Boş depolama alanınız bitmek üzere (%{usedSpacePercent})",
-    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Bir dosya ya da klasör <strong>değiştirildi</strong> ya da <strong>yeniden adlandırıldı</strong>",
-    "A new file or folder has been <strong>created</strong>" : "Yeni bir dosya ya da klasör <strong>eklendi</strong>",
-    "A file or folder has been <strong>deleted</strong>" : "Bir dosya ya da klasör <strong>silindi</strong>",
-    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "<strong>Sık kullanılan dosyalarınız</strong> ile ilgili ekleme ve değişiklik bildirimleri sınırlansın <em>(Yalnız akış)</em>",
-    "A file or folder has been <strong>restored</strong>" : "Bir dosya ya da klasör <strong>geri yüklendi</strong>"
+    "Select" : "Seçin",
+    "You don’t have permission to upload or create files here" : "Buraya dosya yükleme ya da ekleme izniniz yok",
+    "New" : "Yeni",
+    "Cannot transfer ownership of a file or folder you don't own" : "Sahibi olmadığınız bir dosya ya da klasörün sahipliğini aktaramazsınız",
+    "%s%% of %s used" : "%s%%/%s kullanılmış",
+    "Settings" : "Ayarlar"
 },
 "nplurals=2; plural=(n > 1);");
