@@ -8,6 +8,9 @@ OC.L10N.register(
     "Move or copy" : "移动或复制",
     "Download" : "下载",
     "Delete" : "删除",
+    "Tags" : "标签",
+    "Show list view" : "显示列表视图",
+    "Show grid view" : "显示网格视图",
     "Home" : "首页",
     "Close" : "关闭",
     "Favorites" : "收藏",
@@ -21,14 +24,16 @@ OC.L10N.register(
     "Target folder \"{dir}\" does not exist any more" : "目标目录 \"{dir}\" 不存在",
     "Not enough free space" : "可用空间不足",
     "An unknown error has occurred" : "发生了未知错误。",
+    "File could not be uploaded" : "文件无法上传",
     "Uploading …" : "正在上传...",
     "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} / {totalSize} ({bitrate})",
     "Uploading that item is not supported" : "不支持上传此项目",
-    "Target folder does not exist any more" : "目标文件夹不存在",
-    "Operation is blocked by access control" : "操作被访问控制阻止",
+    "Target folder does not exist any more" : "目标文件夹已不存在",
+    "Operation is blocked by access control" : "访问控制阻止此操作",
     "Error when assembling chunks, status code {status}" : "组装块时发生错误，状态码 {status}",
     "Actions" : "操作",
     "Rename" : "重命名",
+    "Move" : "移动",
     "Copy" : "复制",
     "Choose target folder" : "选择目标文件夹",
     "Open" : "打开",
@@ -39,7 +44,9 @@ OC.L10N.register(
     "Could not load info for file \"{file}\"" : "无法加载文件 \"{file}\" 的信息",
     "Files" : "文件",
     "Details" : "详细信息",
-    "Select" : "选择",
+    "Please select tag(s) to add to the selection" : "请选择要添加到所选项目的标签",
+    "Apply tag(s) to selection" : "将标签应用到所选项目",
+    "Select directory \"{dirName}\"" : "选择目录 \"{dirName}\"",
     "Pending" : "等待",
     "Unable to determine date" : "无法确定日期",
     "This operation is forbidden" : "该操作被禁止",
@@ -69,9 +76,7 @@ OC.L10N.register(
     "_%n file_::_%n files_" : ["%n 个文件"],
     "{dirs} and {files}" : "{dirs} 和 {files}",
     "_including %n hidden_::_including %n hidden_" : ["包括 %n 个隐藏文件"],
-    "You don’t have permission to upload or create files here" : "您没有权限在此上传或创建文件",
     "_Uploading %n file_::_Uploading %n files_" : ["正在上传 %n 个文件"],
-    "New" : "新建",
     "Select file range" : "选择文件范围",
     "{used} of {quota} used" : "已使用 {used} / {quota}",
     "{used} used" : "已使用 {used} 存储空间",
@@ -79,15 +84,15 @@ OC.L10N.register(
     "File name cannot be empty." : "文件名不能为空。",
     "\"/\" is not allowed inside a file name." : "文件名不能包含“/”",
     "\"{name}\" is not an allowed filetype" : "\"{name}\" 不是允许的文件类型",
-    "Storage of {owner} is full, files can not be updated or synced anymore!" : "{owner} 的存储空间已满，文件将无法更新或同步！",
-    "Group folder \"{mountPoint}\" is full, files can not be updated or synced anymore!" : "组文件夹 \"{mountPoint}\" 已满，无法再更新或同步文件！",
-    "External storage \"{mountPoint}\" is full, files can not be updated or synced anymore!" : "外部存储 \"{mountPoint}\" 已满，无法再更新或同步文件！",
-    "Your storage is full, files can not be updated or synced anymore!" : "您的存储空间已满，文件将无法更新或同步！",
+    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "{owner} 的存储已满，无法再更新或同步文件了！",
+    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "群组文件夹 “{mountPoint}” 已满，无法再更新或同步文件！",
+    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "外部存储器 \"{mountPoint}\" 已满，无法再更新或同步文件！",
+    "Your storage is full, files cannot be updated or synced anymore!" : "你的存储已满，无法再更新或同步文件！",
     "Storage of {owner} is almost full ({usedSpacePercent}%)." : "{owner} 的存储空间几乎已满 ({usedSpacePercent}%)。",
     "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "组文件夹 \"{mountPoint}\" 的存储空间几乎已满 ({usedSpacePercent}%)。",
     "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "外部存储 \"{mountPoint}\" 的存储空间几乎已满 ({usedSpacePercent}%)。",
     "Your storage is almost full ({usedSpacePercent}%)." : "您的存储空间几乎已满（{usedSpacePercent}%）",
-    "_matches '{filter}'_::_match '{filter}'_" : ["匹配 '{filter}'"],
+    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["匹配 \"{filter}\""],
     "View in folder" : "在文件夹中查看",
     "Copied!" : "已复制",
     "Copy direct link (only works for users who have access to this file/folder)" : "复制直接链接(仅适用于有权访问此文件/文件夹的用户)",
@@ -130,7 +135,13 @@ OC.L10N.register(
     "{user} deleted an encrypted file in {file}" : "{user} 在 {file} 删除了加密文件",
     "You restored {file}" : "您恢复了{file}",
     "{user} restored {file}" : "{user} 恢复了 {file}",
+    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "你将 {oldfile} (隐藏的) 重命名为了 {newfile} (隐藏的)",
+    "You renamed {oldfile} (hidden) to {newfile}" : "你将 {oldfile} (隐藏的) 重命名为了 {newfile}",
+    "You renamed {oldfile} to {newfile} (hidden)" : "你将 {oldfile} 重命名为了 {newfile} (隐藏的)",
     "You renamed {oldfile} to {newfile}" : "您将 {oldfile} 改名为 {newfile}",
+    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} 将 {oldfile} (隐藏的) 重命名为了 {newfile} (隐藏的)",
+    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} 将 {oldfile} (隐藏的)  重命名为了 {newfile}",
+    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} 将 {oldfile} 重命名为了 {newfile} (隐藏的)",
     "{user} renamed {oldfile} to {newfile}" : "{user} 将 {oldfile} 改名为 {newfile}",
     "You moved {oldfile} to {newfile}" : "你将 {oldfile} 移动到了 {newfile}",
     "{user} moved {oldfile} to {newfile}" : "{user} 将 {oldfile} 移动到了 {newfile}",
@@ -143,9 +154,9 @@ OC.L10N.register(
     "Accept" : "接受",
     "Reject" : "拒绝",
     "Incoming ownership transfer from {user}" : "来自{user}的所有权转移",
-    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "您要接受{path}吗？\n\n注意：接受之后的转移过程可能长达1小时。",
+    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "您要接受{path}吗？\n\n注意：接受后转移过程可能长达1小时。",
     "Ownership transfer failed" : "所有权转移失败",
-    "Your ownership transfer of {path} to {user} failed." : "您的{path}向{user}的所有权转移失败。",
+    "Your ownership transfer of {path} to {user} failed." : "您{path}的所有权向{user}转移失败。",
     "The ownership transfer of {path} from {user} failed." : "来自{user}的{path}的所有权转移失败。",
     "Ownership transfer done" : "所有权转移完成",
     "Your ownership transfer of {path} to {user} has completed." : "您的{path}向{user}的所有权转移已完成。",
@@ -154,19 +165,17 @@ OC.L10N.register(
     "File Management" : "文件管理",
     "Transfer ownership of a file or folder" : "转移文件或文件夹的所有权",
     "Choose file or folder to transfer" : "选择要转移的文件或文件夹",
-    "Change" : "变更",
+    "Change" : "修改",
     "New owner" : "新的拥有者",
     "Search users" : "搜索用户",
     "Choose a file or folder to transfer" : "选择要转移的文件或文件夹",
     "Transfer" : "转移",
-    "Transfer {path} to {userid}" : "转移 {path} 给 {userid}",
+    "Transfer {path} to {userid}" : "将 {path} 转移给 {userid}",
     "Invalid path selected" : "选择的路径无效",
     "Ownership transfer request sent" : "所有权转移请求已发送",
-    "Cannot transfer ownership of a file or folder you don't own" : "无法转让您未拥有的文件或文件夹的所有权",
-    "Tags" : "标签",
-    "Unable to change the favourite state of the file" : "无法更改文件的收藏状态",
+    "Unable to change the favourite state of the file" : "无法修改文件的收藏状态",
     "Error while loading the file data" : "加载文件数据时出错",
-    "Pick a template for {name}" : "为 {name} 挑选一个模板",
+    "Pick a template for {name}" : "给 {name} 挑选一个模板",
     "Cancel" : "取消",
     "Create" : "创建",
     "Create a new file with the selected template" : "用所选模板创建一个新文件",
@@ -176,14 +185,13 @@ OC.L10N.register(
     "Set up templates folder" : "设置模板文件夹",
     "Templates" : "模板",
     "Unable to initialize the templates directory" : "无法初始化模板目录",
-    "%s used" : "已使用了 %s",
-    "%s%% of %s used" : "%s 已使用了 %s 中的 %%",
-    "%1$s of %2$s used" : "已使用了 %2$s 中的 %1$s",
-    "Settings" : "设置",
+    "%s used" : "已使用 %s",
+    "%1$s of %2$s used" : "已使用 %2$s 中的 %1$s",
     "Show hidden files" : "显示隐藏文件",
     "Crop image previews" : "裁剪图片预览",
     "WebDAV" : "WebDAV",
     "Use this address to access your Files via WebDAV" : "使用此地址通过 WebDAV 访问您的文件",
+    "Toggle %1$s sublist" : "切换 %1$s 子列表",
     "Toggle grid view" : "切换网格视图",
     "No files in here" : "这里没有文件",
     "Upload some content or sync with your devices!" : "上传一些内容或与您的设备同步！",
@@ -202,15 +210,11 @@ OC.L10N.register(
     "Pending shares" : "待定共享",
     "Text file" : "文本文件",
     "New text file.txt" : "新建文本文档.txt",
-    "Unshare" : "取消共享",
-    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "{owner} 的存储空间即将用完（{usedSpacePercent}%）",
-    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)" : "组文件夹 \"{mountPoint}\" 的存储空间几乎已满 ({usedSpacePercent}%)",
-    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)" : "外部存储 \"{mountPoint}\" 的存储空间几乎已满 ({usedSpacePercent}%)",
-    "Your storage is almost full ({usedSpacePercent}%)" : "您的存储空间即将用完（{usedSpacePercent}%）",
-    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "文件/文件夹已经 <strong>更改</strong> 或者 <strong>重命名</strong>",
-    "A new file or folder has been <strong>created</strong>" : "新的文件或文件夹已被 <strong>创建</strong>",
-    "A file or folder has been <strong>deleted</strong>" : "一个文件或文件夹已被 <strong>删除</strong>",
-    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "仅限 <strong>收藏文件</strong>的创建和更改通知 <em>（仅限流）</em>",
-    "A file or folder has been <strong>restored</strong>" : "一个文件或文件夹已被<strong>恢复</strong>"
+    "Select" : "选择",
+    "You don’t have permission to upload or create files here" : "您没有权限在此上传或创建文件",
+    "New" : "新建",
+    "Cannot transfer ownership of a file or folder you don't own" : "无法转让您未拥有的文件或文件夹的所有权",
+    "%s%% of %s used" : "%s 已使用 %s 中的 %%",
+    "Settings" : "设置"
 },
 "nplurals=1; plural=0;");
