@@ -6,10 +6,13 @@
  * @author Bart Visscher <bartv@thisnet.nl>
  * @author Bjoern Schiessle <bjoern@schiessle.org>
  * @author Björn Schießle <bjoern@schiessle.org>
- * @author Carlos Damken <carlos@damken.com>
+ * @author Christoph Wurst <christoph@winzerhof-wurst.at>
  * @author Felix Moeller <mail@felixmoeller.de>
+ * @author Felix Nieuwenhuizen <felix@tdlrali.com>
  * @author Joas Schilling <coding@schilljs.com>
  * @author Jörn Friedrich Dreyer <jfd@butonic.de>
+ * @author Julius Härtl <jus@bitgrid.net>
+ * @author Liam JACK <liamjack@users.noreply.github.com>
  * @author Lukas Reschke <lukas@statuscode.ch>
  * @author Morris Jobke <hey@morrisjobke.de>
  * @author Robin Appelman <robin@icewind.nl>
@@ -17,7 +20,7 @@
  * @author Roeland Jago Douma <roeland@famdouma.nl>
  * @author Thomas Müller <thomas.mueller@tmit.eu>
  * @author Victor Dubiniuk <dubiniuk@owncloud.com>
- * @author Vincent Petry <pvince81@owncloud.com>
+ * @author Vincent Petry <vincent@nextcloud.com>
  *
  * @license AGPL-3.0
  *
@@ -31,57 +34,68 @@
  * GNU Affero General Public License for more details.
  *
  * You should have received a copy of the GNU Affero General Public License, version 3,
- * along with this program.  If not, see <http://www.gnu.org/licenses/>
+ * along with this program. If not, see <http://www.gnu.org/licenses/>
  *
  */
 
-/**
- * Versions
- *
- * A class to handle the versioning of files.
- */
-
 namespace OCA\Files_Versions;
 
+use OC\Files\Search\SearchBinaryOperator;
+use OC\Files\Search\SearchComparison;
+use OC\Files\Search\SearchQuery;
+use OC_User;
 use OC\Files\Filesystem;
 use OC\Files\View;
+use OCA\Files_Sharing\SharedMount;
 use OCA\Files_Versions\AppInfo\Application;
 use OCA\Files_Versions\Command\Expire;
 use OCA\Files_Versions\Events\CreateVersionEvent;
 use OCA\Files_Versions\Versions\IVersionManager;
+use OCP\Files\FileInfo;
+use OCP\Files\Folder;
+use OCP\Files\IRootFolder;
+use OCP\Files\Node;
+use OCP\Command\IBus;
+use OCP\EventDispatcher\IEventDispatcher;
+use OCP\Files\IMimeTypeDetector;
 use OCP\Files\NotFoundException;
+use OCP\Files\Search\ISearchBinaryOperator;
+use OCP\Files\Search\ISearchComparison;
+use OCP\Files\StorageNotAvailableException;
+use OCP\IURLGenerator;
+use OCP\IUser;
+use OCP\IUserManager;
 use OCP\Lock\ILockingProvider;
-use OCP\User;
+use Psr\Log\LoggerInterface;
 
 class Storage {
+	public const DEFAULTENABLED = true;
+	public const DEFAULTMAXSIZE = 50; // unit: percentage; 50% of available disk space/quota
+	public const VERSIONS_ROOT = 'files_versions/';
 
-	const DEFAULTENABLED=true;
-	const DEFAULTMAXSIZE=50; // unit: percentage; 50% of available disk space/quota
-	const VERSIONS_ROOT = 'files_versions/';
-
-	const DELETE_TRIGGER_MASTER_REMOVED = 0;
-	const DELETE_TRIGGER_RETENTION_CONSTRAINT = 1;
-	const DELETE_TRIGGER_QUOTA_EXCEEDED = 2;
+	public const DELETE_TRIGGER_MASTER_REMOVED = 0;
+	public const DELETE_TRIGGER_RETENTION_CONSTRAINT = 1;
+	public const DELETE_TRIGGER_QUOTA_EXCEEDED = 2;
 
 	// files for which we can remove the versions after the delete operation was successful
-	private static $deletedFiles = array();
+	private static $deletedFiles = [];
 
-	private static $sourcePathAndUser = array();
+	private static $sourcePathAndUser = [];
 
-	private static $max_versions_per_interval = array(
+	private static $max_versions_per_interval = [
 		//first 10sec, one version every 2sec
-		1 => array('intervalEndsAfter' => 10,      'step' => 2),
+		1 => ['intervalEndsAfter' => 10,      'step' => 2],
 		//next minute, one version every 10sec
-		2 => array('intervalEndsAfter' => 60,      'step' => 10),
+		2 => ['intervalEndsAfter' => 60,      'step' => 10],
 		//next hour, one version every minute
-		3 => array('intervalEndsAfter' => 3600,    'step' => 60),
+		3 => ['intervalEndsAfter' => 3600,    'step' => 60],
 		//next 24h, one version every hour
-		4 => array('intervalEndsAfter' => 86400,   'step' => 3600),
+		4 => ['intervalEndsAfter' => 86400,   'step' => 3600],
 		//next 30days, one version per day
-		5 => array('intervalEndsAfter' => 2592000, 'step' => 86400),
+		5 => ['intervalEndsAfter' => 2592000, 'step' => 86400],
 		//until the end one version per week
-		6 => array('intervalEndsAfter' => -1,      'step' => 604800),
-	);
+		6 => ['intervalEndsAfter' => -1,      'step' => 604800],
+	];
 
 	/** @var \OCA\Files_Versions\AppInfo\Application */
 	private static $application;
@@ -96,15 +110,15 @@ class Storage {
 	 */
 	public static function getUidAndFilename($filename) {
 		$uid = Filesystem::getOwner($filename);
-		$userManager = \OC::$server->getUserManager();
+		$userManager = \OC::$server->get(IUserManager::class);
 		// if the user with the UID doesn't exists, e.g. because the UID points
 		// to a remote user with a federated cloud ID we use the current logged-in
 		// user. We need a valid local user to create the versions
 		if (!$userManager->userExists($uid)) {
-			$uid = User::getUser();
+			$uid = OC_User::getUser();
 		}
 		Filesystem::initMountPoints($uid);
-		if ( $uid !== User::getUser() ) {
+		if ($uid !== OC_User::getUser()) {
 			$info = Filesystem::getFileInfo($filename);
 			$ownerView = new View('/'.$uid.'/files');
 			try {
@@ -125,8 +139,8 @@ class Storage {
 	 * @param string $source source path
 	 */
 	public static function setSourcePathAndUser($source) {
-		list($uid, $path) = self::getUidAndFilename($source);
-		self::$sourcePathAndUser[$source] = array('uid' => $uid, 'path' => $path);
+		[$uid, $path] = self::getUidAndFilename($source);
+		self::$sourcePathAndUser[$source] = ['uid' => $uid, 'path' => $path];
 	}
 
 	/**
@@ -136,7 +150,6 @@ class Storage {
 	 * @return array with user id and path
 	 */
 	public static function getSourcePathAndUser($source) {
-
 		if (isset(self::$sourcePathAndUser[$source])) {
 			$uid = self::$sourcePathAndUser[$source]['uid'];
 			$path = self::$sourcePathAndUser[$source]['path'];
@@ -144,7 +157,7 @@ class Storage {
 		} else {
 			$uid = $path = false;
 		}
-		return array($uid, $path);
+		return [$uid, $path];
 	}
 
 	/**
@@ -176,33 +189,45 @@ class Storage {
 			return false;
 		}
 
-		list($uid, $filename) = self::getUidAndFilename($filename);
+		// since hook paths are always relative to the "default filesystem view"
+		// we always use the owner from there to get the full node
+		$uid = Filesystem::getView()->getOwner('');
 
-		$files_view = new View('/'.$uid .'/files');
+		/** @var IRootFolder $rootFolder */
+		$rootFolder = \OC::$server->get(IRootFolder::class);
+		$userFolder = $rootFolder->getUserFolder($uid);
 
-		$eventDispatcher = \OC::$server->getEventDispatcher();
-		$fileInfo = $files_view->getFileInfo($filename);
-		$id = $fileInfo->getId();
-		$nodes = \OC::$server->getRootFolder()->getUserFolder($uid)->getById($id);
-		foreach ($nodes as $node) {
-			$event = new CreateVersionEvent($node);
-			$eventDispatcher->dispatch('OCA\Files_Versions::createVersion', $event);
-			if ($event->shouldCreateVersion() === false) {
-				return false;
+		$eventDispatcher = \OC::$server->get(IEventDispatcher::class);
+		try {
+			$file = $userFolder->get($filename);
+		} catch (NotFoundException $e) {
+			return false;
+		}
+
+		$mount = $file->getMountPoint();
+		if ($mount instanceof SharedMount) {
+			$ownerFolder = $rootFolder->getUserFolder($mount->getShare()->getShareOwner());
+			$ownerNodes = $ownerFolder->getById($file->getId());
+			if (count($ownerNodes)) {
+				$file = current($ownerNodes);
 			}
 		}
 
 		// no use making versions for empty files
-		if ($fileInfo->getSize() === 0) {
+		if ($file->getSize() === 0) {
+			return false;
+		}
+
+		$event = new CreateVersionEvent($file);
+		$eventDispatcher->dispatch('OCA\Files_Versions::createVersion', $event);
+		if ($event->shouldCreateVersion() === false) {
 			return false;
 		}
 
 		/** @var IVersionManager $versionManager */
-		$versionManager = \OC::$server->query(IVersionManager::class);
-		$userManager = \OC::$server->getUserManager();
-		$user = $userManager->get($uid);
+		$versionManager = \OC::$server->get(IVersionManager::class);
 
-		$versionManager->createVersion($user, $fileInfo);
+		$versionManager->createVersion($file->getOwner(), $file);
 	}
 
 
@@ -211,10 +236,10 @@ class Storage {
 	 * @param string $path
 	 */
 	public static function markDeletedFile($path) {
-		list($uid, $filename) = self::getUidAndFilename($path);
-		self::$deletedFiles[$path] = array(
+		[$uid, $filename] = self::getUidAndFilename($path);
+		self::$deletedFiles[$path] = [
 			'uid' => $uid,
-			'filename' => $filename);
+			'filename' => $filename];
 	}
 
 	/**
@@ -229,7 +254,7 @@ class Storage {
 		 * @var \OC\Files\Storage\Storage $storage
 		 * @var string $internalPath
 		 */
-		list($storage, $internalPath) = $view->resolvePath($path);
+		[$storage, $internalPath] = $view->resolvePath($path);
 		$cache = $storage->getCache($internalPath);
 		$cache->remove($internalPath);
 	}
@@ -238,21 +263,19 @@ class Storage {
 	 * Delete versions of a file
 	 */
 	public static function delete($path) {
-
 		$deletedFile = self::$deletedFiles[$path];
 		$uid = $deletedFile['uid'];
 		$filename = $deletedFile['filename'];
 
 		if (!Filesystem::file_exists($path)) {
-
 			$view = new View('/' . $uid . '/files_versions');
 
 			$versions = self::getVersions($uid, $filename);
 			if (!empty($versions)) {
 				foreach ($versions as $v) {
-					\OC_Hook::emit('\OCP\Versions', 'preDelete', array('path' => $path . $v['version'], 'trigger' => self::DELETE_TRIGGER_MASTER_REMOVED));
+					\OC_Hook::emit('\OCP\Versions', 'preDelete', ['path' => $path . $v['version'], 'trigger' => self::DELETE_TRIGGER_MASTER_REMOVED]);
 					self::deleteVersion($view, $filename . '.v' . $v['version']);
-					\OC_Hook::emit('\OCP\Versions', 'delete', array('path' => $path . $v['version'], 'trigger' => self::DELETE_TRIGGER_MASTER_REMOVED));
+					\OC_Hook::emit('\OCP\Versions', 'delete', ['path' => $path . $v['version'], 'trigger' => self::DELETE_TRIGGER_MASTER_REMOVED]);
 				}
 			}
 		}
@@ -269,7 +292,7 @@ class Storage {
 	 * @param string $operation can be 'copy' or 'rename'
 	 */
 	public static function renameOrCopy($sourcePath, $targetPath, $operation) {
-		list($sourceOwner, $sourcePath) = self::getSourcePathAndUser($sourcePath);
+		[$sourceOwner, $sourcePath] = self::getSourcePathAndUser($sourcePath);
 
 		// it was a upload of a existing file if no old path exists
 		// in this case the pre-hook already called the store method and we can
@@ -278,7 +301,7 @@ class Storage {
 			return true;
 		}
 
-		list($targetOwner, $targetPath) = self::getUidAndFilename($targetPath);
+		[$targetOwner, $targetPath] = self::getUidAndFilename($targetPath);
 
 		$sourcePath = ltrim($sourcePath, '/');
 		$targetPath = ltrim($targetPath, '/');
@@ -298,7 +321,7 @@ class Storage {
 					'/' . $targetOwner . '/files_versions/' . $targetPath
 				);
 			}
-		} else if ($versions = Storage::getVersions($sourceOwner, '/' . $sourcePath)) {
+		} elseif ($versions = Storage::getVersions($sourceOwner, '/' . $sourcePath)) {
 			// create missing dirs if necessary
 			self::createMissingDirectories($targetPath, new View('/'. $targetOwner));
 
@@ -315,7 +338,6 @@ class Storage {
 		if (!$rootView->is_dir('/' . $targetOwner . '/files/' . $targetPath)) {
 			self::scheduleExpire($targetOwner, $targetPath);
 		}
-
 	}
 
 	/**
@@ -325,20 +347,17 @@ class Storage {
 	 * @param int $revision revision timestamp
 	 * @return bool
 	 */
-	public static function rollback($file, $revision) {
+	public static function rollback(string $file, int $revision, IUser $user) {
 
 		// add expected leading slash
-		$file = '/' . ltrim($file, '/');
-		list($uid, $filename) = self::getUidAndFilename($file);
-		if ($uid === null || trim($filename, '/') === '') {
-			return false;
-		}
+		$filename = '/' . ltrim($file, '/');
 
 		// Fetch the userfolder to trigger view hooks
-		$userFolder = \OC::$server->getUserFolder($uid);
+		$root = \OC::$server->get(IRootFolder::class);
+		$userFolder = $root->getUserFolder($user->getUID());
 
-		$users_view = new View('/'.$uid);
-		$files_view = new View('/'. User::getUser().'/files');
+		$users_view = new View('/'.$user->getUID());
+		$files_view = new View('/'. $user->getUID().'/files');
 
 		$versionCreated = false;
 
@@ -356,7 +375,7 @@ class Storage {
 			$versionCreated = true;
 		}
 
-		$fileToRestore =  'files_versions' . $filename . '.v' . $revision;
+		$fileToRestore = 'files_versions' . $filename . '.v' . $revision;
 
 		// Restore encrypted version of the old file for the newly restored file
 		// This has to happen manually here since the file is manually copied below
@@ -374,23 +393,22 @@ class Storage {
 		// rollback
 		if (self::copyFileContents($users_view, $fileToRestore, 'files' . $filename)) {
 			$files_view->touch($file, $revision);
-			Storage::scheduleExpire($uid, $file);
+			Storage::scheduleExpire($user->getUID(), $file);
 
 			$node = $userFolder->get($file);
 
 			// TODO: move away from those legacy hooks!
-			\OC_Hook::emit('\OCP\Versions', 'rollback', array(
+			\OC_Hook::emit('\OCP\Versions', 'rollback', [
 				'path' => $filename,
 				'revision' => $revision,
 				'node' => $node,
-			));
+			]);
 			return true;
-		} else if ($versionCreated) {
+		} elseif ($versionCreated) {
 			self::deleteVersion($users_view, $version);
 		}
 
 		return false;
-
 	}
 
 	/**
@@ -404,9 +422,9 @@ class Storage {
 	 */
 	private static function copyFileContents($view, $path1, $path2) {
 		/** @var \OC\Files\Storage\Storage $storage1 */
-		list($storage1, $internalPath1) = $view->resolvePath($path1);
+		[$storage1, $internalPath1] = $view->resolvePath($path1);
 		/** @var \OC\Files\Storage\Storage $storage2 */
-		list($storage2, $internalPath2) = $view->resolvePath($path2);
+		[$storage2, $internalPath2] = $view->resolvePath($path2);
 
 		$view->lockFile($path1, ILockingProvider::LOCK_EXCLUSIVE);
 		$view->lockFile($path2, ILockingProvider::LOCK_EXCLUSIVE);
@@ -415,7 +433,7 @@ class Storage {
 		if ($storage1->instanceOfStorage('\OC\Files\ObjectStore\ObjectStoreStorage') || $storage2->instanceOfStorage('\OC\Files\ObjectStore\ObjectStoreStorage')) {
 			$source = $storage1->fopen($internalPath1, 'r');
 			$target = $storage2->fopen($internalPath2, 'w');
-			list(, $result) = \OC_Helper::streamCopy($source, $target);
+			[, $result] = \OC_Helper::streamCopy($source, $target);
 			fclose($source);
 			fclose($target);
 
@@ -440,7 +458,7 @@ class Storage {
 	 * @return array versions newest version first
 	 */
 	public static function getVersions($uid, $filename, $userFullPath = '') {
-		$versions = array();
+		$versions = [];
 		if (empty($filename)) {
 			return $versions;
 		}
@@ -476,12 +494,15 @@ class Storage {
 						if (empty($userFullPath)) {
 							$versions[$key]['preview'] = '';
 						} else {
-							$versions[$key]['preview'] = \OC::$server->getURLGenerator('files_version.Preview.getPreview', ['file' => $userFullPath, 'version' => $timestamp]);
+							/** @var IURLGenerator $urlGenerator */
+							$urlGenerator = \OC::$server->get(IURLGenerator::class);
+							$versions[$key]['preview'] = $urlGenerator->linkToRoute('files_version.Preview.getPreview',
+								['file' => $userFullPath, 'version' => $timestamp]);
 						}
 						$versions[$key]['path'] = Filesystem::normalizePath($pathinfo['dirname'] . '/' . $filename);
 						$versions[$key]['name'] = $versionedFile;
 						$versions[$key]['size'] = $view->filesize($dir . '/' . $entryName);
-						$versions[$key]['mimetype'] = \OC::$server->getMimeTypeDetector()->detectPath($versionedFile);
+						$versions[$key]['mimetype'] = \OC::$server->get(IMimeTypeDetector::class)->detectPath($versionedFile);
 					}
 				}
 			}
@@ -496,43 +517,59 @@ class Storage {
 
 	/**
 	 * Expire versions that older than max version retention time
+	 *
 	 * @param string $uid
 	 */
-	public static function expireOlderThanMaxForUser($uid){
-		$expiration = self::getExpiration();
-		$threshold = $expiration->getMaxAgeAsTimestamp();
-		$versions = self::getAllVersions($uid);
-		if (!$threshold || !array_key_exists('all', $versions)) {
+	public static function expireOlderThanMaxForUser($uid) {
+		/** @var IRootFolder $root */
+		$root = \OC::$server->get(IRootFolder::class);
+		try {
+			/** @var Folder $versionsRoot */
+			$versionsRoot = $root->get('/' . $uid . '/files_versions');
+		} catch (NotFoundException $e) {
 			return;
 		}
 
-		$toDelete = [];
-		foreach (array_reverse($versions['all']) as $key => $version) {
-			if ((int)$version['version'] <$threshold) {
-				$toDelete[$key] = $version;
-			} else {
-				//Versions are sorted by time - nothing mo to iterate.
-				break;
-			}
+		$expiration = self::getExpiration();
+		$threshold = $expiration->getMaxAgeAsTimestamp();
+		if (!$threshold) {
+			return;
 		}
 
-		$view = new View('/' . $uid . '/files_versions');
-		if (!empty($toDelete)) {
-			foreach ($toDelete as $version) {
-				\OC_Hook::emit('\OCP\Versions', 'preDelete', array('path' => $version['path'].'.v'.$version['version'], 'trigger' => self::DELETE_TRIGGER_RETENTION_CONSTRAINT));
-				self::deleteVersion($view, $version['path'] . '.v' . $version['version']);
-				\OC_Hook::emit('\OCP\Versions', 'delete', array('path' => $version['path'].'.v'.$version['version'], 'trigger' => self::DELETE_TRIGGER_RETENTION_CONSTRAINT));
+		$allVersions = $versionsRoot->search(new SearchQuery(
+			new SearchBinaryOperator(ISearchBinaryOperator::OPERATOR_NOT, [
+				new SearchComparison(ISearchComparison::COMPARE_EQUAL, 'mimetype', FileInfo::MIMETYPE_FOLDER),
+			]),
+			0,
+			0,
+			[]
+		));
+
+		/** @var Node[] $versions */
+		$versions = array_filter($allVersions, function (Node $info) use ($threshold) {
+			$versionsBegin = strrpos($info->getName(), '.v');
+			if ($versionsBegin === false) {
+				return false;
 			}
+			$version = (int)substr($info->getName(), $versionsBegin + 2);
+			return $version < $threshold;
+		});
+
+		foreach ($versions as $version) {
+			$internalPath = $version->getInternalPath();
+			\OC_Hook::emit('\OCP\Versions', 'preDelete', ['path' => $internalPath, 'trigger' => self::DELETE_TRIGGER_RETENTION_CONSTRAINT]);
+			$version->delete();
+			\OC_Hook::emit('\OCP\Versions', 'delete', ['path' => $internalPath, 'trigger' => self::DELETE_TRIGGER_RETENTION_CONSTRAINT]);
 		}
 	}
 
 	/**
 	 * translate a timestamp into a string like "5 days ago"
+	 *
 	 * @param int $timestamp
 	 * @return string for example "5 days ago"
 	 */
 	private static function getHumanReadableTimestamp($timestamp) {
-
 		$diff = time() - $timestamp;
 
 		if ($diff < 60) { // first minute
@@ -550,7 +587,6 @@ class Storage {
 		} else {
 			return round($diff / 29030400) . " years ago";
 		}
-
 	}
 
 	/**
@@ -560,8 +596,8 @@ class Storage {
 	 */
 	private static function getAllVersions($uid) {
 		$view = new View('/' . $uid . '/');
-		$dirs = array(self::VERSIONS_ROOT);
-		$versions = array();
+		$dirs = [self::VERSIONS_ROOT];
+		$versions = [];
 
 		while (!empty($dirs)) {
 			$dir = array_pop($dirs);
@@ -578,7 +614,7 @@ class Storage {
 					$version = substr($filePath, $versionsBegin + 2);
 					$relpath = substr($filePath, $relPathStart, $versionsBegin - $relPathStart);
 					$key = $version . '#' . $relpath;
-					$versions[$key] = array('path' => $relpath, 'timestamp' => $version);
+					$versions[$key] = ['path' => $relpath, 'timestamp' => $version];
 				}
 			}
 		}
@@ -586,7 +622,10 @@ class Storage {
 		// newest version first
 		krsort($versions);
 
-		$result = array();
+		$result = [
+			'all' => [],
+			'by_file' => [],
+		];
 
 		foreach ($versions as $key => $value) {
 			$size = $view->filesize(self::VERSIONS_ROOT.'/'.$value['path'].'.v'.$value['timestamp']);
@@ -615,7 +654,7 @@ class Storage {
 		$expiration = self::getExpiration();
 
 		if ($expiration->shouldAutoExpire()) {
-			list($toDelete, $size) = self::getAutoExpireList($time, $versions);
+			[$toDelete, $size] = self::getAutoExpireList($time, $versions);
 		} else {
 			$size = 0;
 			$toDelete = [];  // versions we want to delete
@@ -639,7 +678,7 @@ class Storage {
 	 */
 	protected static function getAutoExpireList($time, $versions) {
 		$size = 0;
-		$toDelete = array();  // versions we want to delete
+		$toDelete = [];  // versions we want to delete
 
 		$interval = 1;
 		$step = Storage::$max_versions_per_interval[$interval]['step'];
@@ -650,6 +689,11 @@ class Storage {
 		}
 
 		$firstVersion = reset($versions);
+
+		if ($firstVersion === false) {
+			return [$toDelete, $size];
+		}
+
 		$firstKey = key($versions);
 		$prevTimestamp = $firstVersion['version'];
 		$nextVersion = $firstVersion['version'] - $step;
@@ -663,7 +707,7 @@ class Storage {
 						//distance between two version too small, mark to delete
 						$toDelete[$key] = $version['path'] . '.v' . $version['version'];
 						$size += $version['size'];
-						\OC::$server->getLogger()->info('Mark to expire '. $version['path'] .' next version should be ' . $nextVersion . " or smaller. (prevTimestamp: " . $prevTimestamp . "; step: " . $step, ['app' => 'files_versions']);
+						\OC::$server->get(LoggerInterface::class)->info('Mark to expire '. $version['path'] .' next version should be ' . $nextVersion . " or smaller. (prevTimestamp: " . $prevTimestamp . "; step: " . $step, ['app' => 'files_versions']);
 					} else {
 						$nextVersion = $version['version'] - $step;
 						$prevTimestamp = $version['version'];
@@ -683,7 +727,7 @@ class Storage {
 			}
 		}
 
-		return array($toDelete, $size);
+		return [$toDelete, $size];
 	}
 
 	/**
@@ -697,7 +741,9 @@ class Storage {
 		$expiration = self::getExpiration();
 		if ($expiration->isEnabled()) {
 			$command = new Expire($uid, $fileName);
-			\OC::$server->getCommandBus()->push($command);
+			/** @var IBus $bus */
+			$bus = \OC::$server->get(IBus::class);
+			$bus->push($command);
 		}
 	}
 
@@ -714,18 +760,27 @@ class Storage {
 	public static function expire($filename, $uid) {
 		$expiration = self::getExpiration();
 
+		/** @var LoggerInterface $logger */
+		$logger = \OC::$server->get(LoggerInterface::class);
+
 		if ($expiration->isEnabled()) {
 			// get available disk space for user
-			$user = \OC::$server->getUserManager()->get($uid);
+			$user = \OC::$server->get(IUserManager::class)->get($uid);
 			if (is_null($user)) {
-				\OC::$server->getLogger()->error('Backends provided no user object for ' . $uid, ['app' => 'files_versions']);
+				$logger->error('Backends provided no user object for ' . $uid, ['app' => 'files_versions']);
 				throw new \OC\User\NoUserException('Backends provided no user object for ' . $uid);
 			}
 
 			\OC_Util::setupFS($uid);
 
-			if (!Filesystem::file_exists($filename)) {
-				return false;
+			try {
+				if (!Filesystem::file_exists($filename)) {
+					return false;
+				}
+			} catch (StorageNotAvailableException $e) {
+				// if we can't check that the file hasn't been deleted we can only assume that it hasn't
+				// note that this `StorageNotAvailableException` is about the file the versions originate from,
+				// not the storage that the versions are stored on
 			}
 
 			if (empty($filename)) {
@@ -736,7 +791,7 @@ class Storage {
 
 			$softQuota = true;
 			$quota = $user->getQuota();
-			if ( $quota === null || $quota === 'none' ) {
+			if ($quota === null || $quota === 'none') {
 				$quota = Filesystem::free_space('/');
 				$softQuota = false;
 			} else {
@@ -750,13 +805,17 @@ class Storage {
 			// subtract size of files and current versions size from quota
 			if ($quota >= 0) {
 				if ($softQuota) {
-					$files_view = new View('/' . $uid . '/files');
-					$rootInfo = $files_view->getFileInfo('/', false);
-					$free = $quota - $rootInfo['size']; // remaining free space for user
-					if ($free > 0) {
-						$availableSpace = ($free * self::DEFAULTMAXSIZE / 100) - $versionsSize; // how much space can be used for versions
+					$root = \OC::$server->get(IRootFolder::class);
+					$userFolder = $root->getUserFolder($uid);
+					if (is_null($userFolder)) {
+						$availableSpace = 0;
 					} else {
-						$availableSpace = $free - $versionsSize;
+						$free = $quota - $userFolder->getSize(false); // remaining free space for user
+						if ($free > 0) {
+							$availableSpace = ($free * self::DEFAULTMAXSIZE / 100) - $versionsSize; // how much space can be used for versions
+						} else {
+							$availableSpace = $free - $versionsSize;
+						}
 					}
 				} else {
 					$availableSpace = $quota;
@@ -768,18 +827,18 @@ class Storage {
 			$allVersions = Storage::getVersions($uid, $filename);
 
 			$time = time();
-			list($toDelete, $sizeOfDeletedVersions) = self::getExpireList($time, $allVersions, $availableSpace <= 0);
+			[$toDelete, $sizeOfDeletedVersions] = self::getExpireList($time, $allVersions, $availableSpace <= 0);
 
 			$availableSpace = $availableSpace + $sizeOfDeletedVersions;
 			$versionsSize = $versionsSize - $sizeOfDeletedVersions;
 
 			// if still not enough free space we rearrange the versions from all files
 			if ($availableSpace <= 0) {
-				$result = Storage::getAllVersions($uid);
+				$result = self::getAllVersions($uid);
 				$allVersions = $result['all'];
 
 				foreach ($result['by_file'] as $versions) {
-					list($toDeleteNew, $size) = self::getExpireList($time, $versions, $availableSpace <= 0);
+					[$toDeleteNew, $size] = self::getExpireList($time, $versions, $availableSpace <= 0);
 					$toDelete = array_merge($toDelete, $toDeleteNew);
 					$sizeOfDeletedVersions += $size;
 				}
@@ -787,11 +846,10 @@ class Storage {
 				$versionsSize = $versionsSize - $sizeOfDeletedVersions;
 			}
 
-			$logger = \OC::$server->getLogger();
-			foreach($toDelete as $key => $path) {
-				\OC_Hook::emit('\OCP\Versions', 'preDelete', array('path' => $path, 'trigger' => self::DELETE_TRIGGER_QUOTA_EXCEEDED));
+			foreach ($toDelete as $key => $path) {
+				\OC_Hook::emit('\OCP\Versions', 'preDelete', ['path' => $path, 'trigger' => self::DELETE_TRIGGER_QUOTA_EXCEEDED]);
 				self::deleteVersion($versionsFileview, $path);
-				\OC_Hook::emit('\OCP\Versions', 'delete', array('path' => $path, 'trigger' => self::DELETE_TRIGGER_QUOTA_EXCEEDED));
+				\OC_Hook::emit('\OCP\Versions', 'delete', ['path' => $path, 'trigger' => self::DELETE_TRIGGER_QUOTA_EXCEEDED]);
 				unset($allVersions[$key]); // update array with the versions we keep
 				$logger->info('Expire: ' . $path, ['app' => 'files_versions']);
 			}
@@ -799,17 +857,17 @@ class Storage {
 			// Check if enough space is available after versions are rearranged.
 			// If not we delete the oldest versions until we meet the size limit for versions,
 			// but always keep the two latest versions
-			$numOfVersions = count($allVersions) -2 ;
+			$numOfVersions = count($allVersions) - 2 ;
 			$i = 0;
 			// sort oldest first and make sure that we start at the first element
 			ksort($allVersions);
 			reset($allVersions);
 			while ($availableSpace < 0 && $i < $numOfVersions) {
 				$version = current($allVersions);
-				\OC_Hook::emit('\OCP\Versions', 'preDelete', array('path' => $version['path'].'.v'.$version['version'], 'trigger' => self::DELETE_TRIGGER_QUOTA_EXCEEDED));
+				\OC_Hook::emit('\OCP\Versions', 'preDelete', ['path' => $version['path'].'.v'.$version['version'], 'trigger' => self::DELETE_TRIGGER_QUOTA_EXCEEDED]);
 				self::deleteVersion($versionsFileview, $version['path'] . '.v' . $version['version']);
-				\OC_Hook::emit('\OCP\Versions', 'delete', array('path' => $version['path'].'.v'.$version['version'], 'trigger' => self::DELETE_TRIGGER_QUOTA_EXCEEDED));
-				\OC::$server->getLogger()->info('running out of space! Delete oldest version: ' . $version['path'].'.v'.$version['version'], ['app' => 'files_versions']);
+				\OC_Hook::emit('\OCP\Versions', 'delete', ['path' => $version['path'].'.v'.$version['version'], 'trigger' => self::DELETE_TRIGGER_QUOTA_EXCEEDED]);
+				$logger->info('running out of space! Delete oldest version: ' . $version['path'].'.v'.$version['version'], ['app' => 'files_versions']);
 				$versionsSize -= $version['size'];
 				$availableSpace += $version['size'];
 				next($allVersions);
@@ -846,11 +904,10 @@ class Storage {
 	 * Static workaround
 	 * @return Expiration
 	 */
-	protected static function getExpiration(){
-		if (is_null(self::$application)) {
-			self::$application = new Application();
+	protected static function getExpiration() {
+		if (self::$application === null) {
+			self::$application = \OC::$server->get(Application::class);
 		}
-		return self::$application->getContainer()->query(Expiration::class);
+		return self::$application->getContainer()->get(Expiration::class);
 	}
-
 }
