@@ -1,14 +1,13 @@
 OC.L10N.register(
     "settings",
     {
-    "Migration in progress. Please wait until the migration is finished" : "عملية الترحيل جارية. الرجاء الإنتظار حتى تكتمل العملية",
-    "Migration started …" : "بدأت عملية الترحيل …",
-    "Saved" : "حفظ",
-    "Not saved" : "لم يتم حفظه",
-    "Sending…" : "جارٍ الإرسال …",
-    "Email sent" : "تم ارسال البريد الالكتروني",
     "Private" : "خاص بك",
     "Local" : "المحلي",
+    "Only visible to people on this instance and guests" : "ظاهر فقط للمستخدمين والضيوف",
+    "Federated" : "المتحدة",
+    "Only synchronize to trusted servers" : "قم فقط بالمزامنة مع الخوادم الموثوقة",
+    "Published" : "نشرت",
+    "Synchronize to trusted servers and the global and public address book" : "قم بالمزامنة مع الخوادم الموثوقة ودفتر العناوين العالمية والعامة",
     "Verify" : "تحقق",
     "Verifying …" : "عملية التحقق جارية …",
     "Unable to change password" : "لا يمكن تغيير كلمة المرور",
@@ -17,10 +16,6 @@ OC.L10N.register(
     "So-so password" : "كلمة سر غير فعالة",
     "Good password" : "كلمة السر جيدة",
     "Strong password" : "كلمة السر قوية",
-    "An error occurred while changing your language. Please reload the page and try again." : "حدث خطأ أثناء تغيير إعدادات اللغة الخاصة بك. يرجى إعادة تحميل الصفحة والمحاوله مرة أخرى.",
-    "An error occurred while changing your locale. Please reload the page and try again." : "حدث خطأ أثناء تغيير الإعدادات المحلية الخاصة بك. يرجى إعادة تحميل الصفحة والمحاوله مرة أخرى.",
-    "Select a profile picture" : "اختر صورة الملف الشخصي ",
-    "Week starts on {fdow}" : "بداية الأسبوع يوم {fdow}",
     "Groups" : "مجموعات",
     "Group list is empty" : "قائمة المجموعة فارغة",
     "{actor} changed your password" : "{actor} قام بتغيير كلمتك السرية",
@@ -30,9 +25,8 @@ OC.L10N.register(
     "You changed your email address" : "لقد قمت بتعديل عنوان بريدك الإلكتروني",
     "Your email address was changed by an administrator" : "قام أحد المدراء بتغيير عنوان بريدك الإلكتروني",
     "Security" : "الأمان",
-    "Couldn't remove app." : "لم نتمكّن مِن حذف التطبيق.",
-    "Couldn't update app." : "تعذر تحديث التطبيق.",
     "Wrong password" : "كلمة مرور خاطئة",
+    "Saved" : "حفظ",
     "No user supplied" : "لم يتم توفير مستخدم ",
     "Authentication error" : "لم يتم التأكد من الشخصية بنجاح",
     "Wrong admin recovery password. Please check the password and try again." : "خطا في كلمة مرور المسؤول المستردة, يرجى التاكد من كلمة المرور والمحاولة مرة اخرى.",
@@ -41,6 +35,7 @@ OC.L10N.register(
     "Email setting test" : "تجريب إعدادات البريد الإلكتروني",
     "Well done, %s!" : "حسنًا فعلت، %s !",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "حدث خطأ أثناء إرسال البريد الإلكتروني. برجى مراجعة الاعدادات. (خطأ: %s)",
+    "Invalid user" : "مستخدم غير صالح",
     "Invalid mail address" : "عنوان البريد الإلكتروني خاطئ",
     "Settings saved" : "تم حفظ الإعدادات",
     "Unable to change full name" : "لم يتم التمكن من تغيير اسمك الكامل",
@@ -74,6 +69,8 @@ OC.L10N.register(
     "A background job is pending that checks for user imported SSL certificates. Please check back later." : "العمليات الخلفية قيد الانتظار يتم فحص شهادة الآمان SSL تمت اضافتها من المستخدم. يرجى المحاولة لاحقاً.",
     "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "يوجد مستخدم رفع شهادة آمان SSL حاليا، لا تستخدم حاليا مع Nextcloud 21. يمكن رفعها باستخدام سطر الامر عبر \"occ security:certificates:import\". داخل مجلد data كما هو موضح.",
     "None" : "لا شيء",
+    "Two-Factor Authentication" : "المصادقة بخطوتين",
+    "Limit to groups" : "التقيد إلى مجموعات",
     "Save changes" : "حفظ التعديلات",
     "All" : "الكل",
     "No results" : "دون أية نتيجة",
@@ -89,7 +86,7 @@ OC.L10N.register(
     "User documentation" : "دليل المستخدم",
     "Admin documentation" : "دليل المدير",
     "Developer documentation" : "دليل المُطوّر",
-    "Update all" : "تحديث الكل",
+    "Featured" : "مميزة",
     "Results from other categories" : "نتائج عبر الفئات الأخرى",
     "No apps found for your version" : "لا يمكن العثور على تطبيقات للإصدار الخاص بك.",
     "Disable all" : "تعطيل الكل",
@@ -119,14 +116,33 @@ OC.L10N.register(
     "Done" : "تم",
     "Copied!" : "تم نسخه !",
     "Copy" : "نسخ",
+    "Profile" : "الملف الشخصي",
+    "Enable" : "تفعيل",
+    "Server-side encryption" : "التشفير مِن جانب الخادوم",
+    "Enable server-side encryption" : "تشغيل التشفير مِن جانب الخادوم",
+    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "في حال تفعيل التشفير، عملية رفع الملف المشفر سيتم تفعيلها في الخادم. يمكن تعطيل التشفير في وقت لاحق فقط اذا كانت حزمة التشفير المفعلة تدعم التعطيل، وجميع الشروط الاخرى (على سبيل المثال اعداد رمز الاستعادة) مشمول ضمن الحزمة.",
+    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "التشفير لوحدها لا تضمن حماية النظام بشكل كامل. يرجى اتباع التعليمات لمزيد من المعلومات والحصول على معلومات عن عمل تطبيق التشفير، واستخداماته العديد.",
+    "Be aware that encryption always increases the file size." : "تنويه حجم الملفات يزيد دائما مع استخدام التشفير.",
+    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "من الجيد سحب نسخ احتياطية بشكل معتاد لبياناتك، في حال كنت مفعل خاصية التشفير تأكد دائما من حصولك على رمز التشفير بالإضافة الى البيانات.",
+    "This is the final warning: Do you really want to enable encryption?" : "هذا التحذير الاخير: هل تريد حقا تفعيل خاصية التشفير؟",
+    "No encryption module loaded, please enable an encryption module in the app menu." : "لم يتم تحميل حزمة التشفير، يرجى تفعيل حزمة التشفير من قائمة التطبيق.",
+    "Select default encryption module:" : "اختر حزمة التشفير الافتراضية:",
     "Remove group" : "حذف الفريق",
+    "Current password" : "كلمات السر الحالية",
+    "New password" : "كلمات سر جديدة",
+    "Change password" : "عدل كلمة السر",
+    "png or jpg, max. 20 MB" : "صيغة png أو jpg و حجم أقصاه 20 م.ب",
+    "Picture provided by original account" : "الصورة المستخدمة من الحساب الاصلي",
+    "Cancel" : "الغاء",
+    "Details" : "التفاصيل",
+    "You are a member of the following groups:" : "إنك عضو في الفِرَق التالية:",
     "Your email address" : "عنوانك البريدي",
     "No email address set" : "لم يتم إدخال أي عنوان للبريد الإلكتروني",
     "Language" : "اللغة",
     "Help translate" : "ساعد في الترجمة",
+    "Your phone number" : "رقم هاتفك",
     "Add" : "إضافة",
     "Delete user" : "احذف المستخدم",
-    "Cancel" : "الغاء",
     "Welcome mail sent!" : "تم إرسال بريد الترحيب!",
     "Edit User" : "تعديل المستخدم",
     "New user" : "مستخدم جديد",
@@ -145,22 +161,27 @@ OC.L10N.register(
     "Disabled apps" : "التطبيقات المعطلة",
     "Updates" : "التحديثات",
     "App bundles" : "حُزَم التطبيقات",
-    "Details" : "التفاصيل",
     "Changelog" : "سجل التغييرات",
     "Add group" : "إضافة فريق",
+    "Active users" : "المستخدمون النشطون",
     "Admins" : "المدراء",
     "Disabled users" : "المستخدمون المُعطَّلون",
     "Default quota:" : "الحصة الافتراضية:",
     "Show Languages" : "اعرض اللغات",
     "Show user backend" : "عرض مستخدم لوحة التحكم الرئيسية",
-    "Address" : "العنوان",
+    "Not saved" : "لم يتم حفظه",
+    "Sending…" : "جارٍ الإرسال …",
+    "Email sent" : "تم ارسال البريد الالكتروني",
+    "Location" : "الموقع",
+    "Profile picture" : "صورة الملف الشخصي",
+    "About" : "عن",
     "Full name" : "الإسم الكامل",
     "Phone number" : "رقم الهاتف",
+    "Role" : "الدور",
     "Twitter" : "تويتر",
     "Website" : "موقع الويب",
-    "Enable" : "تفعيل",
+    "Hide" : "إخفاء",
     "Never" : "أبدا",
-    "App update" : "تحديث التطبيق",
     "Administrator documentation" : "دليل المدير",
     "Documentation" : "الدليل",
     "Forum" : "منتدى",
@@ -184,26 +205,12 @@ OC.L10N.register(
     "Send email" : "إرسال بريد إلكتروني",
     "All checks passed." : "تم اجتياز جميع الاختبارات.",
     "Version" : "إصدار",
-    "Two-Factor Authentication" : "المصادقة بخطوتين",
-    "Server-side encryption" : "التشفير مِن جانب الخادوم",
-    "Enable server-side encryption" : "تشغيل التشفير مِن جانب الخادوم",
-    "Please read carefully before activating server-side encryption: " : "يرجى الاطلاع بعناية قبل تفعيل التشفير في الخادم.",
-    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "في حال تفعيل التشفير، عملية رفع الملف المشفر سيتم تفعيلها في الخادم. يمكن تعطيل التشفير في وقت لاحق فقط اذا كانت حزمة التشفير المفعلة تدعم التعطيل، وجميع الشروط الاخرى (على سبيل المثال اعداد رمز الاستعادة) مشمول ضمن الحزمة.",
-    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "التشفير لوحدها لا تضمن حماية النظام بشكل كامل. يرجى اتباع التعليمات لمزيد من المعلومات والحصول على معلومات عن عمل تطبيق التشفير، واستخداماته العديد.",
-    "Be aware that encryption always increases the file size." : "تنويه حجم الملفات يزيد دائما مع استخدام التشفير.",
-    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "من الجيد سحب نسخ احتياطية بشكل معتاد لبياناتك، في حال كنت مفعل خاصية التشفير تأكد دائما من حصولك على رمز التشفير بالإضافة الى البيانات.",
-    "This is the final warning: Do you really want to enable encryption?" : "هذا التحذير الاخير: هل تريد حقا تفعيل خاصية التشفير؟",
-    "Enable encryption" : "تنشيط التعمية",
-    "No encryption module loaded, please enable an encryption module in the app menu." : "لم يتم تحميل حزمة التشفير، يرجى تفعيل حزمة التشفير من قائمة التطبيق.",
-    "Select default encryption module:" : "اختر حزمة التشفير الافتراضية:",
-    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "يجب عليك دمج مفتاح التشفير من التشفير السابق (ownCloud <= 8.0) إلى الجديد. يرجى تفعيل \"حزمة التشفير الإفتراضية\" وبعدها استخدم امر التشفير التالي 'occ encryption:migrate'",
-    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "يجب عليك دمج مفتاح التشفير من التشفير السابق (ownCloud <= 8.0) إلى الجديد.",
-    "Start migration" : "إبدأ الدمج",
     "Allow apps to use the Share API" : "السماح للتطبيقات بالمشاركة عن طريق الAPI",
     "Enforce expiration date" : "فرض تاريخ نهاية صلاحية",
     "Allow public uploads" : "السماح بالرفع للعامة ",
     "Always ask for a password" : "أطلب دائما كلمة السر",
     "Enforce password protection" : "فرض الحماية بكلمة مرور",
+    "Set default expiration date" : "تعيين تاريخ إنتهاء الصلاحية الإفتراضية",
     "Allow resharing" : "السماح بإعادة المشاركة ",
     "Allow sharing with groups" : "السماح بالمشاركة مع المجموعات",
     "Restrict users to only share with users in their groups" : "سماح المستخدمين للمشاركة ضمن مجموعتهم فقط.",
@@ -213,38 +220,35 @@ OC.L10N.register(
     "Follow us on Twitter" : "تابعونا على تويتر",
     "Follow us on Mastodon" : "تابعونا على ماستدون",
     "Check out our blog" : "إلقي نظرة على مدوّنتنا",
-    "Profile picture" : "صورة الملف الشخصي",
+    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "إصدار المجتمع هذا من Nextcloud غير مدعوم والإشعارات الفورية غير متاحة.",
+    "Migration in progress. Please wait until the migration is finished" : "عملية الترحيل جارية. الرجاء الإنتظار حتى تكتمل العملية",
+    "Migration started …" : "بدأت عملية الترحيل …",
+    "An error occurred while changing your language. Please reload the page and try again." : "حدث خطأ أثناء تغيير إعدادات اللغة الخاصة بك. يرجى إعادة تحميل الصفحة والمحاوله مرة أخرى.",
+    "An error occurred while changing your locale. Please reload the page and try again." : "حدث خطأ أثناء تغيير الإعدادات المحلية الخاصة بك. يرجى إعادة تحميل الصفحة والمحاوله مرة أخرى.",
+    "Select a profile picture" : "اختر صورة الملف الشخصي ",
+    "Week starts on {fdow}" : "بداية الأسبوع يوم {fdow}",
+    "Couldn't remove app." : "لم نتمكّن مِن حذف التطبيق.",
+    "Couldn't update app." : "تعذر تحديث التطبيق.",
+    "All languages" : "كافة اللغات",
+    "Everyone" : "الجميع",
+    "Test email settings" : "فحص إعدادات البريد الإلكتروني",
+    "Please read carefully before activating server-side encryption: " : "يرجى الاطلاع بعناية قبل تفعيل التشفير في الخادم.",
+    "Enable encryption" : "تنشيط التعمية",
+    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "يجب عليك دمج مفتاح التشفير من التشفير السابق (ownCloud <= 8.0) إلى الجديد. يرجى تفعيل \"حزمة التشفير الإفتراضية\" وبعدها استخدم امر التشفير التالي 'occ encryption:migrate'",
+    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "يجب عليك دمج مفتاح التشفير من التشفير السابق (ownCloud <= 8.0) إلى الجديد.",
+    "Start migration" : "إبدأ الدمج",
+    "days" : "أيام",
     "Upload new" : "رفع الان",
     "Select from Files" : "إختر مِن بين الملفات",
     "Remove image" : "إزالة الصورة",
-    "png or jpg, max. 20 MB" : "صيغة png أو jpg و حجم أقصاه 20 م.ب",
-    "Picture provided by original account" : "الصورة المستخدمة من الحساب الاصلي",
     "Choose as profile picture" : "اختر صورة للملف الشخصي ",
-    "You are a member of the following groups:" : "إنك عضو في الفِرَق التالية:",
     "You are using <strong>%s</strong>" : "تستخدم حاليا <strong>%s</strong>",
     "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "تستخدم حاليا <strong>%1$s</strong> مِن أصل <strong>%2$s</strong> (<strong>%3$s %%</strong>)",
-    "Your phone number" : "رقم هاتفك",
+    "No display name set" : "لم يتم إدخال أي إسم",
+    "Address" : "العنوان",
     "Your postal address" : "عنوان البريد العادي",
     "Link https://…" : "الرابط https://…",
     "Twitter handle @…" : "حساب تويتر @…",
-    "Current password" : "كلمات السر الحالية",
-    "New password" : "كلمات سر جديدة",
-    "Change password" : "عدل كلمة السر",
-    "Public" : "عمومي",
-    "installing and updating apps via the app store or Federated Cloud Sharing" : "التثبيت والتحديث من متجر التطبيقات أو Federated Cloud Sharing",
-    "Nextcloud Android app" : "تطبيق Nextcloud للأندرويد",
-    "Nextcloud Talk for iOS" : "نيكست كلاود التحدث للايفون",
-    "Nextcloud Talk for Android" : "نيكست كلاود التحدث للاندرويد",
-    "Close" : "إغلاق",
-    "All languages" : "كافة اللغات",
-    "Everyone" : "الجميع",
-    "The app will be downloaded from the app store" : "سوف يتم تحميل التطبيق من متجر التطبيقات",
-    "mail" : "البريد",
-    "Test email settings" : "فحص إعدادات البريد الإلكتروني",
-    "Expire after " : "ينتهي بعد",
-    "days" : "أيام",
-    "Allow users to share via link" : "السماح للمستخدم بمشاركة الملف عن طريق رابط",
-    "No display name set" : "لم يتم إدخال أي إسم",
-    "For password reset and notifications" : "لإعادة تعيين كلمة السر و تلقي الإشعارات"
+    "Avatar" : "الصورة الرمزية"
 },
 "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
