@@ -1,12 +1,6 @@
 OC.L10N.register(
     "settings",
     {
-    "Migration in progress. Please wait until the migration is finished" : "Migraatio on kesken. Odota kunnes migraatio valmistuu",
-    "Migration started …" : "Migraatio käynnistyi…",
-    "Saved" : "Tallennettu",
-    "Not saved" : "Ei tallennettu",
-    "Sending…" : "Lähetetään…",
-    "Email sent" : "Sähköposti lähetetty",
     "Private" : "Yksityinen",
     "Local" : "Paikallinen",
     "Only visible to people on this instance and guests" : "Vain näkyvissä tämän instanssin ihmisille ja vieraille",
@@ -21,10 +15,6 @@ OC.L10N.register(
     "So-so password" : "Kohtalainen salasana",
     "Good password" : "Hyvä salasana",
     "Strong password" : "Vahva salasana",
-    "An error occurred while changing your language. Please reload the page and try again." : "Kieltä vaihtaessa tapahtui virhe. Päivitä sivu ja yritä uudelleen.",
-    "An error occurred while changing your locale. Please reload the page and try again." : "Maa-asetustoa vaihtaessa tapahtui virhe. Päivitä sivu ja yritä uudelleen.",
-    "Select a profile picture" : "Valitse profiilikuva",
-    "Week starts on {fdow}" : "Viikon ensimmäinen päivä on {fdow}",
     "Groups" : "Ryhmät",
     "Group list is empty" : "Ryhmälista on tyhjä",
     "Unable to retrieve the group list" : "Ryhmälistaa ei voitu noutaa",
@@ -47,6 +37,7 @@ OC.L10N.register(
     "You changed your email address" : "Muutit sähköpostiosoitteesi",
     "Your email address was changed by an administrator" : "Ylläpitäjä muutti sähköpostiosoitteesi",
     "You created app password \"{token}\"" : "Loit sovellussalasanan \"{token}\"",
+    "An administrator created app password \"{token}\"" : "Ylläpitäjä loi sovellussalasanan \"{token}\"",
     "You deleted app password \"{token}\"" : "Poistit sovellussalasanan \"{token}\"",
     "You renamed app password \"{token}\" to \"{newToken}\"" : "Nimesit sovellussalasanan \"{token}\" uudelleen muotoon \"{newToken}\"",
     "You granted filesystem access to app password \"{token}\"" : "Annoit pääsyn tiedostojärjestelmään sovellussalasanalle \"{token}\"",
@@ -57,14 +48,16 @@ OC.L10N.register(
     "Remote wipe was started on %1$s" : "Etätyhjennys aloitettiin %1$s",
     "Remote wipe has finished on %1$s" : "Etätyhjennys valmistui %1$s",
     "Your <strong>password</strong> or <strong>email</strong> was modified" : "<strong>Salasanaasi</strong> tai <strong>sähköpostiosoitettasi</strong> muokattiin",
-    "Couldn't remove app." : "Sovelluksen poistaminen epäonnistui.",
-    "Couldn't update app." : "Sovelluksen päivitys epäonnistui.",
+    "Could not remove app." : "Sovellusta ei voitu poistaa.",
+    "Could not update app." : "Sovellusta ei voitu päivittää.",
     "Wrong password" : "Väärä salasana",
+    "Unable to change personal password" : "Henkilökohtaista salasanaa ei voitu vaihtaa",
+    "Saved" : "Tallennettu",
     "No user supplied" : "Käyttäjää ei määritetty",
+    "Unable to change password. Password too long." : "Salasanaa ei voitu vaihtaa. Salasana on liian pitkä.",
     "Authentication error" : "Tunnistautumisvirhe",
     "Please provide an admin recovery password; otherwise, all user data will be lost." : "Anna ylläpitäjän palautussalasana; muuten kaikki käyttäjien data menetetään.",
     "Wrong admin recovery password. Please check the password and try again." : "Väärä ylläpitäjän salasana. Tarkista salasana ja yritä uudelleen.",
-    "Backend doesn't support password change, but the user's encryption key was updated." : "Taustaosa ei tue salasanan vaihtamista, mutta käyttäjän salausavain päivitettiin.",
     "Federated Cloud Sharing" : "Federoitu pilvijakaminen",
     "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL käyttää vanhentunutta %1$s versiota (%2$s). Päivitä käyttöjärjestelmäsi tai toiminnot, kuten %3$s, eivät toimi luotettavasti.",
     "Invalid SMTP password." : "Virheellinen SMTP-salasana.",
@@ -107,6 +100,7 @@ OC.L10N.register(
     "Personal" : "Henkilökohtainen",
     "Administration" : "Ylläpito",
     "Additional settings" : "Lisäasetukset",
+    "Administration privileges" : "Ylläpitäjän oikeudet",
     "Groupware" : "Groupware",
     "Overview" : "Yleiskuvaus",
     "Basic settings" : "Perusasetukset",
@@ -123,10 +117,12 @@ OC.L10N.register(
     "Unlimited" : "Rajoittamaton",
     "Verifying" : "Vahvistetaan",
     "The old server-side-encryption format is enabled. We recommend disabling this." : "Vanha palvelinpuolen salausmenetelmä on käytössä. Suosittelemme sen ottamista pois käytöstä.",
+    "Profile information" : "Profiilitiedot",
     "Nextcloud settings" : "Nextcloud-asetukset",
-    "Administration privileges" : "Ylläpitäjän oikeudet",
+    "Here you can decide which group can access certain sections of the administration settings." : "Tässä voit päättää, mitkä ryhmät voivat käyttää tiettyja osioita ylläpitäjän asetuksista.",
     "None" : "Ei mitään",
     "Unable to modify setting" : "Asetuksen muokkaaminen ei onnistu",
+    "Two-Factor Authentication" : "Kaksivaiheinen tunnistautuminen",
     "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Kaksivaiheinen tunnistautuminen voidaan pakottaa kaikille käyttäjille ja halutuille ryhmille. Mikäli heillä ei ole kaksivaiheista tunnistautumistapaa määriteltynä, he eivät pysty kirjautumaan järjestelmään.",
     "Enforce two-factor authentication" : "Pakota kaksivaiheinen tunnistautuminen",
     "Limit to groups" : "Rajoita ryhmiin",
@@ -157,12 +153,13 @@ OC.L10N.register(
     "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Esitellyt sovellukset on yhteisön itsensä kehitettämiä. Ne tarjoavat keskeisiä toimintoja ja ovat valmiita tuotantokäyttöön.",
     "Featured" : "Poiminta",
     "Update to {update}" : "Päivitä versioon {update}",
-    "Update all" : "Päivitä kaikki",
+    "All apps are up-to-date." : "Kaikki sovellukset ovat ajan tasalla.",
     "Results from other categories" : "Tulokset muista luokista",
     "No apps found for your version" : "Sovelluksia ei löytynyt versiollesi",
     "Disable all" : "Poista kaikki käytöstä",
     "Enable all" : "Ota kaikki käyttöön",
     "_%n app has an update available_::_%n apps have an update available_" : ["%n sovelluksella on päivitys saatavilla","%n sovelluksella on päivitys saatavilla"],
+    "_Update_::_Update all_" : ["Päivitä","Päivitä kaikki"],
     "Marked for remote wipe" : "Merkitty etätyhjennettäväksi",
     "Device settings" : "Laiteasetukset",
     "Allow filesystem access" : "Salli pääsy tiedostojärjestelmään",
@@ -177,8 +174,8 @@ OC.L10N.register(
     "Google Chrome for Android" : "Google Chrome Android-laitteelle",
     "iPhone" : "iPhone",
     "iPad" : "iPad",
-    "{productName} iOS app" : "{productName} iOS-sovellus",
-    "{productName} Android app" : "{productName} Android-sovellus",
+    "{productName} iOS app" : "{productName}in iOS-sovellus",
+    "{productName} Android app" : "{productName}in Android-sovellus",
     "{productName} Talk for iOS" : "{productName} Talk iOS:lle",
     "{productName} Talk for Android" : "{productName} Talk Androidille",
     "Sync client - {os}" : "Synkronointisovellus - {os}",
@@ -204,31 +201,81 @@ OC.L10N.register(
     "Copied!" : "Kopioitu!",
     "Copy" : "Kopioi",
     "Could not copy app password. Please copy it manually." : "Sovellussalasanaa ei voitu kopioida. Kopioi se manuaalisesti.",
+    "Cron (Recommended)" : "Cron (suositeltu)",
+    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Tämän suorittamiseksi tarvitset PHP:n POSIX-laajennuksen. Lue {linkstart}PHP:n dokumentaatio{linkend} saadaksesi lisätietoja.",
+    "Profile" : "Profiili",
+    "Enable or disable profile by default for new users." : "Käytä tai poista käytöstä profiili oletusarvoisesti uusille käyttäjille.",
+    "Enable" : "Käytä",
+    "Unable to update profile default setting" : "Profiilin oletusasetuksen päivittäminen ei onnistunut",
+    "Server-side encryption" : "Palvelinpään salaus",
+    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Palvelimelle ladatut tiedostot voidaan salata. Salaus aiheuttaa muun muassa palvelimen suorituskyvyn laskua, joten ota salaus käyttöön vain tarvittaessa.",
+    "Enable server-side encryption" : "Käytä palvelinpään salausta",
+    "Please read carefully before activating server-side encryption:" : "Lue tarkasti, ennen kuin otat palvelinpään salauksen käyttöön:",
+    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Kun salaus on otettu käyttöön, käyttöönoton jälkeen palvelimelle ladatut tiedostot salataan palvelimen ollessa lepotilassa. Salauksen ottaminen pois päältä myöhemmin on mahdollista vain, jos aktiivinen salausmoduuli tukee toiminta ja kaikki muut vaatimukset (kuten palautusavaimen asettaminen) täyttyvät.",
+    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Salaus sellaisenaan ei takaa järjestelmäsi turvallisuutta. Tutustu dokumentaation saadaksesi lisätietoja, miten salaussovellus toimii ja nähdäksesi tuettuja käyttötapauksia.",
+    "Be aware that encryption always increases the file size." : "Ota huomioon, että salaus kasvattaa aina tiedostojen kokoa.",
+    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Säännöllisten varmuuskopioiden ottaminen on erittäin tärkeää. Jos olet ottanut salauksen käyttöön, huolehdi salausavainten varmuuskopioinnista.",
+    "This is the final warning: Do you really want to enable encryption?" : "Tämä on viimeinen varoitus: haluatko varmasti ottaa salauksen käyttöön?",
+    "No encryption module loaded, please enable an encryption module in the app menu." : "Salausmoduulia ei ole käytössä. Ota salausmoduuli käyttöön sovellusvalikosta.",
+    "Select default encryption module:" : "Valitse oletuksena käytettävä salausmoduuli:",
+    "Rename group" : "Nimeä ryhmä uudelleen",
     "Remove group" : "Poista ryhmä",
     "You are about to remove the group {group}. The users will NOT be deleted." : "Olet aikeissa poistaa ryhmän {group}. Käyttäjiä EI poisteta!",
     "Please confirm the group removal " : "Vahvista ryhmän poistaminen",
+    "Current password" : "Nykyinen salasana",
+    "New password" : "Uusi salasana",
+    "Change password" : "Vaihda salasana",
+    "Your profile picture" : "Profiilikuvasi",
+    "Upload profile picture" : "Lähetä profiilikuva",
+    "Choose profile picture from files" : "Valitse profiilikuva tiedostoista",
+    "Remove profile picture" : "Poista profiilikuva",
+    "png or jpg, max. 20 MB" : "png tai jpg, korkeintaan 20 Mt",
+    "Picture provided by original account" : "Kuvan tarjoaa alkuperäinen tili",
+    "Cancel" : "Peru",
+    "Set as profile picture" : "Aseta profiilikuvaksi",
+    "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "Ota huomioon, että profiilikuvasi päivittyminen kaikkialle saattaa kestää jopa 24 tuntia.",
+    "Choose your profile picture" : "Valitse profiilikuva",
+    "Please select a valid png or jpg file" : "Valitse kelvollinen png- tai jpg-tiedosto",
+    "Error setting profile picture" : "Virhe profiilikuvaa asettaessa",
+    "Error cropping profile picture" : "Virhe profiilikuvaa rajatessa",
+    "Error saving profile picture" : "Virhe profiilikuvaa tallentaessa",
+    "Error removing profile picture" : "Virhe profiilikuvaa poistaessa",
+    "Your biography" : "Sinun elämäkertasi",
+    "Details" : "Yksityiskohdat",
+    "You are a member of the following groups:" : "Olet seuraavien ryhmien jäsen:",
+    "You are using <strong>{usage}</strong>" : "Käytössäsi on <strong>{usage}</strong>",
+    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Käytössäsi on <strong>{usage}</strong>/<strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
     "Your full name" : "Koko nimesi",
-    "Unable to update full name" : "Koko nimeä ei voi päivittää",
-    "No full name set" : "Koko nimeä ei ole asetettu",
     "Email options" : "Sähköpostiasetukset",
     "Primary email for password reset and notifications" : "Ensisijainen sähköposti salasanan nollaamista ja ilmoituksia varten",
     "Remove primary email" : "Poista ensisijainen sähköpostiosoite",
     "Delete email" : "Poista sähköposti",
+    "Unset as primary email" : "Poista ensisijaisesta sähköpostista",
     "This address is not confirmed" : "Tätä osoitetta ei ole vahvistettu",
     "Set as primary email" : "Aseta ensisijaiseksi sähköpostiosoitteeksi",
     "Your email address" : "Sähköpostiosoitteesi",
     "Additional email address {index}" : "Lisäsähköpostiosoite {index}",
+    "Unable to delete primary email address" : "Ensisijaista sähköpostiosoitetta ei voitu poistaa",
+    "Unable to update primary email address" : "Ensisijaista sähköpostiosoitetta ei voitu päivittää",
     "No email address set" : "Sähköpostiosoitetta ei ole asetettu",
+    "Additional emails" : "Muut sähköpostit",
+    "Your headline" : "Otsikkosi",
     "Language" : "Kieli",
     "Help translate" : "Auta kääntämisessä",
     "Unable to update language" : "Kieltä ei voi päivittää",
     "No language set" : "Kieltä ei ole asetettu",
+    "Locale" : "Aluekohtainen asetus",
+    "Week starts on {firstDayOfWeek}" : "Viikon ensimmäinen päivä on {firstDayOfWeek}",
+    "Unable to update locale" : "Maa-asetuston päivittäminen ei onnistu",
+    "No locale set" : "Maa-asetustoa ei ole asetettu",
+    "Your location" : "Sijaintisi",
     "Your organisation" : "Organisaatiosi",
-    "Unable to update organisation" : "Organisaatiota ei voi päivittää",
+    "Your phone number" : "Puhelinnumerosi",
     "Edit your Profile visibility" : "Muokkaa profiilisi näkyvyyttä",
     "Enable Profile" : "Käytä profiilia",
     "Your role" : "Roolisi",
-    "Unable to update role" : "Roolin päivittäminen ei onnistu",
+    "Your Twitter handle" : "Twitter-tunnuksesi",
+    "Your website" : "Verkkosivustosi",
     "Add" : "Lisää",
     "You do not have permissions to see the details of this user" : "Käyttöoikeutesi eivät riitä tämän käyttäjän tietojen näkemiseen",
     "Add new password" : "Lisää uusi salasana",
@@ -244,7 +291,6 @@ OC.L10N.register(
     "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Laitteen kadotessa tai organisaatiosta poistuessa voidaan käyttäjälle {userid} Nextcloudiin yhdistetyistä laitteista pyyhkiä  tiedot. Toimii vain laitteiden ollessa yhteydessä Internetiin.",
     "Remote wipe of devices" : "Laitteiden etätyhjennys",
     "Wipe {userid}'s devices" : "Tyhjennä käyttäjän {userid} laitteet",
-    "Cancel" : "Peru",
     "Fully delete {userid}'s account including all their personal files, app data, etc." : "Poista täysin käyttäjän {userid} tili mukaan lukien henkilökohtaiset tiedostot, sovellusten tiedot jne.",
     "Account deletion" : "Tilin poistaminen",
     "Delete {userid}'s account" : "Poista käyttäjän {userid} tili",
@@ -286,7 +332,6 @@ OC.L10N.register(
     "App bundles" : "Sovelluskokoelmat",
     "Featured apps" : "Esitellyt sovellukset",
     "{license}-licensed" : "{license}-lisensoitu",
-    "Details" : "Yksityiskohdat",
     "Changelog" : "Muutosloki",
     "by {author}\n{license}" : "tekijä {author}\n{license}",
     "Enter group name" : "Kirjoita ryhmän nimi",
@@ -301,12 +346,16 @@ OC.L10N.register(
     "Show user backend" : "Näytä käyttäjätaustaosa",
     "Show storage path" : "Näytä tallennustilan polku",
     "Send email to new user" : "Lähetä sähköpostia uudelle käyttäjälle",
-    "Address" : "Osoite",
+    "Not saved" : "Ei tallennettu",
+    "Sending…" : "Lähetetään…",
+    "Email sent" : "Sähköposti lähetetty",
+    "Location" : "Sijainti",
+    "Profile picture" : "Profiilikuva",
     "About" : "Tietoja",
     "Full name" : "Koko nimi",
+    "Headline" : "Otsikko",
     "Organisation" : "Organisaatio",
     "Phone number" : "Puhelinnumero",
-    "Profile" : "Profiili",
     "Role" : "Rooli",
     "Twitter" : "Twitter",
     "Website" : "Verkkosivusto",
@@ -315,14 +364,12 @@ OC.L10N.register(
     "Show to logged in users only" : "Näytä vain sisäänkirjautuneille käyttäjille",
     "Hide" : "Piilota",
     "Download and enable" : "Lataa ja ota käyttöön",
-    "Enable" : "Käytä",
     "Enable untested app" : "Ota käyttöön testaamaton sovellus",
     "The app will be downloaded from the App Store" : "Sovellus ladataan sovelluskaupasta",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Sovellusta ei ole merkattu yhteensopivaksi Nextcloud-versiosi kanssa. Voit kuitenkin jatkaa ja asentaa sovelluksen. Huomioi, että sovellus ei välttämättä toimi odotetusti.",
     "Never" : "Ei koskaan",
-    "An error occured during the request. Unable to proceed." : "Pyynnön aikana tapahtui virhe. Jatkaminen ei onnistu.",
+    "An error occurred during the request. Unable to proceed." : "Pyynnön aikana tapahtui virhe. Jatkaminen ei onnistu.",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Sovellus on käytössä, mutta se tulee päivittää. Sinut ohjataan sovelluksen päivityssivulle viiden sekunnin kuluttua.",
-    "App update" : "Sovelluspäivitys",
     "Error: This app cannot be enabled because it makes the server unstable" : "Virhe: Sovellusta ei voida ottaa käyttöön, koska se aiheuttaa palvelimen epävakauden",
     "Administrator documentation" : "Ylläpidon dokumentaatio",
     "Documentation" : "Dokumentaatio",
@@ -346,6 +393,7 @@ OC.L10N.register(
     "SMTP Username" : "SMTP-käyttäjätunnus",
     "SMTP Password" : "SMTP-salasana",
     "Save" : "Tallenna",
+    "Test and verify email settings" : "Testaa ja vahvista sähköpostiasetukset",
     "Send email" : "Lähetä sähköpostiviesti",
     "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Turvallisuuden ja suorituskyvyn vuoksi on tärkeää, että palvelimen asetukset ovat määritetty oikein. Apuna on joitain automaattisia tarkistuksia. Lue lisätietoja linkitetystä dokumentaatiosta.",
     "All checks passed." : "Läpäistiin kaikki tarkistukset.",
@@ -355,34 +403,6 @@ OC.L10N.register(
     "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Lue tarkkaan <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">asennusohjeet ↗</a>, ja tarkista virheet sekä varoitukset <a href=\"%2$s\">lokista</a>.",
     "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Tarkista Nextcloudisi turvallisuus käyttäen <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">tietoturvakartoitustamme ↗</a>.",
     "Version" : "Versio",
-    "Two-Factor Authentication" : "Kaksivaiheinen tunnistautuminen",
-    "Server-side encryption" : "Palvelinpään salaus",
-    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Palvelimelle ladatut tiedostot voidaan salata. Salaus aiheuttaa mm. palvelimen suorituskyvyn laskua, joten joten ota se käyttöön vain tarvittaessa.",
-    "Enable server-side encryption" : "Käytä palvelinpään salausta",
-    "Please read carefully before activating server-side encryption: " : "Lue tarkasti, ennen kuin otat palvelinpään salauksen käyttöön:",
-    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Kun salaus on otettu käyttöön, käyttöönoton jälkeen palvelimelle ladatut tiedostot salataan palvelimen ollessa lepotilassa. Salauksen ottaminen pois päältä myöhemmin on mahdollista vain, jos aktiivinen salausmoduuli tukee toiminta ja kaikki muut vaatimukset (kuten palautusavaimen asettaminen) täyttyvät.",
-    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Salaus sellaisenaan ei takaa järjestelmäsi turvallisuutta. Tutustu dokumentaation saadaksesi lisätietoja, miten salaussovellus toimii ja nähdäksesi tuettuja käyttötapauksia.",
-    "Be aware that encryption always increases the file size." : "Ota huomioon, että salaus kasvattaa aina tiedostojen kokoa.",
-    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Säännöllisten varmuuskopioiden ottaminen on erittäin tärkeää. Jos olet ottanut salauksen käyttöön, huolehdi salausavainten varmuuskopioinnista.",
-    "This is the final warning: Do you really want to enable encryption?" : "Tämä on viimeinen varoitus: haluatko varmasti ottaa salauksen käyttöön?",
-    "Enable encryption" : "Käytä salausta",
-    "No encryption module loaded, please enable an encryption module in the app menu." : "Salausmoduulia ei ole käytössä. Ota salausmoduuli käyttöön sovellusvalikosta.",
-    "Select default encryption module:" : "Valitse oletuksena käytettävä salausmoduuli:",
-    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Sinun täytyy siirtää salausavaimet vanhasta salaustekniikasta (ownCloud <= 8.0) uuteen. Ota \"Default encryption module\" käyttöön ja suorita komento 'occ encryption:migrate'",
-    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Sinun täytyy siirtää salausavaimet vanhasta salaustekniikasta (ownCloud <= 8.0) uuteen.",
-    "Start migration" : "Käynnistä migraatio",
-    "Last job execution ran %s. Something seems wrong." : "Viimeisin cron-työn suoritus %s. Jokin vaikuttaa menneen pieleen.",
-    "Some jobs haven’t been executed since %s. Please consider increasing the execution frequency." : "Jotkin tehtävät on suoritettu viimeksi %s jälkeen. Harkitse suoritustiheyden nopeuttamista.",
-    "Some jobs didn’t execute since %s. Please consider switching to system cron." : "Joidenkin tehtävien suoritukset ovat onnistuneet viimeksi %s. Harkitse vaihtoa järjestelmän cron-palveluun.",
-    "Last job ran %s." : "Viimeisin työ suoritettu %s.",
-    "Background job didn’t run yet!" : "Taustatyötä ei suoritettu vielä!",
-    "For optimal performance it's important to configure background jobs correctly. For bigger instances 'Cron' is the recommended setting. Please see the documentation for more information." : "Optimaalisen suorituskyvyn vuoksi on tärkeää määrittää taustatyöt oikein. Suuria asennuksia varten 'Cron' on suositeltava asetus. Lisätietoja on saatavilla dokumentaatiossa.",
-    "Pick background job setting" : "Valitse taustatyöasetus",
-    "Execute one task with each page loaded." : "Suorita tehtävä sivun latauksen yhteydessä.",
-    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP." : "Käytä ulkoista webcron-palvelua cron.php-skriptin suorittamiseen HTTP-protokollan kautta 5 minuutin välein. ",
-    "Use system cron service to call the cron.php file every 5 minutes." : "Käytä järjestelmän cron-palvelua cron.php-skriptin suorittamiseen 5 minuutin välein",
-    "The cron.php needs to be executed by the system user \"%s\"." : "Tiedosto cron.php tulee suorittaa järjestelmän käyttäjänä \"%s\".",
-    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Tämän suorittamiseksi tarvitset PHP:n POSIX-laajennuksen. Lue {linkstart}PHP:n dokumentaatio{linkend} saadaksesi lisätietoja.",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Ylläpitäjänä voit hienosäätää jakamista. Katso dokumentaatiosta lisätietoa.",
     "Allow apps to use the Share API" : "Salli sovellusten käyttää jakamisen ohjelmointirajapintaa",
     "Set default expiration date for shares" : "Aseta oletusarvoinen vanhenemispäivä jaoille",
@@ -390,6 +410,7 @@ OC.L10N.register(
     "day(s)" : "päivä(ä)",
     "Enforce expiration date" : "Pakota vanhenemispäivä",
     "Set default expiration date for shares to other servers" : "Aseta oletuspäivä muille palvelimille tehtyjen jakojen lopettamiselle",
+    "Allow users to share via link and emails" : "Salli käyttäjien jakaa linkkien ja sähköpostin kautta",
     "Allow public uploads" : "Salli julkiset lähetykset",
     "Always ask for a password" : "Kysy aina salasanaa",
     "Enforce password protection" : "Pakota salasanasuojaus",
@@ -410,19 +431,50 @@ OC.L10N.register(
     "Follow us on Mastodon" : "Seuraa meitä Mastodonissa",
     "Check out our blog" : "Lue blogia",
     "Subscribe to our newsletter" : "Tilaa uutiskirje",
-    "Profile picture" : "Profiilikuva",
+    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Tätä yhteisöjulkaisua Nextcloudista ei tueta, ja pikailmoitukset eivät ole saatavilla.",
+    "Use a second factor besides your password to increase security for your account." : "Käytä toista vaihetta salasanasi lisäksi parantaaksesi tilisi tietoturvaa.",
+    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Jos yhdistät kolmannen osapuolen ohjelmia Nextcloudiin, määritä niille sovellussalasanat ennen kaksiosaisen todentamismenetelmän käyttöönottoa.",
+    "Migration in progress. Please wait until the migration is finished" : "Migraatio on kesken. Odota kunnes migraatio valmistuu",
+    "Migration started …" : "Migraatio käynnistyi…",
+    "An error occurred while changing your language. Please reload the page and try again." : "Kieltä vaihtaessa tapahtui virhe. Päivitä sivu ja yritä uudelleen.",
+    "An error occurred while changing your locale. Please reload the page and try again." : "Maa-asetustoa vaihtaessa tapahtui virhe. Päivitä sivu ja yritä uudelleen.",
+    "Select a profile picture" : "Valitse profiilikuva",
+    "Week starts on {fdow}" : "Viikon ensimmäinen päivä on {fdow}",
+    "Couldn't remove app." : "Sovelluksen poistaminen epäonnistui.",
+    "Couldn't update app." : "Sovelluksen päivitys epäonnistui.",
+    "Backend doesn't support password change, but the user's encryption key was updated." : "Taustaosa ei tue salasanan vaihtamista, mutta käyttäjän salausavain päivitettiin.",
+    "You need to set your user email before being able to send test emails." : "Aseta sähköpostiosoite, jotta voit testata sähköpostin toimivuutta.",
+    "Set as primary mail" : "Aseta ensisijaiseksi sähköpostiosoitteeksi",
+    "Change privacy level of email" : "Muuta sähköpostin yksityisyystasoa",
+    "All languages" : "Kaikki kielet",
+    "Everyone" : "Kaikki",
+    "An error occured during the request. Unable to proceed." : "Pyynnön aikana tapahtui virhe. Jatkaminen ei onnistu.",
+    "Test email settings" : "Testaa sähköpostiasetukset",
+    "Please read carefully before activating server-side encryption: " : "Lue tarkasti, ennen kuin otat palvelinpään salauksen käyttöön:",
+    "Enable encryption" : "Käytä salausta",
+    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Sinun täytyy siirtää salausavaimet vanhasta salaustekniikasta (ownCloud <= 8.0) uuteen. Ota \"Default encryption module\" käyttöön ja suorita komento 'occ encryption:migrate'",
+    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Sinun täytyy siirtää salausavaimet vanhasta salaustekniikasta (ownCloud <= 8.0) uuteen.",
+    "Start migration" : "Käynnistä migraatio",
+    "Last job execution ran %s. Something seems wrong." : "Viimeisin cron-työn suoritus %s. Jokin vaikuttaa menneen pieleen.",
+    "Some jobs haven’t been executed since %s. Please consider increasing the execution frequency." : "Jotkin tehtävät on suoritettu viimeksi %s jälkeen. Harkitse suoritustiheyden nopeuttamista.",
+    "Some jobs didn’t execute since %s. Please consider switching to system cron." : "Joidenkin tehtävien suoritukset ovat onnistuneet viimeksi %s. Harkitse vaihtoa järjestelmän cron-palveluun.",
+    "Last job ran %s." : "Viimeisin työ suoritettu %s.",
+    "Background job didn’t run yet!" : "Taustatyötä ei suoritettu vielä!",
+    "Pick background job setting" : "Valitse taustatyöasetus",
+    "Recommended" : "Suositeltu",
+    "The cron.php needs to be executed by the system user \"%s\"." : "Tiedosto cron.php tulee suorittaa järjestelmän käyttäjänä \"%s\".",
+    "days" : "päivän jälkeen",
     "Change privacy level of profile picture" : "Muuta profiilikuvan yksityisyystasoa",
     "Upload new" : "Lähetä uusi",
     "Select from Files" : "Valitse tiedostosovelluksesta",
     "Remove image" : "Poista kuva",
-    "png or jpg, max. 20 MB" : "png tai jpg, korkeintaan 20 Mt",
-    "Picture provided by original account" : "Kuvan tarjoaa alkuperäinen tili",
     "Choose as profile picture" : "Valitse profiilikuvaksi",
-    "You are a member of the following groups:" : "Olet seuraavien ryhmien jäsen:",
     "You are using <strong>%s</strong>" : "Käytössäsi on <strong>%s</strong>",
     "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "Käytössäsi on <strong>%1$s</strong> / <strong>%2$s</strong> (<strong>%3$s %%</strong>)",
+    "Change privacy level of full name" : "Muuta koko nimen yksityisyystasoa",
+    "No display name set" : "Näyttönimeä ei ole asetettu",
     "Change privacy level of phone number" : "Muuta puhelinnumeron yksityisyystasoa",
-    "Your phone number" : "Puhelinnumerosi",
+    "Address" : "Osoite",
     "Change privacy level of address" : "Muuta osoitteen yksityisyystasoa",
     "Your postal address" : "Postiosoitteesi",
     "Change privacy level of website" : "Muuta verkkosivuston yksityisyystasoa",
@@ -430,39 +482,11 @@ OC.L10N.register(
     "Link https://…" : "Linkki https://…",
     "Change privacy level of Twitter profile" : "Muuta Twitter-tunnuksen yksityisyystasoa",
     "Twitter handle @…" : "Twitter-tunnus @…",
-    "Locale" : "Aluekohtainen asetus",
-    "Current password" : "Nykyinen salasana",
-    "New password" : "Uusi salasana",
-    "Change password" : "Vaihda salasana",
-    "Use a second factor besides your password to increase security for your account." : "Käytä toista vaihetta salasanasi lisäksi parantaaksesi tilisi tietoturvaa.",
-    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Jos yhdistät kolmannen osapuolen ohjelmia Nextcloudiin, määritä niille sovellussalasanat ennen kaksiosaisen todentamismenetelmän käyttöönottoa.",
-    "Don't synchronize to servers" : "Älä synkronoi palvelimille",
-    "Trusted" : "Luotettu",
-    "Public" : "Julkinen",
-    "installing and updating apps via the app store or Federated Cloud Sharing" : "Sovellusten asennus tai päivitys sovelluskaupasta tai federoidusta pilvijaosta",
-    "You need to set your user email before being able to send test emails." : "Aseta sähköpostiosoite, jotta voit testata sähköpostin toimivuutta.",
-    "Nextcloud iOS app" : "Nextcloudin iOS-sovellus",
-    "Nextcloud Android app" : "Nextcloudin Android-sovellus",
-    "Nextcloud Talk for iOS" : "Nextcloud Talk iOS:ille",
-    "Nextcloud Talk for Android" : "Nextcloud Talk Androidille",
-    "Add user in group" : "Lisää käyttäjä ryhmään",
-    "Close" : "Sulje",
-    "All languages" : "Kaikki kielet",
-    "Everyone" : "Kaikki",
-    "The app will be downloaded from the app store" : "Sovellus ladataan sovelluskaupasta",
-    "Error: This app can not be enabled because it makes the server unstable" : "Virhe: tätä sovellusta ei voi ottaa käyttöön, koska se tekee palvelimesta epävakaan",
-    "mail" : "posti",
-    "Test email settings" : "Testaa sähköpostiasetukset",
-    "Expire after " : "Vanhenna",
-    "days" : "päivän jälkeen",
-    "Allow users to share via link" : "Salli käyttäjien jakaa linkkien kautta",
-    "Set default expiration date for link shares" : "Aseta oletusarvoinen vanhenemispäivä linkkijaoille",
-    "Allow username autocompletion in share dialog (if this is disabled the full username or email address needs to be entered)" : "Salli käyttäjänimen automaattinen täydentäminen jakemisikkunassa (jos tämä on pois käytöstä, tulee koko käyttäjänimi tai sähköpostiosoite kirjoittaa)",
-    "Restrict username autocompletion to users within the same groups" : "Rajoita käyttäjänimen automaattista täydentämistä samoihin ryhmiin kuuluviin käyttäjiin",
-    "No display name set" : "Näyttönimeä ei ole asetettu",
-    "For password reset and notifications" : "Salasanan nollausta ja ilmoituksia varten",
-    "Change privacy level of full name" : "Muuta koko nimen yksityisyystasoa",
-    "Change privacy level of email" : "Muuta sähköpostin yksityisyystasoa",
-    "Set as primary mail" : "Aseta ensisijaiseksi sähköpostiosoitteeksi"
+    "Admin privileges" : "Ylläpitäjän oikeudet",
+    "Unable to update full name" : "Koko nimeä ei voi päivittää",
+    "No full name set" : "Koko nimeä ei ole asetettu",
+    "Unable to update organisation" : "Organisaatiota ei voi päivittää",
+    "Unable to update role" : "Roolin päivittäminen ei onnistu",
+    "Avatar" : "Profiilikuva"
 },
 "nplurals=2; plural=(n != 1);");
