@@ -1,14 +1,10 @@
 OC.L10N.register(
     "settings",
     {
-    "Migration in progress. Please wait until the migration is finished" : "Yfirfærsla er í gangi. Dokaðu við þar til henni er lokið",
-    "Migration started …" : "Yfirfærsla hafin...",
-    "Saved" : "Vistað",
-    "Not saved" : "Ekki vistað",
-    "Sending…" : "Sendi...",
-    "Email sent" : "Tölvupóstur sendur",
     "Private" : "Einka",
     "Local" : "Staðvært",
+    "Federated" : "Deilt milli þjóna (skýjasambandssameign)",
+    "Published" : "Útgefið",
     "Verify" : "Sannreyna",
     "Verifying …" : "Sannreyni …",
     "Unable to change password" : "Ekki tókst að breyta lykilorði",
@@ -17,10 +13,6 @@ OC.L10N.register(
     "So-so password" : "Svo-svo lykilorð",
     "Good password" : "Gott lykilorð",
     "Strong password" : "Sterkt lykilorð",
-    "An error occurred while changing your language. Please reload the page and try again." : "Villa kom upp við að skipta um tungumálið þitt. Endurlestu síðuna og prófaðu aftur.",
-    "An error occurred while changing your locale. Please reload the page and try again." : "Villa kom upp við að skipta um staðfærsluna þína. Endurlestu síðuna og prófaðu aftur.",
-    "Select a profile picture" : "Veldu einkennismynd",
-    "Week starts on {fdow}" : "Vika byrjar á {fdow}",
     "Groups" : "Hópar",
     "Group list is empty" : "Listi yfir hópa er tómur",
     "Unable to retrieve the group list" : "Tókst ekki að ná í lista yfir hópinn",
@@ -52,14 +44,12 @@ OC.L10N.register(
     "Remote wipe was started on %1$s" : "Fjartengd útþurrkun var hafin á %1$s",
     "Remote wipe has finished on %1$s" : "Fjartengdri útþurrkun er lokið á %1$s",
     "Your <strong>password</strong> or <strong>email</strong> was modified" : "Breyting hefur orðið á <strong>lykilorði</strong> eða <strong>tölvupóstfangi</strong> þínu",
-    "Couldn't remove app." : "Gat ekki fjarlægt forrit.",
-    "Couldn't update app." : "Gat ekki uppfært forrit.",
     "Wrong password" : "Rangt lykilorð",
+    "Saved" : "Vistað",
     "No user supplied" : "Enginn notandi gefinn",
     "Authentication error" : "Villa við auðkenningu",
     "Please provide an admin recovery password; otherwise, all user data will be lost." : "Settu inn endurheimtulykilorð kerfisstjóra, annars munu öll notandagögn tapast.",
     "Wrong admin recovery password. Please check the password and try again." : "Rangt endurheimtulykilorð kerfisstjóra, athugaðu lykilorðið og reyndu aftur.",
-    "Backend doesn't support password change, but the user's encryption key was updated." : "Bakendi styður ekki breytingu á lykilorði, en það tókst að uppfæra dulritunarlykil notandans.",
     "Federated Cloud Sharing" : "Deiling með skýjasambandi",
     "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL er að nota úrelda útgáfu af %1$s (%2$s). Uppfærðu stýrikerfið þitt, annars er hætt við að eiginleikar á borð við %3$s virki ekki sem skyldi.",
     "Invalid SMTP password." : "Ógilt SMTP-lykilorð",
@@ -68,6 +58,7 @@ OC.L10N.register(
     "If you received this email, the email configuration seems to be correct." : "Fyrst að þú fékkst þennan tölvupóst, þá lítur út fyrir að tölvupóstuppsetningin sé í lagi.",
     "Email could not be sent. Check your mail server log" : "Ekki var hægt að senda póst. Skoðaðu annál póstþjónsins",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Vandamál kom upp við að senda tölvupóst. Farðu yfir stillingarnar þínar. (Villa: %s)",
+    "Invalid user" : "Ógildur notandi",
     "Invalid mail address" : "Ógilt tölvupóstfang",
     "Settings saved" : "Stillingar vistaðar",
     "Unable to change full name" : "Get ekki breytt fullu nafni",
@@ -115,6 +106,7 @@ OC.L10N.register(
     "Verifying" : "Sannreyni",
     "Nextcloud settings" : "Stillingar Nextcloud",
     "None" : "Ekkert",
+    "Two-Factor Authentication" : "Tveggja-þrepa auðkenning",
     "Enforce two-factor authentication" : "Þvinga fram tveggja-þrepa auðkenningu",
     "Limit to groups" : "Takmarka við hópa",
     "Enforcement of two-factor authentication can be set for certain groups only." : "Hægt er að þvinga fram tveggja-þátta auðkenningu fyrir einungis ákveðna hópa.",
@@ -141,7 +133,6 @@ OC.L10N.register(
     "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Forrit í deiglunni eru þróuð af og innan samfélagsins. Þau bjóða upp á ýmsa kjarnaeiginleika og eru tilbúin til notkunar í raunvinnslu.",
     "Featured" : "Í deiglunni",
     "Update to {update}" : "Uppfæra í {update}",
-    "Update all" : "Uppfæra allt",
     "Results from other categories" : "Niðurstöður úr öðrum flokkum",
     "No apps found for your version" : "Engin forrit fundust fyrir útgáfuna þína",
     "Disable all" : "Gera allt óvirkt",
@@ -182,14 +173,40 @@ OC.L10N.register(
     "Copied!" : "Afritað!",
     "Copy" : "Afrita",
     "Could not copy app password. Please copy it manually." : "Tókst ekki að afrita lykilorð forritsins. Afritaðu það handvirkt.",
+    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Til að keyra þetta þarftu að hafa PHP-POSIX-viðaukann (extension). Skoðaðu {linkstart}PHP-hjálparskjölin{linkend} fyrir nánari útlistun.",
+    "Profile" : "Notandasnið",
+    "Enable" : "Virkja",
+    "Server-side encryption" : "Dulritun á þjóni",
+    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Dulritun á vefþjóni (server-side encryption) gerir kleift að dulrita skrár sem sendar eru inn á þennan þjón. Sá eiginleiki er ekki án áhrifa á afköst kerfisins, þannig að slíkt ætti ekki að virkja nema að vel yfirlögðu máli.",
+    "Enable server-side encryption" : "Virkja dulritun á þjóni",
+    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Þegar dulritun er virkjuð, munu frá þeim tímapunkti allar skrár sem sendar eru inn á þjóninn verða dulritaðar inni á honum. Einungis mun verða hægt að afvirkja dulritun síðar, ef virka dulritunareiningin styður þá aðgerð, og ef allar forsendur (t.d. að setja endurheimtulykil) eru uppfylltar.",
+    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Dulritun ein og sér tryggir ekki öryggi kerfisins. Endilega skoðaðu hjálparskjölin um hvernig dulritunarforritið virkar, og dæmi um hvaða uppsetningar eru studdar.",
+    "Be aware that encryption always increases the file size." : "Hafðu í huga að dulritun eykur alltaf skráastærð.",
+    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Það er góður siður að taka regluleg öryggisafrit af gögnunum þínum; ef um dulrituð gögn er að ræða, gakktu úr skugga um að einnig sé tekið öryggisafrit af dulritunarlyklum ásamt gögnunum.",
+    "This is the final warning: Do you really want to enable encryption?" : "Þetta er lokaaðvörun: Viltu örugglega virkja dulritun?",
+    "No encryption module loaded, please enable an encryption module in the app menu." : "Engin dulritunareining hlaðin inn, virkjaðu dulritunareiningu í valmynd forritsins.",
+    "Select default encryption module:" : "Veldu sjálfgefna dulritunareiningu:",
     "Remove group" : "Fjarlægja hóp",
     "You are about to remove the group {group}. The users will NOT be deleted." : "Þú er í þann mund að fara að fjarlægja hópinn {group}. Notendunum verður EKKI eytt.",
     "Please confirm the group removal " : "Staðfestu fjarlægingu hópsins",
+    "Current password" : "Núverandi lykilorð",
+    "New password" : "Nýtt lykilorð",
+    "Change password" : "Breyta lykilorði",
+    "png or jpg, max. 20 MB" : "png eða jpg, hám. 20 MB",
+    "Picture provided by original account" : "Mynd frá upprunalegum aðgangi",
+    "Cancel" : "Hætta við",
+    "Details" : "Nánar",
+    "You are a member of the following groups:" : "Þú ert meðlimur eftirfarandi hópa:",
+    "Delete email" : "Eyða tölvupósti",
     "Your email address" : "Netfangið þitt",
     "No email address set" : "Ekkert tölvupóstfang sett",
     "Language" : "Tungumál",
     "Help translate" : "Hjálpa við þýðingu",
     "No language set" : "Ekkert tungumál skilgreint",
+    "Locale" : "Staðfærsla",
+    "Your phone number" : "Símanúmerið þitt",
+    "Your Twitter handle" : "Twitter notandanafnið þitt",
+    "Your website" : "Vefsvæðið þitt",
     "Add" : "Bæta við",
     "You do not have permissions to see the details of this user" : "Þú hefur ekki réttindi til að skoða ítarupplýsingar um þennan notanda",
     "Set user as admin for" : "Setja notanda sem stjórnanda fyrir",
@@ -201,7 +218,6 @@ OC.L10N.register(
     "Resend welcome email" : "Endursenda kveðjupóst",
     "Remote wipe of devices" : "Fjartengd útþurrkun af tækjum",
     "Wipe {userid}'s devices" : "Þurrka út af tækjum {userid}",
-    "Cancel" : "Hætta við",
     "Account deletion" : "Eyðing á aðgangi",
     "Delete {userid}'s account" : "Eyða notandaaðgangi {userid}",
     "Welcome mail sent!" : "Kveðjupóstur sendur!",
@@ -230,15 +246,16 @@ OC.L10N.register(
     "Passwordless Authentication" : "Lykilorðalaus auðkenning",
     "Set up your account for passwordless authentication following the FIDO2 standard." : "Settu aðganginn þinn upp fyrir lykilorðalausa auðkenningu byggða á FIDO2-staðlinum.",
     "No devices configured." : "Engin tæki skilgreind.",
+    "Your browser does not support WebAuthn." : "Vafrinn þinn styður ekki WebAuthn.",
     "Your apps" : "Forritin þín",
     "Active apps" : "Virk forrit",
     "Disabled apps" : "Óvirk forrit",
     "Updates" : "Uppfærslur",
     "App bundles" : "Forritavöndlar",
     "{license}-licensed" : "{license}-notkunarleyfi",
-    "Details" : "Nánar",
     "Changelog" : "Breytingaskrá",
     "Add group" : "Bæta við hópi",
+    "Active users" : "Virkir notendur",
     "Admins" : "Kerfisstjórar",
     "Disabled users" : "Óvirkir notendur",
     "Default quota:" : "Sjálfgefinn kvóti:",
@@ -248,19 +265,24 @@ OC.L10N.register(
     "Show user backend" : "Birta bakenda notanda",
     "Show storage path" : "Birta slóð á gagnageymslu",
     "Send email to new user" : "Senda tölvupóst til nýs notanda",
-    "Address" : "Heimilisfang",
+    "Not saved" : "Ekki vistað",
+    "Sending…" : "Sendi...",
+    "Email sent" : "Tölvupóstur sendur",
+    "Location" : "Staðsetning",
+    "Profile picture" : "Einkennismynd",
+    "About" : "Um hugbúnaðinn",
     "Full name" : "Fullt nafn",
+    "Headline" : "Fyrirsögn",
     "Phone number" : "Símanúmer",
+    "Role" : "Role",
     "Twitter" : "Twitter",
     "Website" : "Vefsvæði",
+    "Hide" : "Fela",
     "Download and enable" : "Sækja og virkja",
-    "Enable" : "Virkja",
     "Enable untested app" : "Virkja óprófað forrit",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Þetta forrit er merkt sem ekki samhæft við þína útgáfu af Nextcloud. Ef þú heldur áfram er mögulegt að þú getir samt sett forritið upp. En athugaðu þá að ekki er víst að forritið virki eins og skyldi.",
     "Never" : "Aldrei",
-    "An error occured during the request. Unable to proceed." : "Villa kom upp við beiðnina. Get ekki haldið áfram.",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Forritið hefur verið virkjað, en það þarf að uppfæra það. Þú verður áframsendur á uppfærslusíðuna eftir 5 sekúndur.",
-    "App update" : "Endurnýjun forrits",
     "Administrator documentation" : "Hjálparskjöl stjórnanda",
     "Documentation" : "Hjálparskjöl",
     "Forum" : "Vefspjall",
@@ -292,37 +314,14 @@ OC.L10N.register(
     "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Yfirfarðu vandlega <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">uppsetningarleiðbeiningarnar ↗</a>, og athugaðu hvort nokkrar villumeldingar eða aðvaranir séu í <a href=\"%2$s\">annálnum</a>.",
     "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Athugaðu öryggi Nextcloud-skýsins með <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">öryggisskönnun okkar ↗</a>.",
     "Version" : "Útgáfa",
-    "Two-Factor Authentication" : "Tveggja-þrepa auðkenning",
-    "Server-side encryption" : "Dulritun á þjóni",
-    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Dulritun á vefþjóni (server-side encryption) gerir kleift að dulrita skrár sem sendar eru inn á þennan þjón. Sá eiginleiki er ekki án áhrifa á afköst kerfisins, þannig að slíkt ætti ekki að virkja nema að vel yfirlögðu máli.",
-    "Enable server-side encryption" : "Virkja dulritun á þjóni",
-    "Please read carefully before activating server-side encryption: " : "Lestu eftirfarandi gaumgæfilega áður en þú virkjar dulritun á þjóni: ",
-    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Þegar dulritun er virkjuð, munu frá þeim tímapunkti allar skrár sem sendar eru inn á þjóninn verða dulritaðar inni á honum. Einungis mun verða hægt að afvirkja dulritun síðar, ef virka dulritunareiningin styður þá aðgerð, og ef allar forsendur (t.d. að setja endurheimtulykil) eru uppfylltar.",
-    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Dulritun ein og sér tryggir ekki öryggi kerfisins. Endilega skoðaðu hjálparskjölin um hvernig dulritunarforritið virkar, og dæmi um hvaða uppsetningar eru studdar.",
-    "Be aware that encryption always increases the file size." : "Hafðu í huga að dulritun eykur alltaf skráastærð.",
-    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Það er góður siður að taka regluleg öryggisafrit af gögnunum þínum; ef um dulrituð gögn er að ræða, gakktu úr skugga um að einnig sé tekið öryggisafrit af dulritunarlyklum ásamt gögnunum.",
-    "This is the final warning: Do you really want to enable encryption?" : "Þetta er lokaaðvörun: Viltu örugglega virkja dulritun?",
-    "Enable encryption" : "Virkja dulritun",
-    "No encryption module loaded, please enable an encryption module in the app menu." : "Engin dulritunareining hlaðin inn, virkjaðu dulritunareiningu í valmynd forritsins.",
-    "Select default encryption module:" : "Veldu sjálfgefna dulritunareiningu:",
-    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Þú verður að yfirfæra dulritunarlyklana þína úr gömlu dulrituninni (ownCloud <= 8.0) yfir í þá nýju. Virkjaðu \"Sjálfgefna dulritunareiningu\" og keyrðu 'occ encryption:migrate'",
-    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Þú verður að yfirfæra dulritunarlyklana þína úr gömlu dulrituninni (ownCloud <= 8.0) yfir í þá nýju.",
-    "Start migration" : "Hefja yfirfærslu",
-    "Last job execution ran %s. Something seems wrong." : "Síðasta verk var keyrt %s. Eitthvað er ekki eins og það á að sér að vera.",
-    "Last job ran %s." : "Síðasta verk var keyrt %s.",
-    "Background job didn’t run yet!" : "Bakgrunnsverk hefur ekki ennþá verið keyrt!",
-    "For optimal performance it's important to configure background jobs correctly. For bigger instances 'Cron' is the recommended setting. Please see the documentation for more information." : "Til að ná bestum afköstum er mikilvægt að stilla bakgrunnsverk rétt. Fyrir stórar uppsetningar er mælt með því að nota 'cron' kerfisins. Skoðaðu hjálparskjölin til að sjá ítarlegar upplýsingar.",
-    "Pick background job setting" : "Veldu stillingu á bakgrunnsverki",
-    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP." : "cron.php er skráð á webcron-þjónustu til að kalla á cron.php á 5 mínútna fresti yfir HTTP.",
-    "Use system cron service to call the cron.php file every 5 minutes." : "Nota cron-þjónustu kerfisins til að kalla á cron.php skrána á 5 mínútna fresti.",
-    "The cron.php needs to be executed by the system user \"%s\"." : "cron.php verður að vera keyrt af kerfisnotandanum \"%s\".",
-    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Til að keyra þetta þarftu að hafa PHP-POSIX-viðaukann (extension). Skoðaðu {linkstart}PHP-hjálparskjölin{linkend} fyrir nánari útlistun.",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Sem stjórnandi geturðu fínstillt hegðun við deilingu. Endilega kíktu á hjálparskjölin til að sjá ítarlegri upplýsingar.",
     "Allow apps to use the Share API" : "Leyfa forritum að nota Share API",
+    "day(s)" : "dag(ar)",
     "Enforce expiration date" : "Krefjast dagsetningar á gildistíma",
     "Allow public uploads" : "Leyfa opinberar innsendingar",
     "Always ask for a password" : "Alltaf biðja um lykilorð",
     "Enforce password protection" : "Krefjast verndunar með aðgangsorði",
+    "Set default expiration date" : "Setja sjálfgefinn gildistíma",
     "Allow resharing" : "Leyfa endurdeilingu",
     "Allow sharing with groups" : "Leyfa deilingu með hópum",
     "Restrict users to only share with users in their groups" : "Takmarka notendur við að deila með notendum í þeirra eigin hópum",
@@ -336,46 +335,46 @@ OC.L10N.register(
     "Follow us on Mastodon" : "Fylgstu með okkur á Mastodon",
     "Check out our blog" : "Kíktu á bloggið okkar",
     "Subscribe to our newsletter" : "Gerstu áskrifandi að fréttabréfinu okkar",
-    "Profile picture" : "Einkennismynd",
+    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Þessi samfélagsútgáfa Nextcloud kemur ekki með neinni opinberri aðstoð og rauntímatilkynningar eru ekki til taks.",
+    "Use a second factor besides your password to increase security for your account." : "Notaðu annað þrep til viðbótar lykilorðinu þínu til að auka öryggi notandaaðgangsins þíns.",
+    "Migration in progress. Please wait until the migration is finished" : "Yfirfærsla er í gangi. Dokaðu við þar til henni er lokið",
+    "Migration started …" : "Yfirfærsla hafin...",
+    "An error occurred while changing your language. Please reload the page and try again." : "Villa kom upp við að skipta um tungumálið þitt. Endurlestu síðuna og prófaðu aftur.",
+    "An error occurred while changing your locale. Please reload the page and try again." : "Villa kom upp við að skipta um staðfærsluna þína. Endurlestu síðuna og prófaðu aftur.",
+    "Select a profile picture" : "Veldu einkennismynd",
+    "Week starts on {fdow}" : "Vika byrjar á {fdow}",
+    "Couldn't remove app." : "Gat ekki fjarlægt forrit.",
+    "Couldn't update app." : "Gat ekki uppfært forrit.",
+    "Backend doesn't support password change, but the user's encryption key was updated." : "Bakendi styður ekki breytingu á lykilorði, en það tókst að uppfæra dulritunarlykil notandans.",
+    "You need to set your user email before being able to send test emails." : "Þú verður að gefa upp netfangið þitt svo að þú getir sent prófunarpósta.",
+    "All languages" : "Öll tungumál",
+    "Everyone" : "Allir",
+    "An error occured during the request. Unable to proceed." : "Villa kom upp við beiðnina. Get ekki haldið áfram.",
+    "Test email settings" : "Prófa tölvupóststillingar",
+    "Please read carefully before activating server-side encryption: " : "Lestu eftirfarandi gaumgæfilega áður en þú virkjar dulritun á þjóni: ",
+    "Enable encryption" : "Virkja dulritun",
+    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Þú verður að yfirfæra dulritunarlyklana þína úr gömlu dulrituninni (ownCloud <= 8.0) yfir í þá nýju. Virkjaðu \"Sjálfgefna dulritunareiningu\" og keyrðu 'occ encryption:migrate'",
+    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Þú verður að yfirfæra dulritunarlyklana þína úr gömlu dulrituninni (ownCloud <= 8.0) yfir í þá nýju.",
+    "Start migration" : "Hefja yfirfærslu",
+    "Last job execution ran %s. Something seems wrong." : "Síðasta verk var keyrt %s. Eitthvað er ekki eins og það á að sér að vera.",
+    "Last job ran %s." : "Síðasta verk var keyrt %s.",
+    "Background job didn’t run yet!" : "Bakgrunnsverk hefur ekki ennþá verið keyrt!",
+    "Pick background job setting" : "Veldu stillingu á bakgrunnsverki",
+    "Recommended" : "Mælt með",
+    "The cron.php needs to be executed by the system user \"%s\"." : "cron.php verður að vera keyrt af kerfisnotandanum \"%s\".",
+    "days" : "daga",
     "Upload new" : "Senda inn nýtt",
     "Select from Files" : "Veldu skrár",
     "Remove image" : "Fjarlægja mynd",
-    "png or jpg, max. 20 MB" : "png eða jpg, hám. 20 MB",
-    "Picture provided by original account" : "Mynd frá upprunalegum aðgangi",
     "Choose as profile picture" : "Veldu sem einkennismynd",
-    "You are a member of the following groups:" : "Þú ert meðlimur eftirfarandi hópa:",
     "You are using <strong>%s</strong>" : "Þú ert að nota <strong>%s</strong>",
     "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "Þú ert að nota <strong>%1$s</strong> af <strong>%2$s</strong> (<strong>%3$s %%</strong>)",
-    "Your phone number" : "Símanúmerið þitt",
+    "No display name set" : "Ekkert birtingarnafn sett",
+    "Address" : "Heimilisfang",
     "Your postal address" : "Heimilisfangið þitt",
     "It can take up to 24 hours before the account is displayed as verified." : "Það getur tekið allt að 24 klukkustundum áður en notandaaðgangurinn er birtur sem sannvottaður.",
     "Link https://…" : "Tengill https://…",
     "Twitter handle @…" : "Twitter notandanafn @…",
-    "Locale" : "Staðfærsla",
-    "Current password" : "Núverandi lykilorð",
-    "New password" : "Nýtt lykilorð",
-    "Change password" : "Breyta lykilorði",
-    "Use a second factor besides your password to increase security for your account." : "Notaðu annað þrep til viðbótar lykilorðinu þínu til að auka öryggi notandaaðgangsins þíns.",
-    "Public" : "Opinbert",
-    "installing and updating apps via the app store or Federated Cloud Sharing" : "uppsetning eða uppfærsla forrita úr forritabúð eða með skýjasambandi",
-    "You need to set your user email before being able to send test emails." : "Þú verður að gefa upp netfangið þitt svo að þú getir sent prófunarpósta.",
-    "Nextcloud iOS app" : "Nextcloud iOS forrit",
-    "Nextcloud Android app" : "Nextcloud Android forrit",
-    "Nextcloud Talk for iOS" : "Nextcloud Talk fyrir iOS",
-    "Nextcloud Talk for Android" : "Nextcloud Talk fyrir Android",
-    "Add user in group" : "Bæta notanda í hóp",
-    "Close" : "Loka",
-    "All languages" : "Öll tungumál",
-    "Everyone" : "Allir",
-    "The app will be downloaded from the app store" : "Forritinu verður hlaðið niður úr forritabúðinni",
-    "Error: This app can not be enabled because it makes the server unstable" : "Villa: ekki er hægt að virkja þetta forrit því það gerir þjóninn óstöðugan.",
-    "mail" : "póstur",
-    "Test email settings" : "Prófa tölvupóststillingar",
-    "Expire after " : "Rennur út eftir ",
-    "days" : "daga",
-    "Allow users to share via link" : "Leyfa notendum að deila með tengli",
-    "Set default expiration date for link shares" : "Setja sjálfgefinn gildistíma fyrir sameignartengla",
-    "No display name set" : "Ekkert birtingarnafn sett",
-    "For password reset and notifications" : "Fyrir tilkynningar og endurstillingu lykilorðs"
+    "Avatar" : "Auðkennismynd"
 },
 "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
