@@ -1,14 +1,9 @@
 OC.L10N.register(
     "settings",
     {
-    "Migration in progress. Please wait until the migration is finished" : "მიმდინარეობს მიგრაცია. გთხოვთ დაელოდოთ მიგრაციის დასრულებას",
-    "Migration started …" : "მიგრაცია დაიწყო …",
-    "Saved" : "დამახსოვრდა",
-    "Not saved" : "არაა შენახული",
-    "Sending…" : "იგზავნება…",
-    "Email sent" : "ელ-წერილი გაიგზავნა",
     "Private" : "პირადი",
     "Local" : "ლოკალური",
+    "Federated" : "ფედერალური",
     "Verify" : "დამოწმება",
     "Verifying …" : "მოწმდება …",
     "Unable to change password" : "პაროლის ცვილება შეუძლებელია",
@@ -17,7 +12,6 @@ OC.L10N.register(
     "So-so password" : "ნორმალური პაროლი",
     "Good password" : "კარგი პაროლი",
     "Strong password" : "ძლიერი პაროლ",
-    "Select a profile picture" : "აირჩიეთ პროფილის სურათი",
     "Groups" : "ჯგუფები",
     "{actor} changed your password" : "{actor} მომხმარებელმა შეცვალა თქვენი პაროლი",
     "You changed your password" : "თქვენ შეცვალეთ თქვენი პაროლი",
@@ -29,14 +23,12 @@ OC.L10N.register(
     "You successfully logged in using two-factor authentication (%1$s)" : "თქვენ ორ-ფაქტორიანი აუტენტიფიკაციით წარმატებით გაიარეთ ავტორიზაცია (%1$s)",
     "A login attempt using two-factor authentication failed (%1$s)" : "ავტორიზაცია ორ-ფაქტორიანი აუტენტიფიკაციით ვერ მოხერხდა (%1$s)",
     "Your <strong>password</strong> or <strong>email</strong> was modified" : "<strong>თქვენი პაროლი</strong> ან <strong>ელ-ფოსტის მისამართი</strong> შეიცვალა",
-    "Couldn't remove app." : "აპლიკაციის წაშლა ვერ მოხერხდა.",
-    "Couldn't update app." : "აპლიკაციის განახლება ვერ მოხერხდა.",
     "Wrong password" : "არასწორი პაროლი",
+    "Saved" : "დამახსოვრდა",
     "No user supplied" : "მომხმარებელი არ იქნა მოწოდებული",
     "Authentication error" : "აუტენტიფიკაციის შეცდომა",
     "Please provide an admin recovery password; otherwise, all user data will be lost." : "გთხოვთ მოგვაწოდოთ ადმინისტრატორის აღდგენის პაროლი; სხვა შემთხვევაში ყველა მონაცემი დაიკარგება.",
     "Wrong admin recovery password. Please check the password and try again." : "ადმინისტრატორის აღდგენის არასწორი პაროლი. გთხოვთ გადაამოწმოთ პაროლი და სცადოთ ახლიდან.",
-    "Backend doesn't support password change, but the user's encryption key was updated." : "ბექენდს არ აქვს პაროლის ცვლილების მხარდაჭერა, თუმცა მომხმარებლის შიფრაციის გასაღები განახლდა.",
     "Federated Cloud Sharing" : "ფედერალური ქლაუდ გაზიარება",
     "Invalid SMTP password." : "არასწორი SMTP პაროლი.",
     "Email setting test" : "ელ-ფოსტის დაყენების შემოწმება",
@@ -44,6 +36,7 @@ OC.L10N.register(
     "If you received this email, the email configuration seems to be correct." : "იმ შემთხვევაში თუ მიიღეთ ეს ელ-წერილი, ელ-ფოსტის კონფიგურაცია კარგად უნდა იყოს.",
     "Email could not be sent. Check your mail server log" : "ელ-წერილი ვერ იგზავნება. გთხოვთ შეამოწმოთ მეილ-სერვერის ლოგი",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "ელ-წერილის გაგზავნისას წარმოიშვა შეცდომა. გთხოვთ გადახედოთ თქვენს პარამეტრებს. (შეცდომა: %s)",
+    "Invalid user" : "არასწორი მომხმარებელი",
     "Invalid mail address" : "არასწორი საფოსტო მისამართი",
     "Settings saved" : "პარამეტრები შენახულია",
     "Unable to change full name" : "სრული სახელის ცვლილება ვერ ხერხდება",
@@ -134,12 +127,33 @@ OC.L10N.register(
     "Done" : "დასრულებულია",
     "Copied!" : "კოპირებულია",
     "Copy" : "კოპირება",
+    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "ამის გასაშვებად საჭიროა გქონდეთ PHP POSIX გაფართოება. მეტი დეტალებისთვის იხილეთ {linkstart}PHP დოკუმენტაცია{linkend}. ",
+    "Enable" : "ჩართვა",
+    "Server-side encryption" : "სერვერული-მხარის შიფრაცია",
+    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "სერვერული-მხარის შიფრაცია იძლევა სერვერზე ატვირთული ფაილების შიფრაციის საშუალებას. ეს ფუნქცია ლიმიტს აწესებს მოქმედებაზე, ასე რომ გააქტიურედ მხოლოდ აუცილებლობისას.",
+    "Enable server-side encryption" : "სერვერული-მხარის შიფრაციის ამოქმედება",
+    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "შიფრაციის ჩართვის შემდეგ, სერვერზე ატვირთული ყველა ფაილი დაიშიფრება. იმ შემთხვევაში თუ აქტიური შიფრაციის მოდულს აქვს შიფრაციის დეაქტივაციის უნარი და ყველა წინაპირობა დაცულია (მაგ.: აღდგენის გასაღების დაყენება), სხვა დროს შეძლებთ მისი მოქმედების შეჩერებას.",
+    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "მხოლოდ შიფრაცია არ იძლევა სისტემის უსაფრთხოების გარანტიას. მეტი ინფორმაციისთვის იმაზე თუ როგორ მუშაობს შიფრაციის აპლიკაცია იხილეთ დოკუმენტაცია და გაეცანით მოხმარების შემთხვევებს.",
+    "Be aware that encryption always increases the file size." : "იცოდეთ, შიფრაცია ყოველთვის ზრდის ფაილის ზომას.",
+    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "ყოველთვის კარგია თქვენი მონაცემების დაზღვევა, შიფრაციის შემთხვევაში თვენს მონაცემებთან ერთად აუცილებლად დააზღვიეთ შიფრაციის გასაღებებიც.",
+    "This is the final warning: Do you really want to enable encryption?" : "ეს ბოლო გაფრთხილებაა: ნამდვილად გსურთ შიფრაციის ამოქმედება?",
+    "No encryption module loaded, please enable an encryption module in the app menu." : "შიფრაციის მოდული არაა ჩატვირთული, გთხოვთ აამოქმედოთ ის აპლიკაციის მენიუდან. ",
+    "Select default encryption module:" : "აირჩიეთ შიფრაციის საწყისი მოდული:",
+    "Current password" : "მიმდინარე პაროლი",
+    "New password" : "ახალი პაროლი",
+    "Change password" : "პაროლის შეცვლა",
+    "png or jpg, max. 20 MB" : "png ან jpg, მაქს. 20 მბ",
+    "Picture provided by original account" : "სურათი ორიგინალი ანგარიშიდან",
+    "Cancel" : "უარყოფა",
+    "Details" : "დეტალები",
     "Your email address" : "თქვენი ელ-ფოსტის მისამართი",
     "No email address set" : "ელ-ფოსტის მისამართი არაა დაყენებული",
     "Language" : "ენა",
     "Help translate" : "თარგმნის დახმარება",
+    "Your phone number" : "თქვენი ტელეფონის ნომერი",
+    "Your Twitter handle" : "თქვენი Twitter-is @…",
+    "Your website" : "თქვენი ვებ-საიტი",
     "Add" : "დამატება",
-    "Cancel" : "უარყოფა",
     "{size} used" : "მოხმარებულია {size}",
     "Display name" : "დისპლეი სახელი",
     "Email" : "ელ-ფოსტა",
@@ -154,22 +168,26 @@ OC.L10N.register(
     "Disabled apps" : "არამოქმედი აპლიკაციები",
     "Updates" : "განახლებები",
     "App bundles" : "აპლიკაციის შეკვრები",
-    "Details" : "დეტალები",
     "Changelog" : "ცვლილებების ლოგი",
     "Add group" : "ჯგუფის დამატება",
+    "Active users" : "აქტიური მომხმარებლები",
     "Admins" : "ადმინისტრატორები",
     "Show last login" : "ბოლო ავტორიზაციის ჩვენება",
     "Show user backend" : "მომხმარებლის ბექენდის ჩვენება",
     "Send email to new user" : "გაუგზავნეთ ელ-წერილი ახალ მომხმარებელს",
-    "Address" : "მისამართი",
+    "Not saved" : "არაა შენახული",
+    "Sending…" : "იგზავნება…",
+    "Email sent" : "ელ-წერილი გაიგზავნა",
+    "Location" : "ადგილმდებარეობა",
+    "Profile picture" : "პროფილის სურათი",
+    "About" : "შესახებ",
     "Full name" : "სრული სახელი",
     "Phone number" : "ტელეფონის ნომერი",
     "Twitter" : "Twitter-ი",
     "Website" : "ვებ-საიტი",
-    "Enable" : "ჩართვა",
+    "Hide" : "დამალვა",
     "Never" : "არასდროს",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "აპლიკაცია ამოქმედდა, თუმცა საჭიროებს განახლებას. 5 წამში გადამისამართდებით განახლების გვერდზე.",
-    "App update" : "აპლიკაციის განახლება",
     "Administrator documentation" : "ადმინისტრატორის დოკუმენტაცია",
     "Documentation" : "დოკუმენტაცია",
     "Forum" : "ფორუმი",
@@ -194,33 +212,13 @@ OC.L10N.register(
     "Send email" : "ელ-წერილის გაგზავნა",
     "All checks passed." : "ყველა შემოწმებამ ჩაიარა დადებითად.",
     "Version" : "ვერსია",
-    "Server-side encryption" : "სერვერული-მხარის შიფრაცია",
-    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "სერვერული-მხარის შიფრაცია იძლევა სერვერზე ატვირთული ფაილების შიფრაციის საშუალებას. ეს ფუნქცია ლიმიტს აწესებს მოქმედებაზე, ასე რომ გააქტიურედ მხოლოდ აუცილებლობისას.",
-    "Enable server-side encryption" : "სერვერული-მხარის შიფრაციის ამოქმედება",
-    "Please read carefully before activating server-side encryption: " : "სანამ გააქტიურებთ სერვერული-მხარის შიფრაციას გთხოვთ ყურადღებით გაეცნოთ:",
-    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "შიფრაციის ჩართვის შემდეგ, სერვერზე ატვირთული ყველა ფაილი დაიშიფრება. იმ შემთხვევაში თუ აქტიური შიფრაციის მოდულს აქვს შიფრაციის დეაქტივაციის უნარი და ყველა წინაპირობა დაცულია (მაგ.: აღდგენის გასაღების დაყენება), სხვა დროს შეძლებთ მისი მოქმედების შეჩერებას.",
-    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "მხოლოდ შიფრაცია არ იძლევა სისტემის უსაფრთხოების გარანტიას. მეტი ინფორმაციისთვის იმაზე თუ როგორ მუშაობს შიფრაციის აპლიკაცია იხილეთ დოკუმენტაცია და გაეცანით მოხმარების შემთხვევებს.",
-    "Be aware that encryption always increases the file size." : "იცოდეთ, შიფრაცია ყოველთვის ზრდის ფაილის ზომას.",
-    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "ყოველთვის კარგია თქვენი მონაცემების დაზღვევა, შიფრაციის შემთხვევაში თვენს მონაცემებთან ერთად აუცილებლად დააზღვიეთ შიფრაციის გასაღებებიც.",
-    "This is the final warning: Do you really want to enable encryption?" : "ეს ბოლო გაფრთხილებაა: ნამდვილად გსურთ შიფრაციის ამოქმედება?",
-    "Enable encryption" : "შიფრაციის ამოქმედება",
-    "No encryption module loaded, please enable an encryption module in the app menu." : "შიფრაციის მოდული არაა ჩატვირთული, გთხოვთ აამოქმედოთ ის აპლიკაციის მენიუდან. ",
-    "Select default encryption module:" : "აირჩიეთ შიფრაციის საწყისი მოდული:",
-    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "საჭიროა შიფრაციის გასაღებების მიგრაცია (ownCloud <= 8.0) ახალებზე. გთხოვთ აამოქმედოთ \"საწყისი მიგრაციის მოდული\" და გაუშვათ 'occ encryption:migrate'",
-    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "საჭიროა შიფრაციის ძველი გასაღებების მიგრაცია (ownCloud <= 8.0) ახალებზე.",
-    "Start migration" : "მიგრაციის დაწყება",
-    "Last job execution ran %s. Something seems wrong." : "ბოლო საქმე გაიშვა %s. რაღაც არასწორია.",
-    "Last job ran %s." : "ბოლო საქმის გაშვება - %s.",
-    "Background job didn’t run yet!" : "ფონური საქმე ჯერ არ გაშვებულა!",
-    "For optimal performance it's important to configure background jobs correctly. For bigger instances 'Cron' is the recommended setting. Please see the documentation for more information." : "ოპტიმალური მოღვაწეობისთვის მნიშვნელოვანია ფონური საქმეების სწორი კონფიგურაცია. დიდი ინსტანციებისთვის 'კრონი' რეკომენდირებული არჩევანია. გთხოვთ მეტი ინფორმაციისთვის იხილოთ დოკუმენტაცია.",
-    "The cron.php needs to be executed by the system user \"%s\"." : "cron.php უნდა გაუშვას სისტემურმა მოხმარებელმა \"%s\".",
-    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "ამის გასაშვებად საჭიროა გქონდეთ PHP POSIX გაფართოება. მეტი დეტალებისთვის იხილეთ {linkstart}PHP დოკუმენტაცია{linkend}. ",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "როგორც ადმინისტრატორს შეგიძლიათ გაზიარების ქცევის კორექტირება. დამატებითი ინფორმაციისთვის იხილეთ დოკუმენტაცია.",
     "Allow apps to use the Share API" : "დაუშვი აპლიკაციების უფლება  Share API –ზე",
     "Enforce expiration date" : "ვადის ამოწურვის თარიღის იძულება",
     "Allow public uploads" : "საქვეყნო ატვირთების დაშვება",
     "Always ask for a password" : "ყოველთვის მოხდეს პაროლის მოთხოვნა",
     "Enforce password protection" : "პროლით დაცვის იძულება",
+    "Set default expiration date" : "დააყენეთ საწყისი ვადის ამოწურვის თარიღი",
     "Allow resharing" : "ხელახალი გაზიარების დაშვება",
     "Allow sharing with groups" : "ჯგუფებთან გაზიარების მხარდაჭერა",
     "Restrict users to only share with users in their groups" : "შეზღუდეთ მომხმარებლები გააზიარონ მომხმარებლებთან, რომლებიც მიეკუთვნებიან მათ ჯგუფებს",
@@ -233,35 +231,36 @@ OC.L10N.register(
     "Follow us on Twitter" : "გამოგვყევით Twitter-ზე",
     "Check out our blog" : "იხილეთ ჩვენი ბლოგი",
     "Subscribe to our newsletter" : "გამოიწერეთ ჩვენი სიახლეები",
-    "Profile picture" : "პროფილის სურათი",
+    "Migration in progress. Please wait until the migration is finished" : "მიმდინარეობს მიგრაცია. გთხოვთ დაელოდოთ მიგრაციის დასრულებას",
+    "Migration started …" : "მიგრაცია დაიწყო …",
+    "Select a profile picture" : "აირჩიეთ პროფილის სურათი",
+    "Couldn't remove app." : "აპლიკაციის წაშლა ვერ მოხერხდა.",
+    "Couldn't update app." : "აპლიკაციის განახლება ვერ მოხერხდა.",
+    "Backend doesn't support password change, but the user's encryption key was updated." : "ბექენდს არ აქვს პაროლის ცვლილების მხარდაჭერა, თუმცა მომხმარებლის შიფრაციის გასაღები განახლდა.",
+    "You need to set your user email before being able to send test emails." : "შემოწმების წერილების გაგზავნამდე, უნდა დააყენოთ თქვენი მომხმარებლის ელ-ფოსტა.",
+    "All languages" : "ყველა ენა",
+    "Everyone" : "ყველა",
+    "Test email settings" : "ელ-ფოსტის პარამეტრების შემომება",
+    "Please read carefully before activating server-side encryption: " : "სანამ გააქტიურებთ სერვერული-მხარის შიფრაციას გთხოვთ ყურადღებით გაეცნოთ:",
+    "Enable encryption" : "შიფრაციის ამოქმედება",
+    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "საჭიროა შიფრაციის გასაღებების მიგრაცია (ownCloud <= 8.0) ახალებზე. გთხოვთ აამოქმედოთ \"საწყისი მიგრაციის მოდული\" და გაუშვათ 'occ encryption:migrate'",
+    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "საჭიროა შიფრაციის ძველი გასაღებების მიგრაცია (ownCloud <= 8.0) ახალებზე.",
+    "Start migration" : "მიგრაციის დაწყება",
+    "Last job execution ran %s. Something seems wrong." : "ბოლო საქმე გაიშვა %s. რაღაც არასწორია.",
+    "Last job ran %s." : "ბოლო საქმის გაშვება - %s.",
+    "Background job didn’t run yet!" : "ფონური საქმე ჯერ არ გაშვებულა!",
+    "The cron.php needs to be executed by the system user \"%s\"." : "cron.php უნდა გაუშვას სისტემურმა მოხმარებელმა \"%s\".",
+    "days" : "დღე",
     "Upload new" : "ახალი ატვირთვა",
     "Select from Files" : "აირჩიეთ ფაილებიდან",
     "Remove image" : "სურათის წაშლა",
-    "png or jpg, max. 20 MB" : "png ან jpg, მაქს. 20 მბ",
-    "Picture provided by original account" : "სურათი ორიგინალი ანგარიშიდან",
     "Choose as profile picture" : "აირჩიეთ პროფილის სურათად",
-    "Your phone number" : "თქვენი ტელეფონის ნომერი",
+    "No display name set" : "დისპლეი სახელი არაა დაყენებული",
+    "Address" : "მისამართი",
     "Your postal address" : "თქვენი საფოსტო მისამართი",
     "It can take up to 24 hours before the account is displayed as verified." : "თქვენი ანგარიშის ვერიფიცირებულად გამოჩენამ შეიძლება გასტანოს 24 საათი.",
     "Link https://…" : "ბმული https://…",
     "Twitter handle @…" : "Twitter @…",
-    "Current password" : "მიმდინარე პაროლი",
-    "New password" : "ახალი პაროლი",
-    "Change password" : "პაროლის შეცვლა",
-    "Public" : "ღია",
-    "installing and updating apps via the app store or Federated Cloud Sharing" : "აპლიკაციების app store-იდან დაყენება და განახლება ან ფედერალური ქლაუდ გაზიარება",
-    "You need to set your user email before being able to send test emails." : "შემოწმების წერილების გაგზავნამდე, უნდა დააყენოთ თქვენი მომხმარებლის ელ-ფოსტა.",
-    "Close" : "დახურვა",
-    "All languages" : "ყველა ენა",
-    "Everyone" : "ყველა",
-    "The app will be downloaded from the app store" : "აპლიკაცია გადმოწერილ იქნება app store-იდან",
-    "Error: This app can not be enabled because it makes the server unstable" : "შეცდომა: ეს აპლიკაცია ვერ მოქმედდება რადგანაც სერვერს ხდის არასტაბილურს",
-    "mail" : "წერილი",
-    "Test email settings" : "ელ-ფოსტის პარამეტრების შემომება",
-    "Expire after " : "ვადის ამოწურვა",
-    "days" : "დღე",
-    "Allow users to share via link" : "მიეცით მოხმარებლებს ბმულით გაზიარების უფლება",
-    "No display name set" : "დისპლეი სახელი არაა დაყენებული",
-    "For password reset and notifications" : "პაროლის აღდგენისთვის და შეტყობინებებისთვის"
+    "Avatar" : "ავატარი"
 },
 "nplurals=2; plural=(n!=1);");
