@@ -1,12 +1,6 @@
 OC.L10N.register(
     "settings",
     {
-    "Migration in progress. Please wait until the migration is finished" : "正在進行遷移。請等候遷移結束",
-    "Migration started …" : "開始遷移……",
-    "Saved" : "已儲存",
-    "Not saved" : "未儲存",
-    "Sending…" : "正在傳送……",
-    "Email sent" : "電子郵件已寄出",
     "Private" : "私人",
     "Only visible to people matched via phone number integration through Talk on mobile" : "僅對透過 Talk 在手提電話上通過電話號碼整合進行匹配的人可見",
     "Local" : "近端",
@@ -23,10 +17,6 @@ OC.L10N.register(
     "So-so password" : "密碼強度普通",
     "Good password" : "密碼強度佳",
     "Strong password" : "密碼強度極佳",
-    "An error occurred while changing your language. Please reload the page and try again." : "變更語言時發生錯誤，請重新整理頁面後重試",
-    "An error occurred while changing your locale. Please reload the page and try again." : "變更慣用地區時發生錯誤，請重新整理頁面後重試",
-    "Select a profile picture" : "選擇個人檔案圖片",
-    "Week starts on {fdow}" : "日曆週從{fdow}開始",
     "Groups" : "群組",
     "Group list is empty" : "群組列表為空",
     "Unable to retrieve the group list" : "無法擷取群組列表",
@@ -49,6 +39,7 @@ OC.L10N.register(
     "You changed your email address" : "您已更改您的電郵地址",
     "Your email address was changed by an administrator" : "管理員已更改您的電郵地址",
     "You created app password \"{token}\"" : "您建立了應用程式密碼「{token}」",
+    "An administrator created app password \"{token}\"" : "管理員建立了應用程式密碼「{token}」",
     "You deleted app password \"{token}\"" : "您刪除了應用程式密碼「{token}」",
     "You renamed app password \"{token}\" to \"{newToken}\"" : "您已將應用程式密碼「{token}」重新命名為「{newToken}」",
     "You granted filesystem access to app password \"{token}\"" : "您授予了應用程式密碼「{token}」檔案系統的存取權限",
@@ -59,18 +50,29 @@ OC.L10N.register(
     "Remote wipe was started on %1$s" : "遠端抹除已開始於 %1$s",
     "Remote wipe has finished on %1$s" : "遠端抹除已結束於 %1$s",
     "Your <strong>password</strong> or <strong>email</strong> was modified" : "您的<strong>密碼</strong>或<strong>電子郵件</strong>已修改",
-    "Couldn't remove app." : "無法移除應用程式。",
-    "Couldn't update app." : "無法更新應用程式。",
+    "Could not remove app." : "無法移除應用程式。",
+    "Could not update app." : "無法更新應用程式。",
     "Wrong password" : "密碼錯誤",
+    "Unable to change personal password" : "無法更改個人密碼",
+    "Saved" : "已儲存",
     "No user supplied" : "未提供用戶",
+    "Unable to change password. Password too long." : "密碼太長，無法更改。",
     "Authentication error" : "認證錯誤",
     "Please provide an admin recovery password; otherwise, all user data will be lost." : "請提供管理員還原密碼；否則所有用戶資料將會遺失。",
     "Wrong admin recovery password. Please check the password and try again." : "錯誤的管理員還原密碼。請檢查密碼並再試一次。",
-    "Backend doesn't support password change, but the user's encryption key was updated." : "後端不支援變更密碼，但用戶加密密鑰已更新。",
+    "Backend does not support password change, but the user's encryption key was updated." : "後端系統不支援密碼變更，但用戶加密密鑰已更新。",
     "installing and updating apps via the App Store or Federated Cloud Sharing" : "透過 App Store 或是聯盟式雲端分享來安裝、更新應用程式",
     "Federated Cloud Sharing" : "聯盟式雲端分享",
     "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL 使用的版本 %1$s 過舊（%2$s）。請更新您的作業系統，否則如 %3$s 等功能可能無法正常運作。",
-    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the nextcloud log file for more details." : "對於 https://nextcloud.com 的 HTTPS 請求發生錯誤，因此無法確定 cURL 的 TLS 是否過舊。請檢查 nextcloud 的紀錄檔以取得更多資訊。",
+    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the Nextcloud log file for more details." : "對於 https://nextcloud.com 的 HTTPS 請求發生錯誤，因此無法確定 cURL 的 TLS 版本是否過舊。請檢查 Nextcloud 的紀錄檔案以取得更多資訊。",
+    "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "未加載 PHP OPcache 模塊。為獲得更佳性能，建議將其加載到您的 PHP 安裝中。",
+    "OPcache is disabled. For better performance, it is recommended to apply <code>opcache.enable=1</code> to your PHP configuration." : "已停用 OPcache。要得到更好的效能，建議在您的 PHP 設定中套用 <code>opcache.enable=1</code>。",
+    "OPcache is configured to remove code comments. With OPcache enabled, <code>opcache.save_comments=1</code> must be set for Nextcloud to function." : "OPcache 被設定為移除程式碼註釋。啟用 OPcache 後，必須設定 <code>opcache.save_comments=1</code> 才能讓 Nextcloud 正常運作。",
+    "Nextcloud is not allowed to use the OPcache API. With OPcache enabled, it is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud 不被允許使用 OPcache API。啟用 OPcache 後，強烈建議使用 <code>opcache.restrict_api</code> 包含所有 Nextcloud 目錄，或是關閉此設定以停用 OPcache API 限制，以避免在 Nextcloud 核心或應用程式升級期間發生錯誤。",
+    "Nextcloud is not allowed to use the OPcache API. It is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud 不被允許使用 OPcache API。強烈建議使用 <code>opcache.restrict_api</code> 包含所有 Nextcloud 目錄，或是關閉此設定以停用 OPcache API 限制，以避免在 Nextcloud 核心或應用程式升級期間發生錯誤。",
+    "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be kept in the cache, it is recommended to apply <code>opcache.max_accelerated_files</code> to your PHP configuration with a value higher than <code>%s</code>." : "幾乎超過了可用的 OPcache 密鑰的最大數量。為確保所有腳本都可以保存在緩存中，建議將 <code>opcache.max_accelerated_files</code> 應用於您的 PHP 配置，其值高於 <code>%s</code>。",
+    "The OPcache buffer is nearly full. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.memory_consumption</code> to your PHP configuration with a value higher than <code>%s</code>." : "OPcache 緩衝區幾乎快滿了。為確保所有指令稿都可以保留在快取中，建議在您的 PHP 設定中的 <code>opcache.memory_consumption</code> 套用高於 <code>%s</code> 的值。",
+    "The OPcache interned strings buffer is nearly full. To assure that repeating strings can be effectively cached, it is recommended to apply <code>opcache.interned_strings_buffer</code> to your PHP configuration with a value higher than <code>%s</code>." : "OPcache 內部字串緩衝區幾乎快滿了。為確保可以有效快取重複字串，建議在您的 PHP 設定中的 <code>opcache.interned_strings_buffer</code> 套用高於 <code>%s</code> 的值。",
     "Invalid SMTP password." : "無效的 SMTP 密碼",
     "Email setting test" : "測試郵件設定",
     "Well done, %s!" : "太棒了，%s！",
@@ -114,7 +116,7 @@ OC.L10N.register(
     "Personal" : "個人",
     "Administration" : "管理",
     "Additional settings" : "其他設定",
-    "Admin privileges" : "管理員權限",
+    "Administration privileges" : "管理員權限",
     "Groupware" : "協作應用程式",
     "Overview" : "概覽",
     "Basic settings" : "基本設定",
@@ -134,14 +136,16 @@ OC.L10N.register(
     "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "存在一些用戶匯入的SSL證書，這些在Nextcloud 21中不再使用。可以通過“ occ security:certificates:import”命令在命令行上將其導入。它們在數據目錄中的路徑如下所示。",
     "Invalid UUIDs of LDAP users or groups have been found. Please review your \"Override UUID detection\" settings in the Expert part of the LDAP configuration and use \"occ ldap:update-uuid\" to update them." : "LDAP 用戶或群組的 UUID 無效。請查看 LDAP 配置專家部分中的“覆蓋 UUID 檢測”設置，並使用“occ ldap:update-uuid”更新它們。",
     "The old server-side-encryption format is enabled. We recommend disabling this." : "啟用了舊的伺服器端加密格式。我們建議停用它。",
-    "MariaDB version \"%s\" is used. Nextcloud 21 will no longer support this version and requires MariaDB 10.2 or higher." : "正在使用 MariaDB 版本「%s」。Nextcloud 21 不再支援此版本，並需要 MariaDB 10.2 或更新版本。",
-    "MySQL version \"%s\" is used. Nextcloud 21 will no longer support this version and requires MySQL 8.0 or MariaDB 10.2 or higher." : "正在使用 MySQL 版本「%s」。Nextcloud 21 不再支援此版本，並需要 MySQL 8.0、MariaDB 10.2 或更新版本。",
-    "PostgreSQL version \"%s\" is used. Nextcloud 21 will no longer support this version and requires PostgreSQL 9.6 or higher." : "正在使用 PostgreSQL 版本「%s」。Nextcloud 21 不再支援此版本，並需要 PostgreSQL 9.6 或更新版本。",
+    "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher." : "正在使用 MariaDB 版本「%s」。Nextcloud 21 及更新版本不再支援此版本，並需要 MariaDB 10.2 或更新版本。",
+    "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher." : "正在使用 MySQL 版本「%s」。Nextcloud 21 及更新版本不再支援此版本，並需要 MySQL 8.0 或 MariaDB 10.2 或更新版本。",
+    "PostgreSQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require PostgreSQL 9.6 or higher." : "正在使用 PostgreSQL 版本「%s」。Nextcloud 21 及更新版本不再支援此版本，並需要 PostgreSQL 9.6 或更新版本。",
+    "Profile information" : "簡介資訊",
+    "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "個人資料圖片、全名、電郵地址、電話號碼、地址、網站、Twitter、組織、角色、標題、傳記以及您的個人資料是否已啟用",
     "Nextcloud settings" : "Nextcloud 設定",
-    "Administration privileges" : "管理員權限",
     "Here you can decide which group can access certain sections of the administration settings." : "您可以在此決定哪個群組可以存取哪些管理設定。",
     "None" : "無",
     "Unable to modify setting" : "無法修改設定",
+    "Two-Factor Authentication" : "雙重認證",
     "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "可對所有用戶與特定群組實施雙重認證。如果他們沒有設定雙重認證提供者，那麼他們就會無法登入系統。",
     "Enforce two-factor authentication" : "強制雙重認證",
     "Limit to groups" : "限制給特定群組",
@@ -172,13 +176,13 @@ OC.L10N.register(
     "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "精選應用程式是由社群開發的。它們提供了相當重要的功能，並已準備好在正式環境使用。",
     "Featured" : "精選",
     "Update to {update}" : "更新到 {update}",
-    "Update all" : "更新全部",
     "All apps are up-to-date." : "所有應用程式都是最新的。",
     "Results from other categories" : "其他分類的結果",
     "No apps found for your version" : "沒有找到適合您的版本的應用程式",
     "Disable all" : "全部停用",
     "Enable all" : "全部啟用",
     "_%n app has an update available_::_%n apps have an update available_" : ["%n 個應用程式有可用的更新"],
+    "_Update_::_Update all_" : ["更新全部"],
     "Marked for remote wipe" : "標記為可遠端抹除",
     "Device settings" : "裝置設定",
     "Allow filesystem access" : "允許檔案系統的存取",
@@ -222,16 +226,65 @@ OC.L10N.register(
     "Copied!" : "已複製！",
     "Copy" : "複製",
     "Could not copy app password. Please copy it manually." : "無法複製應用程式密碼。請手動複製。",
+    "For the server to work properly, it's important to configure background jobs correctly. Cron is the recommended setting. Please see the documentation for more information." : "為了讓伺服器正確運作，正確設定後台作業非常重要。建議使用 \"Cron\" 為設定。請查閱說明文件以獲得更多資訊。",
+    "Last job execution ran {time}. Something seems wrong." : "上次執行作業的時間是 {time}。似乎有些不對勁。",
+    "Last job ran {relativeTime}." : "上次執行作業的時間是 {relativeTime}。",
+    "Background job did not run yet!" : "後台作業從未執行！",
+    "AJAX" : "AJAX",
+    "Execute one task with each page loaded. Use case: Single user instance." : "每個頁面載入時執行一次任務。使用情境：單使用者站台。",
+    "Webcron" : "Webcron",
+    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage)." : "cron.php 註冊了一個 webcron 服務，該服務將通過 HTTP 每 5 分鐘執行一次 cron.php。 用例：非常小的實例（1-5 個用戶，具體取決於使用情況）。",
+    "Cron (Recommended)" : "Cron（推薦）",
+    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "要執行這個，您需要 PHP POSIX 擴充元件。請查閱 {linkstart}PHP 說明文件{linkend} 以取得更多資訊。",
+    "Use system cron service to call the cron.php file every 5 minutes. Recommended for all instances." : "使用系統 cron 服務每 5 分鐘調用一次 cron.php。 推薦用於所有實例。",
+    "The cron.php needs to be executed by the system user \"{user}\"." : "cron.php 必須由系統用戶「{user}」執行。",
+    "Unable to update background job mode" : "無法更新後台作業模式",
+    "Profile" : "個人設定",
+    "Enable or disable profile by default for new users." : "默認情況下為新用戶啟用或停用個人檔案。",
+    "Enable" : "啟用",
+    "Unable to update profile default setting" : "無法更新個人檔案默認設定。",
+    "Server-side encryption" : "伺服器端加密",
+    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "伺服器端加密可以加密所有上傳到此伺服器的檔案，但這會讓檔案操作時間增加，降低效能，請審慎評估後再啟用。",
+    "Enable server-side encryption" : "啟用伺服器端加密",
+    "Please read carefully before activating server-side encryption:" : "在您啟動伺服器端加密之前，請仔細閱讀：",
+    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "一旦啟用加密，從那時開始上傳到伺服器的檔案都會被加密，若日後要停用加密，需要作用中加密模組的支援，而且所有的設定（例如：還原金鑰）都正確。",
+    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "單獨加密不能保證系統安全性。請參考加密應用程式運作原理，及支援的使用案例的文件，以取得更多資訊。",
+    "Be aware that encryption always increases the file size." : "請注意，加密一定會增加檔案的大小。",
+    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "定時備份您的資料沒有壞處，若您有啟用加密，請確保您也有備份加密金鑰。",
+    "This is the final warning: Do you really want to enable encryption?" : "這是最後的警告：請問您真的要開啟加密模式？",
+    "No encryption module loaded, please enable an encryption module in the app menu." : "沒有載入加密模組，請您在應用程式選單中啟用加密模組",
+    "Select default encryption module:" : "選擇預設的加密模組：",
+    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}" : "您必須將您的加密密鑰從舊的加密（ownCloud <= 8.0）遷移到新的。請啟用「預設加密模組」並執行 {command}",
+    "Unable to update server side encryption config" : "無法更新伺服器端加密配置",
     "Rename group" : "重新命名群組",
     "Remove group" : "移除群組",
     "You are about to remove the group {group}. The users will NOT be deleted." : "您將要移除群組 {group}。用戶將不會被刪除。",
     "Please confirm the group removal " : "請確認移除群組",
+    "Current password" : "目前密碼",
+    "New password" : "新密碼",
+    "Change password" : "更改密碼",
+    "Your profile picture" : "您的個人資料圖片",
+    "Upload profile picture" : "上傳個人資料圖片",
+    "Choose profile picture from files" : "從檔案選擇個人資料圖片",
+    "Remove profile picture" : "移除個人資料圖片",
+    "png or jpg, max. 20 MB" : "png 或 jpg，最大 20 MB",
+    "Picture provided by original account" : "原始賬戶提供的圖片",
+    "Cancel" : "取消",
+    "Set as profile picture" : "設定為個人資料圖片",
+    "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "請注意，您的個人資料圖片最長可能需要24小時才能在所有地方更新。",
+    "Choose your profile picture" : "選擇您的個人資料圖片",
+    "Please select a valid png or jpg file" : "請選擇有效的 png 或 jpg 檔案",
+    "Error setting profile picture" : "設定個人資料圖片時出錯",
+    "Error cropping profile picture" : "裁剪個人資料圖片時出錯",
+    "Error saving profile picture" : "儲存個人資料圖片時出錯",
+    "Error removing profile picture" : "移除個人資料圖片時出錯",
     "Your biography" : "個人小傳",
-    "Unable to update biography" : "無法更新小傳",
+    "Details" : "詳細資訊",
+    "You are a member of the following groups:" : "你是下列群組的成員︰",
+    "You are using <strong>{usage}</strong>" : "您已使用了 <strong>{usage}</strong> 的存儲空間",
+    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "您已使用了 <strong>{totalSpace}</strong> 中的 <strong>{usage}</strong>（<strong>{usageRelative} %</strong>）",
     "Your full name" : "您的全名",
-    "Unable to update full name" : "無法更新全名",
-    "No full name set" : "未設定全名",
-    "Email options" : "電郵地址選項",
+    "Email options" : "電子郵件通知選項",
     "Primary email for password reset and notifications" : "用於密碼重設和通告信件的主要電郵地址",
     "Remove primary email" : "刪除主要電郵地址",
     "Delete email" : "刪除電郵地址",
@@ -248,13 +301,17 @@ OC.L10N.register(
     "No email address set" : "未設定電郵地址",
     "Additional emails" : "其他電郵地址",
     "Your headline" : "您的標題",
-    "Unable to update headline" : "無法更新標題",
     "Language" : "語言",
     "Help translate" : "協助翻譯",
     "Unable to update language" : "無法更新語言",
     "No language set" : "未設定語言",
+    "Locale" : "地區設定",
+    "Week starts on {firstDayOfWeek}" : "一星期從 {firstDayOfWeek} 開始",
+    "Unable to update locale" : "無法更新語言場景",
+    "No locale set" : "沒有設置語言場景",
+    "Your location" : "您的位置",
     "Your organisation" : "您的機構",
-    "Unable to update organisation" : "無法更新機構",
+    "Your phone number" : "您的電話號碼",
     "Edit your Profile visibility" : "編輯個人檔案能見度",
     "Enable Profile" : "啟用簡介",
     "Unable to update profile enabled state" : "無法更新個人資料啟用狀態",
@@ -262,11 +319,15 @@ OC.L10N.register(
     "{displayId}" : "{displayId}",
     "Unable to update visibility of {displayId}" : "無法更新 {displayId} 的可見性",
     "Your role" : "你的角色",
-    "Unable to update role" : "無法更新角色",
+    "Your Twitter handle" : "您的 Twitter 帳號",
+    "Your website" : "您的網站",
+    "No {property} set" : "沒有設置 {property} ",
+    "Unable to update {property}" : "無法更新 (property)",
+    "Change scope level of {property}, current scope is {scope}" : "更改 {property} 的範圍級別，當前範圍為 {scope}",
+    "Unable to update federation scope of the primary {property}" : "無法更新主要 {property} 的聯盟範圍",
+    "Unable to update federation scope of additional {property}" : "無法更新額外 {property} 的聯盟範圍",
+    "Add additional email" : "添加額外電郵地址",
     "Add" : "新增",
-    "Change scope level of {accountProperty}" : "更改 {accountProperty} 的範圍",
-    "Unable to update federation scope of the primary {accountProperty}" : "無法更新主要 {accountProperty} 的聯盟範圍",
-    "Unable to update federation scope of additional {accountProperty}" : "無法更新額外 {accountProperty} 的聯盟範圍",
     "You do not have permissions to see the details of this user" : "您沒有檢視此用戶詳細資料的權限",
     "Add new password" : "新增密碼",
     "Add new email address" : "新增電郵地址",
@@ -281,7 +342,6 @@ OC.L10N.register(
     "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "如果遺失裝置或退出組織，這可以從與 {userid} 相關的所有裝置遠端抹除 Nextcloud 資料。僅當裝置連線到網際網路時才有效。",
     "Remote wipe of devices" : "遠端抹除裝置",
     "Wipe {userid}'s devices" : "抹除 {userid} 的裝置",
-    "Cancel" : "取消",
     "Fully delete {userid}'s account including all their personal files, app data, etc." : "完全刪除 {userid} 的賬戶，包含他們所有的個人檔案、應用程式資料等等。",
     "Account deletion" : "賬戶刪除",
     "Delete {userid}'s account" : "刪除 {userid} 的賬戶",
@@ -325,7 +385,6 @@ OC.L10N.register(
     "App bundles" : "應用程式套裝",
     "Featured apps" : "精選應用程式",
     "{license}-licensed" : "以 {license} 授權",
-    "Details" : "詳細資訊",
     "Changelog" : "軟件更新紀錄",
     "by {author}\n{license}" : "作者為 {author}\n{license}",
     "Enter group name" : "輸入群組名稱",
@@ -340,15 +399,17 @@ OC.L10N.register(
     "Show user backend" : "顯示用戶資料後端",
     "Show storage path" : "顯示儲存路徑",
     "Send email to new user" : "傳送電子郵件給新用戶",
-    "Address" : "地址",
-    "Avatar" : "頭像",
+    "Not saved" : "未儲存",
+    "Sending…" : "正在傳送……",
+    "Email sent" : "電子郵件已寄出",
+    "Location" : "位置",
+    "Profile picture" : "個人資料圖片",
     "About" : "關於",
     "Full name" : "全名",
     "Additional email" : "附加電郵地址",
     "Headline" : "標題",
     "Organisation" : "機構",
     "Phone number" : "電話號碼",
-    "Profile" : "個人設定",
     "Role" : "角色",
     "Twitter" : "Twitter",
     "Website" : "網站",
@@ -359,14 +420,12 @@ OC.L10N.register(
     "Show to logged in users only" : "僅顯示給登錄用戶",
     "Hide" : "隱藏",
     "Download and enable" : "下載並啟用",
-    "Enable" : "啟用",
     "Enable untested app" : "啟用未經測試的應用程式",
     "The app will be downloaded from the App Store" : "將會從 App Store 下載這個應用程式",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "此應用程式未被標記為與您的 Nextcloud 版本相容。如果繼續，您仍可安裝應用程式。但請注意應用程式可能無法正常運作。",
     "Never" : "絕不",
-    "An error occured during the request. Unable to proceed." : "請求時發生錯誤。無法繼續。",
+    "An error occurred during the request. Unable to proceed." : "請求時發生錯誤。無法繼續。",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "應用程式已啟用但是需要更新。您將會在5秒內被重新導向至更新頁面。",
-    "App update" : "應用程式更新",
     "Error: This app cannot be enabled because it makes the server unstable" : "錯誤：此應用程序無法啟用，因為它造成伺服器不穩定",
     "Administrator documentation" : "管理員使用手冊",
     "Documentation" : "使用手冊",
@@ -377,7 +436,7 @@ OC.L10N.register(
     "SSL/TLS" : "SSL/TLS",
     "STARTTLS" : "STARTTLS",
     "Open documentation" : "開啟使用手冊",
-    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "設置此伺服器以使其能夠發送電郵以進行密碼重置，通知等。",
+    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "設置此伺服器以使其能夠發送電郵以進行密碼重置﹑通知等。",
     "Send mode" : "傳送模式",
     "Encryption" : "加密",
     "Sendmail mode" : "Sendmail 模式",
@@ -400,34 +459,6 @@ OC.L10N.register(
     "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "請再次確認<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">安裝手冊 ↗</a>，並在<a href=\"%2$s\">紀錄檔</a>中檢查是否有任何錯誤或警告。",
     "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "透過<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">我們的安全性掃描 ↗</a>檢查您 Nextcloud 的安全性。",
     "Version" : "版本",
-    "Two-Factor Authentication" : "雙重認證",
-    "Server-side encryption" : "伺服器端加密",
-    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "伺服器端加密可以加密所有上傳到此伺服器的檔案，但這會讓檔案操作時間增加，降低效能，請審慎評估後再啟用。",
-    "Enable server-side encryption" : "啟用伺服器端加密",
-    "Please read carefully before activating server-side encryption: " : "在您啟動伺服器端加密之前，請仔細閱讀：",
-    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "一旦啟用加密，從那時開始上傳到伺服器的檔案都會被加密，若日後要停用加密，需要作用中加密模組的支援，而且所有的設定（例如：還原金鑰）都正確。",
-    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "單獨加密不能保證系統安全性。請參考加密應用程式運作原理，及支援的使用案例的文件，以取得更多資訊。",
-    "Be aware that encryption always increases the file size." : "請注意，加密一定會增加檔案的大小。",
-    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "定時備份您的資料沒有壞處，若您有啟用加密，請確保您也有備份加密金鑰。",
-    "This is the final warning: Do you really want to enable encryption?" : "這是最後的警告：請問您真的要開啟加密模式？",
-    "Enable encryption" : "啟用加密",
-    "No encryption module loaded, please enable an encryption module in the app menu." : "沒有載入加密模組，請您在應用程式選單中啟用加密模組",
-    "Select default encryption module:" : "選擇預設的加密模組：",
-    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "您必須將您的加密密鑰從舊的加密（ownCloud <= 8.0）遷移到新的。請啟用「預設加密模組」並執行 'occ encryption：migrate'",
-    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "您必須將您的加密密鑰從舊的加密（ownCloud <= 8.0）遷移到新的。",
-    "Start migration" : "開始遷移",
-    "Last job execution ran %s. Something seems wrong." : "上次後台作業執行於 %s。似乎有點問題。",
-    "Some jobs haven’t been executed since %s. Please consider increasing the execution frequency." : "從 %s 開始，有一些工作未執行。請考慮增加執行頻率。",
-    "Some jobs didn’t execute since %s. Please consider switching to system cron." : "從 %s 開始，有一些工作未執行。請考慮切換為系統 cron。",
-    "Last job ran %s." : "上次後台作業執行於 %s",
-    "Background job didn’t run yet!" : "後台作業從未執行！",
-    "For optimal performance it's important to configure background jobs correctly. For bigger instances 'Cron' is the recommended setting. Please see the documentation for more information." : "為了獲得最佳的效能，設定後台作業非常重要，對於比較大的服務來說，建議使用 Cron 設定，請查閱說明文件以獲得更多資訊。",
-    "Pick background job setting" : "挑選後台作業設定",
-    "Execute one task with each page loaded." : "每個頁面載入時執行一個工作。",
-    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP." : "cron.php 在 webcron 服務中註冊，每5分鐘透過 HTTP 執行 cron.php。",
-    "Use system cron service to call the cron.php file every 5 minutes." : "使用系統 cron 每5分鐘執行 cron.php。",
-    "The cron.php needs to be executed by the system user \"%s\"." : "cron.php 必須由系統用戶「%s」執行。",
-    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "要執行這個，您需要 PHP POSIX 擴充元件。請查閱 {linkstart}PHP 說明文件{linkend} 以取得更多資訊。",
     "You need to enable the File sharing App." : "您需要啟用檔案分享應用程式。",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "系統管理員可以微調分享行為。請查閱說明文件以獲得更多資訊。",
     "Allow apps to use the Share API" : "允許應用程式使用分享 API",
@@ -440,6 +471,7 @@ OC.L10N.register(
     "Allow public uploads" : "允許公開上傳",
     "Always ask for a password" : "要求輸入密碼",
     "Enforce password protection" : "強制密碼保護",
+    "Exclude groups from password requirements:" : "從密碼要求中排除特定群組：",
     "Set default expiration date" : "設定默認到期日",
     "Exclude groups from creating link shares:" : "禁止以下群組創建連結分享：",
     "Allow resharing" : "允許轉分享",
@@ -451,7 +483,7 @@ OC.L10N.register(
     "Allow username autocompletion to users within the same groups" : "允許對同一群組中的用戶自動完成用戶名",
     "Allow username autocompletion to users based on phone number integration" : "允許基於電話號碼整合的用戶自動完成用戶名",
     "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "如果啟用了自動完成功能“相同的群組”和“電話號碼整合”，則任何一個匹配都足以向用戶顯示。",
-    "Allow username autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "輸入全名或電郵地址時，允許用戶名自動完成（忽略缺少的電話簿匹配項，並且位於同一群組中）",
+    "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "輸入全名或電郵地址時，允許自動完成（忽略缺少的電話簿匹配項，並且位於同一群組中）",
     "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "在公開的檔案連結和上傳頁面顯示免責聲明（僅在檔案列表隱藏的時候才會顯示）",
     "This text will be shown on the public link upload page when the file list is hidden." : "這段文字會在公開檔案上傳頁面檔案列表被隱藏的時候顯示。",
     "Default share permissions" : "預設分享權限",
@@ -463,19 +495,54 @@ OC.L10N.register(
     "Check out our blog" : "逛逛我們的部落格",
     "Subscribe to our newsletter" : "訂閱我們的電子報",
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "不支援 Nextcloud 的這個社群版本，且即時通知不可用。",
-    "Profile picture" : "個人資料圖片",
+    "Use a second factor besides your password to increase security for your account." : "使用密碼以外的第二因數來增強您賬戶的安全性。",
+    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "如果您使用第三方應用程式來連線到 Nextcloud，請確保在啟用雙重認證前為每個應用程式設定應用程式密碼。",
+    "Migration in progress. Please wait until the migration is finished" : "正在進行遷移。請等候遷移結束",
+    "Migration started …" : "開始遷移……",
+    "An error occurred while changing your language. Please reload the page and try again." : "變更語言時發生錯誤，請重新整理頁面後重試",
+    "An error occurred while changing your locale. Please reload the page and try again." : "變更慣用地區時發生錯誤，請重新整理頁面後重試",
+    "Select a profile picture" : "選擇個人檔案圖片",
+    "Week starts on {fdow}" : "日曆週從{fdow}開始",
+    "Couldn't remove app." : "無法移除應用程式。",
+    "Couldn't update app." : "無法更新應用程式。",
+    "Backend doesn't support password change, but the user's encryption key was updated." : "後端不支援變更密碼，但用戶加密密鑰已更新。",
+    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the nextcloud log file for more details." : "對於 https://nextcloud.com 的 HTTPS 請求發生錯誤，因此無法確定 cURL 的 TLS 是否過舊。請檢查 nextcloud 的紀錄檔以取得更多資訊。",
+    "You need to set your user email before being able to send test emails." : "您必須先設定您的用戶電子郵件，然後才能傳送測試郵件。",
+    "Revoking this token might prevent the wiping of your device if it hasn't started the wipe yet." : "如果還沒開始抹除，則撤銷此權杖可能會導致無法抹除您的裝置。",
+    "Set as primary mail" : "設為主要電郵地址",
+    "Change privacy level of email" : "更改電郵地址的私隱級別",
+    "All languages" : "全部語言",
+    "Everyone" : "所有人",
+    "An error occured during the request. Unable to proceed." : "請求時發生錯誤。無法繼續。",
+    "Test email settings" : "測試電子郵件設定",
+    "Please read carefully before activating server-side encryption: " : "在您啟動伺服器端加密之前，請仔細閱讀：",
+    "Enable encryption" : "啟用加密",
+    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "您必須將您的加密密鑰從舊的加密（ownCloud <= 8.0）遷移到新的。請啟用「預設加密模組」並執行 'occ encryption：migrate'",
+    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "您必須將您的加密密鑰從舊的加密（ownCloud <= 8.0）遷移到新的。",
+    "Start migration" : "開始遷移",
+    "Last job execution ran %s. Something seems wrong." : "上次後台作業執行於 %s。似乎有點問題。",
+    "Some jobs haven’t been executed since %s. Please consider increasing the execution frequency." : "從 %s 開始，有一些工作未執行。請考慮增加執行頻率。",
+    "Some jobs didn’t execute since %s. Please consider switching to system cron." : "從 %s 開始，有一些工作未執行。請考慮切換為系統 cron。",
+    "Last job ran %s." : "上次後台作業執行於 %s",
+    "Background job didn’t run yet!" : "後台作業從未執行！",
+    "For the server to work properly, it's important to configure background jobs correctly. \"Cron\" is the recommended setting. Please see the documentation for more information." : "為了讓伺服器正確運作，設定背景工作非常重要。建議使用 Cron 設定。請查閱說明文件以獲得更多資訊。",
+    "Pick background job setting" : "挑選後台作業設定",
+    "Recommended" : "建議",
+    "The cron.php needs to be executed by the system user \"%s\"." : "cron.php 必須由系統用戶「%s」執行。",
+    "days" : "天",
+    "Allow username autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "輸入全名或電郵地址時，允許用戶名自動完成（忽略缺少的電話簿匹配項，並且位於同一群組中）",
     "Change privacy level of profile picture" : "更改個人資料圖片的私隱級別",
     "Upload new" : "上傳新的",
     "Select from Files" : "從雲端檔案選擇",
     "Remove image" : "移除圖像",
-    "png or jpg, max. 20 MB" : "png 或 jpg，最大 20 MB",
-    "Picture provided by original account" : "原始賬戶提供的圖片",
+    "Please note that it can take up to 24 hours for the avatar to get updated everywhere." : "請注意，虛擬化身大頭照最長可能需要24小時才能在所有地方更新。",
     "Choose as profile picture" : "設定為個人資料圖片",
-    "You are a member of the following groups:" : "你是下列群組的成員︰",
     "You are using <strong>%s</strong>" : "您已使用了 <strong>%s</strong> 的存儲空間",
     "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "您已使用了 <strong>%2$s</strong> 中的 <strong>%1$s</strong>（<strong>%3$s %%</strong>）",
+    "Change privacy level of full name" : "更改全名的私隱級別",
+    "No display name set" : "未設定顯示名稱",
     "Change privacy level of phone number" : "更改電話號碼的私隱級別",
-    "Your phone number" : "您的電話號碼",
+    "Address" : "地址",
     "Change privacy level of address" : "更改地址的私隱級別",
     "Your postal address" : "您的郵遞地址",
     "Change privacy level of website" : "更改網站的私隱級別",
@@ -483,40 +550,17 @@ OC.L10N.register(
     "Link https://…" : "連結 https://…",
     "Change privacy level of Twitter profile" : "更改 Twitter proile 的私隱級別",
     "Twitter handle @…" : "Twitter 用戶名稱 @...",
-    "Locale" : "地區設定",
-    "Current password" : "目前密碼",
-    "New password" : "新密碼",
-    "Change password" : "更改密碼",
-    "Use a second factor besides your password to increase security for your account." : "使用密碼以外的第二因數來增強您賬戶的安全性。",
-    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "如果您使用第三方應用程式來連線到 Nextcloud，請確保在啟用雙重認證前為每個應用程式設定應用程式密碼。",
-    "Don't synchronize to servers" : "不要同步至伺服器",
-    "Trusted" : "受信任",
-    "Public" : "公開",
-    "installing and updating apps via the app store or Federated Cloud Sharing" : "透過應用程式中心或是聯盟式雲端分享來安裝、更新應用程式",
-    "You need to set your user email before being able to send test emails." : "您必須先設定您的用戶電子郵件，然後才能傳送測試郵件。",
-    "Revoking this token might prevent the wiping of your device if it hasn't started the wipe yet." : "如果還沒開始抹除，則撤銷此權杖可能會導致無法抹除您的裝置。",
-    "Nextcloud iOS app" : "Nextcloud iOS 應用程式",
-    "Nextcloud Android app" : "Nextcloud Android 應用程式",
-    "Nextcloud Talk for iOS" : "iOS 版 Nextcloud Talk",
-    "Nextcloud Talk for Android" : "Android 版 Nextcloud Talk",
-    "Add user in group" : "在群組中新增用戶",
-    "Close" : "關閉",
-    "All languages" : "全部語言",
-    "Everyone" : "所有人",
-    "The app will be downloaded from the app store" : "將會從應用程式商店下載這個應用程式",
-    "Error: This app can not be enabled because it makes the server unstable" : "錯誤：此應用程序無法啟用，因為它造成伺服器不穩定",
-    "mail" : "電郵地址",
-    "Test email settings" : "測試電子郵件設定",
-    "Expire after " : "將在此日期後過期： ",
-    "days" : "天",
-    "Allow users to share via link" : "允許用戶透過連結分享",
-    "Set default expiration date for link shares" : "設定連結分享的預設到期日",
-    "Allow username autocompletion in share dialog (if this is disabled the full username or email address needs to be entered)" : "在分享對話框中允許用戶名稱自動完成（如果停用此選項，則必須輸入完整的用戶名稱或電郵地址）",
-    "Restrict username autocompletion to users within the same groups" : "將使用戶名稱限制為僅相同群組的用戶可使用",
-    "No display name set" : "未設定顯示名稱",
-    "For password reset and notifications" : "用於密碼重設和通告信件",
-    "Change privacy level of full name" : "更改全名的私隱級別",
-    "Change privacy level of email" : "更改電郵地址的私隱級別",
-    "Set as primary mail" : "設為主要電郵地址"
+    "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.max_accelerated_files</code> to your PHP configuration with a value higher than <code>%s</code>." : "幾乎超過了可用的 OPcache 密鑰的最大數量。為確保所有腳本都可以保存在緩存中，建議將 <code>opcache.max_accelerated_files</code> 應用於您的 PHP 配置，其值高於 <code>%s</code>。",
+    "Admin privileges" : "管理員權限",
+    "Unable to update biography" : "無法更新小傳",
+    "Unable to update full name" : "無法更新全名",
+    "No full name set" : "未設定全名",
+    "Unable to update headline" : "無法更新標題",
+    "Unable to update organisation" : "無法更新機構",
+    "Unable to update role" : "無法更新角色",
+    "Change scope level of {accountProperty}" : "更改 {accountProperty} 的範圍",
+    "Unable to update federation scope of the primary {accountProperty}" : "無法更新主要 {accountProperty} 的聯盟範圍",
+    "Unable to update federation scope of additional {accountProperty}" : "無法更新額外 {accountProperty} 的聯盟範圍",
+    "Avatar" : "虛擬化身大頭照"
 },
 "nplurals=1; plural=0;");
