@@ -5,20 +5,22 @@ OC.L10N.register(
     "File is too big" : "El archivo es demasiado grande.",
     "The selected file is not an image." : "El archivo seleccionado no es una imagen.",
     "The selected file cannot be read." : "El archivo seleccionado no se puede leer.",
+    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El archivo subido sobrepasa el valor MAX_FILE_SIZE especificada en el formulario HTML",
+    "No file was uploaded" : "No se subió ningún archivo ",
+    "Missing a temporary folder" : "Falta un directorio temporal",
     "Invalid file provided" : "Archivo proporcionado inválido",
     "No image or file provided" : "No se especificó un archivo o imagen",
     "Unknown filetype" : "Tipo de archivo desconocido",
-    "Invalid image" : "Imagen inválida",
     "An error occurred. Please contact your admin." : "Se presentó un error. Favor de contactar a su adminsitrador. ",
+    "Invalid image" : "Imagen inválida",
     "No temporary profile picture available, try again" : "No hay una imagen de perfil temporal disponible, favor de intentarlo de nuevo",
     "No crop data provided" : "No se han proporcionado datos del recorte",
     "No valid crop data provided" : "No se han proporcionado datos válidos del recorte",
     "Crop is not square" : "El recorte no está cuadrado",
     "State token does not match" : "El token de estado no corresponde",
     "Could not complete login" : "No se pudo completar el inicio de sesión",
+    "Login" : "Inicio de sesión",
     "Password reset is disabled" : "Restablecer contraseña se encuentra deshabilitado",
-    "Couldn't reset password because the token is invalid" : "No ha sido posible restablecer la contraseña porque el token es inválido",
-    "Couldn't reset password because the token is expired" : "No ha sido posible restablecer la contraseña porque el token ha expirado",
     "%s password reset" : "%s restablecer la contraseña",
     "Password reset" : "Restablecer contraseña",
     "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Haga click en el siguiente botón para restablecer su contraseña. Si no ha solicitado restablecer su contraseña, favor de ignorar este correo. ",
@@ -28,20 +30,12 @@ OC.L10N.register(
     "Preparing update" : "Preparando actualización",
     "[%d / %d]: %s" : "[%d / %d]: %s ",
     "Please use the command line updater because automatic updating is disabled in the config.php." : "Favor de usar el actualizador de línea de comandos ya que el actualizador automático se encuentra deshabilitado en config.php.",
-    "[%d / %d]: Checking table %s" : "[%d / %d]: Verificando tabla %s",
     "Turned on maintenance mode" : "Activar modo mantenimiento",
     "Turned off maintenance mode" : "Desactivar modo mantenimiento",
     "Maintenance mode is kept active" : "El modo mantenimiento sigue activo",
     "Updating database schema" : "Actualizando esquema de base de datos",
     "Updated database" : "Base de datos actualizada",
-    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Verificando si el archivo del esquema de base de datos puede ser actualizado (esto puedo tomar mucho tiempo dependiendo del tamaño de la base de datos)",
-    "Checked database schema update" : "Actualización del esquema de base de datos verificada",
-    "Checking updates of apps" : "Verificando actualizaciónes para aplicaciones",
-    "Checking for update of app \"%s\" in appstore" : "Verificando actualizaciones para la aplicacion \"%s\" en la appstore",
-    "Update app \"%s\" from appstore" : "Actualizar la aplicación \"%s\" desde la appstore",
-    "Checked for update of app \"%s\" in appstore" : "Se verificaron actualizaciones para la aplicación \"%s\" en la appstore",
     "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Verificando si el esquema de la base de datos para %s puede ser actualizado (esto puede tomar mucho tiempo dependiendo del tamaño de la base de datos)",
-    "Checked database schema update for apps" : "Se verificó la actualización del esquema de la base de datos para las aplicaciones",
     "Set log level to debug" : "Establecer nivel de bitacora a depurar",
     "Reset log level" : "Restablecer nivel de bitácora",
     "Starting code integrity check" : "Comenzando verificación de integridad del código",
@@ -59,28 +53,26 @@ OC.L10N.register(
     "Hello {name}" : "Hola {name}",
     "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Estos son los resultados de su búsqueda <script>alert(1)</script></strong>",
     "new" : "nuevo",
-    "_download %n file_::_download %n files_" : ["Descargar %n archivos","Descargar %n archivos"],
+    "_download %n file_::_download %n files_" : ["Descargar %n archivos","Descargar %n archivos","Descargar %n archivos"],
     "The update is in progress, leaving this page might interrupt the process in some environments." : "La actualización está en curso, abandonar esta página puede interrumpir el proceso en algunos ambientes. ",
     "Update to {version}" : "Actualizar a {version}",
     "An error occurred." : "Se presentó un error.",
     "Please reload the page." : "Favor de volver a cargar la página.",
     "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "La actualización no fue exitosa. Para más información <a href=\"{url}\">consulte nuestro comentario  en el foro </a> que cubre este tema. ",
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "La actualización no fue exitosa. Favor de reportar este tema a la <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Comunidad Nextcloud</a>.",
-    "Continue to Nextcloud" : "Continuar a Nextcloud",
-    "_The update was successful. Redirecting you to Nextcloud in %n second._::_The update was successful. Redirecting you to Nextcloud in %n seconds._" : ["La actualización fue exitosa. Lo estamos redireccionando a Nextcloud en %n segundo. ","La actualización fue exitosa. Lo estamos redireccionando a Nextcloud en %n segundos."],
+    "More apps" : "Más aplicaciones",
     "Log in" : "Ingresar",
     "Logging in …" : "Ingresando ...",
     "Server side authentication failed!" : "¡Falló la autenticación del lado del servidor!",
     "Please contact your administrator." : "Favor de contactar al administrador.",
     "An internal error occurred." : "Se presentó un error interno.",
     "Please try again or contact your administrator." : "Favor de volver a intentarlo o contacte a su adminsitrador. ",
-    "Username or email" : "Nombre de usuario o contraseña",
     "Password" : "Contraseña",
     "Wrong username or password." : "Nombre de usuario o contraseña equivocado. ",
     "User disabled" : "Usuario deshabilitado",
+    "Username or email" : "Nombre de usuario o contraseña",
     "Reset password" : "Restablecer contraseña",
     "Couldn't send reset email. Please contact your administrator." : "No fue posible enviar el correo de restauración. Favor de contactar a su adminsitrador. ",
-    "Password can not be changed. Please contact your administrator." : "Las contraseñas no se pueden cambiar. Favor de contactar a su adminstrador",
     "Back to login" : "Volver para iniciar sesión",
     "New password" : "Nueva contraseña",
     "I know what I'm doing" : "Sé lo que estoy haciendo",
@@ -88,12 +80,12 @@ OC.L10N.register(
     "Recommended apps" : "Apps recomendadas",
     "Loading apps …" : "Cargando apps ...",
     "App download or installation failed" : "App descargada o instalación fallida",
-    "Can't install this app because it is not compatible" : "No se puede instalar esta app porque no es compatible",
-    "Can't install this app" : "No se puede instalar esta app",
-    "Cancel" : "Cancelar",
+    "Skip" : "Saltar",
+    "Install recommended apps" : "Instalar apps recomendadas",
     "Forgot password?" : "¿Contraseña olvidada?",
     "Back" : "Atrás",
     "Reset search" : "Restablecer búsqueda",
+    "Search" : "Buscar",
     "Settings" : "Configuraciones ",
     "Could not load your contacts" : "No se pudieron cargar tus contactos",
     "Search contacts …" : "Buscar contactos ...",
@@ -121,12 +113,13 @@ OC.L10N.register(
     "OK" : "OK",
     "Error loading message template: {error}" : "Se presentó un error al cargar la plantilla del mensaje: {error}",
     "read-only" : "sólo-lectura",
-    "_{count} file conflict_::_{count} file conflicts_" : ["{count} conflicto de archivo","{count} conflictos en el archivo"],
+    "_{count} file conflict_::_{count} file conflicts_" : ["{count} conflicto de archivo","{count} conflictos en el archivo","{count} conflictos en el archivo"],
     "One file conflict" : "Un conflicto en el archivo",
     "New Files" : "Archivos Nuevos",
     "Already existing files" : "Archivos ya existentes",
-    "Which files do you want to keep?" : "¿Cuales archivos desea mantener?",
+    "Which files do you want to keep?" : "¿Cuáles archivos deseas mantener?",
     "If you select both versions, the copied file will have a number added to its name." : "Si selecciona ambas versiones, se le agregará un número al nombre del archivo copiado.",
+    "Cancel" : "Cancelar",
     "Continue" : "Continuar",
     "(all selected)" : "(todos seleccionados)",
     "({count} selected)" : "({count} seleccionados)",
@@ -138,7 +131,7 @@ OC.L10N.register(
     "Failed to authenticate, try again" : "Falla en la autenticación, favor de reintentar",
     "seconds ago" : "hace segundos",
     "Connection to server lost" : "Se ha perdido la conexión con el servidor",
-    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Se presentó un erorr al cargar la página, recargando en %n segundo","Se presentó un erorr al cargar la página, recargando en %n segundo"],
+    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Se presentó un erorr al cargar la página, recargando en %n segundo","Se presentó un erorr al cargar la página, recargando en %n segundo","Se presentó un erorr al cargar la página, recargando en %n segundo"],
     "Add to a project" : "Agregar a un proyecto",
     "Show details" : "Mostrar detalles",
     "Hide details" : "Ocultar detalles",
@@ -147,6 +140,7 @@ OC.L10N.register(
     "Failed to create a project" : "Error al crear un proyecto",
     "Failed to add the item to the project" : "Error al agregar el elemento al proyecto",
     "New in" : "Nuevo en",
+    "View changelog" : "Ver registro de cambios",
     "Very weak password" : "Contraseña muy débil",
     "Weak password" : "Contraseña débil",
     "So-so password" : "Contraseña aceptable",
@@ -155,8 +149,8 @@ OC.L10N.register(
     "No action available" : "No hay acciones disponibles",
     "Error fetching contact actions" : "Se presentó un error al traer las acciónes de contatos",
     "Non-existing tag #{tag}" : "Etiqueta #{tag} no-existente",
-    "restricted" : "restringido",
-    "invisible" : "invisible",
+    "Restricted" : "Restringido",
+    "Invisible" : "Invisible",
     "Delete" : "Borrar",
     "Rename" : "Renombrar",
     "Collaborative tags" : "Etiquetas colaborativas",
@@ -167,9 +161,10 @@ OC.L10N.register(
     "Admin" : "Administración",
     "Help" : "Ayuda",
     "Access forbidden" : "Acceso denegado",
-    "File not found" : "Archivo no encontrado",
     "Back to %s" : "Volver a %s",
+    "File not found" : "Archivo no encontrado",
     "Error" : "Error",
+    "Previous" : "Anterior",
     "Internal Server Error" : "Error interno del servidor",
     "More details can be found in the server log." : "Puede consultar más detalles en la bitácora del servidor. ",
     "Technical details" : "Detalles técnicos",
@@ -199,21 +194,14 @@ OC.L10N.register(
     "Database host" : "Servidor de base de datos",
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Favor de especificar el número de puerto así como el nombre del servidor (ejem., localhost:5432).",
     "Performance warning" : "Advertencia de desempeño",
-    "Install recommended apps" : "Instalar apps recomendadas",
-    "Finish setup" : "Terminar configuración",
-    "Finishing …" : "Terminando …",
     "Need help?" : "¿Necesita ayuda?",
     "See the documentation" : "Ver la documentación",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Esta aplicación requiere de JavaScript para su correcta operación. Favor de {linkstart}habilitar JavaScript{linkend} y vuelva a cargar la página. ",
-    "Get your own free account" : "Obtenga su propia cuenta gratuita",
     "Skip to main content" : "Saltar al contenido principal",
     "Skip to navigation of app" : "Saltar a la navegación de la app",
-    "More apps" : "Más aplicaciones",
-    "More" : "Más",
-    "More apps menu" : "Más menú de apps",
+    "Get your own free account" : "Obtenga su propia cuenta gratuita",
     "Contacts" : "Contactos",
     "Contacts menu" : "Menú de contactos",
-    "Settings menu" : "Menú de configuración",
     "Confirm your password" : "Confirme su contraseña",
     "Connect to your account" : "Conéctate a tu cuenta",
     "App token" : "Ficha de la aplicación",
@@ -222,7 +210,7 @@ OC.L10N.register(
     "Account access" : "Acceso a la cuenta",
     "Account connected" : "Cuenta conectada",
     "This share is password-protected" : "Este elemento compartido está protegido con una contraseña",
-    "The password is wrong. Try again." : "Error en la contraseña. Inténtelo de nuevo.",
+    "Go to %s" : "Ir a %s",
     "Two-factor authentication" : "Autenticación de dos-factores",
     "Use backup code" : "Usar código de respaldo",
     "Error while validating your second factor" : "Se presentó un error al validar su segundo factor",
@@ -239,14 +227,12 @@ OC.L10N.register(
     "Upgrade via web on my own risk" : "Actualizar vía Web bajo mi propio riesgo",
     "This %s instance is currently in maintenance mode, which may take a while." : "Esta instancia %s se encuentra actualmente en modo mantenimiento, que podría tomar algo de tiempo. ",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Contacte a su administrador del sistema si este mensaje persiste o se presentó de manera inesperada.",
-    "Following apps have been disabled: %s" : "Las siguientes aplicaciones han sido deshabilitadas: %s",
-    "({scope})" : "({scope})",
-    "Searching other places" : "Buscando en otras ubicaciones",
-    "No search results in other folders for {tag}{filter}{endtag}" : "No hay resultados para la búsqueda en otras carpetas para {tag}{filter}{endtag}",
-    "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} resultado de la búsqueda en otra carpeta","{count} resultados de la búsqueda en otras carpetas"],
-    "Nextcloud {app}" : "Nextcloud {app}",
-    "Saving..." : "Guardando...",
-    "Search" : "Buscar",
-    "These apps will be updated:" : "Las siguientes apllicaciones se actualizarán:"
+    "[%d / %d]: Checking table %s" : "[%d / %d]: Verificando tabla %s",
+    "restricted" : "restringido",
+    "invisible" : "invisible",
+    "More" : "Más",
+    "More apps menu" : "Más menú de apps",
+    "Settings menu" : "Menú de configuración",
+    "The password is wrong. Try again." : "Error en la contraseña. Inténtelo de nuevo."
 },
-"nplurals=2; plural=(n != 1);");
+"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
