@@ -16,8 +16,8 @@ OC.L10N.register(
     "Invalid file provided" : "Archivo proporcionado inválido",
     "No image or file provided" : "No se especificó un archivo o imagen",
     "Unknown filetype" : "Tipo de archivo desconocido",
-    "Invalid image" : "Imagen inválida",
     "An error occurred. Please contact your admin." : "Se presentó un error. Por favor contacta a tu adminsitrador. ",
+    "Invalid image" : "Imagen inválida",
     "No temporary profile picture available, try again" : "No hay una imagen de perfil temporal disponible, por favor inténtalo de nuevo",
     "No crop data provided" : "No se han proporcionado datos del recorte",
     "No valid crop data provided" : "No se han proporcionado datos válidos del recorte",
@@ -33,7 +33,6 @@ OC.L10N.register(
     "Preparing update" : "Preparando actualización",
     "[%d / %d]: %s" : "[%d / %d]: %s ",
     "Please use the command line updater because automatic updating is disabled in the config.php." : "Por favor usa el actualizador de línea de comandos ya que el actualizador automático se encuentra deshabilitado en config.php.",
-    "[%d / %d]: Checking table %s" : "[%d / %d]: Verificando tabla %s",
     "Turned on maintenance mode" : "Modo mantenimiento activado",
     "Turned off maintenance mode" : "Modo mantenimiento desactivado",
     "Maintenance mode is kept active" : "El modo mantenimiento sigue activo",
@@ -71,17 +70,18 @@ OC.L10N.register(
     "Please reload the page." : "Por favor vuelve a cargar la página.",
     "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "La actualización no fue exitosa. Para más información <a href=\"{url}\">consulta nuestro comentario  en el foro </a> que cubre este tema. ",
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "La actualización no fue exitosa. Por favor reporta este tema a la <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Comunidad Nextcloud</a>.",
+    "More apps" : "Más aplicaciones",
     "Log in" : "Ingresar",
     "Logging in …" : "Iniciando sesión ...",
     "Server side authentication failed!" : "¡Falló la autenticación del lado del servidor!",
     "Please contact your administrator." : "Por favor contacta al administrador.",
     "An internal error occurred." : "Se presentó un error interno.",
     "Please try again or contact your administrator." : "Por favor vuelve a intentarlo o contacta a tu adminsitrador. ",
-    "Username or email" : "Usuario o correo electrónico",
     "Password" : "Contraseña",
     "Wrong username or password." : "Usuario o contraseña equivocado. ",
     "User disabled" : "Usuario deshabilitado",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Hemos detectado múltiples intentos de inicio de sesión desde tu IP. Por lo tanto tu siguiente incio de sesión se retrasará hasta 30 segundos. ",
+    "Username or email" : "Usuario o correo electrónico",
     "Reset password" : "Restablecer contraseña",
     "Couldn't send reset email. Please contact your administrator." : "No fue posible enviar el correo de restauración. Por favor contacta a tu adminsitrador. ",
     "Back to login" : "Regresar al inicio de sesión",
@@ -148,8 +148,8 @@ OC.L10N.register(
     "No action available" : "No hay acciones disponibles",
     "Error fetching contact actions" : "Se presentó un error al traer las acciónes de contatos",
     "Non-existing tag #{tag}" : "Etiqueta #{tag} no-existente",
-    "restricted" : "restringido",
-    "invisible" : "invisible",
+    "Restricted" : "Restringido",
+    "Invisible" : "Invisible",
     "Delete" : "Borrar",
     "Rename" : "Renombrar",
     "Collaborative tags" : "Etiquetas colaborativas",
@@ -197,9 +197,6 @@ OC.L10N.register(
     "Need help?" : "¿Necesitas ayuda?",
     "See the documentation" : "Ver la documentación",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Esta aplicación requiere de JavaScript para su correcta operación. Por favor {linkstart}habilita JavaScript{linkend} y vuelve a cargar la página. ",
-    "More apps" : "Más aplicaciones",
-    "More" : "Más",
-    "More apps menu" : "Menú de más aplicaciones",
     "Contacts" : "Contactos",
     "Contacts menu" : "Menú de Contactos",
     "Confirm your password" : "Confirma tu contraseña",
@@ -229,9 +226,14 @@ OC.L10N.register(
     "Upgrade via web on my own risk" : "Actualizar vía Web bajo mi propio riesgo",
     "This %s instance is currently in maintenance mode, which may take a while." : "Esta instancia %s se encuentra actualmente en modo mantenimiento, que podría tomar algo de tiempo. ",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Contacta a tu administrador del sistema si este mensaje persiste o se presentó de manera inesperada.",
+    "[%d / %d]: Checking table %s" : "[%d / %d]: Verificando tabla %s",
     "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "El servidor no cuenta con una conexión a Internet: No se pudieron alcanzar múltiples endpoints. Esto significa que algunas características como montar almacenamiento externo, notificaciones de actualizaciones o instalación de aplicaciones de 3ros no funcionarán correctamente. Acceder archivos de forma remota y el envío de de notificaciones por correo electrónico puede que no funcionen tampoco. Establece una conexión desde este servidor a Internet para aprovechar todas las funcionalidades.",
     "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Probablemente tu directorio de datos y archivos sean accesibles desde Internet. El archivo .htaccess no está funcionando. Se recomienda ampliamente que configures tu servidor web para que el directorio de datos no sea accesible, o bien, que muevas el directorio de datos fuera del directorio raíz del servidor web.",
+    "restricted" : "restringido",
+    "invisible" : "invisible",
+    "More" : "Más",
+    "More apps menu" : "Menú de más aplicaciones",
     "Settings menu" : "Menú de Configuraciones",
     "The password is wrong. Try again." : "La contraseña está equivoada. Por favor vuelve a intentarlo. "
 },
-"nplurals=2; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
+"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
