@@ -2,14 +2,18 @@ OC.L10N.register(
     "lib",
     {
     "Cannot write into \"config\" directory!" : "Nedaří se zapisovat do adresáře „config“!",
-    "This can usually be fixed by giving the webserver write access to the config directory" : "Toto obvykle lze vyřešit udělením oprávnění k zápisu do adresáře s nastaveními pro účet, pod kterým je provozován webový server",
+    "This can usually be fixed by giving the web server write access to the config directory." : "Toto je obvykle možné vyřešit udělením webovému serveru oprávnění k zápisu do adresáře s nastaveními.",
+    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Ale, pokud chcete mít soubor config.php pouze pro čtení, nastavte  v něm volbu „config_is_read_only“ na hodnotu true.",
     "See %s" : "Viz %s",
-    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Nebo, pokud chcete mít soubor config.php pouze pro čtení, nastavte  v něm volbu „config_is_read_only“ na hodnotu true.",
-    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Toto obvykle lze vyřešit udělením oprávnění k zápisu do kořenové složky webu pro účet, pod kterým je provozován webový server. Viz %s",
-    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Nebo, pokud chcete mít soubor config.php pouze pro čtení, nastavte v něm volbu „config_is_read_only“ na hodnotu true. Viz %s",
     "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Soubory aplikace %1$s nebyly nahrazeny řádně. Ověřte, že se jedná o verzi, která je kompatibilní se serverem.",
     "Sample configuration detected" : "Bylo zjištěno setrvání u předváděcího nastavení",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Pravděpodobně byla zkopírována nastavení ze vzorových souborů. Toto není podporováno a může poškodit vaši instalaci. Před prováděním změn v souboru config.php si přečtěte dokumentaci",
+    "%s email verification" : "%s ověřování e-mailem",
+    "Email verification" : "Ověřování e-mailem",
+    "Click the following button to confirm your email." : "Pokud chcete potvrdit svůj e-mail, klikněte na následující tlačítko.",
+    "Click the following link to confirm your email." : "Pokud chcete potvrdit svůj e-mail, klikněte na následující odkaz.",
+    "Confirm your email" : "Potvrďte svůj e-mail",
+    "Other activities" : "Ostatní aktivity",
     "%1$s and %2$s" : "%1$s a %2$s",
     "%1$s, %2$s and %3$s" : "%1$s, %2$s a %3$s",
     "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s a %4$s",
@@ -17,26 +21,29 @@ OC.L10N.register(
     "Education Edition" : "Vydání pro vzdělávací instituce",
     "Enterprise bundle" : "Sada pro organizace",
     "Groupware bundle" : "Sada pro podporu spolupráce",
-    "Social sharing bundle" : "Balíček sociálního sdílení",
+    "Hub bundle" : "Sada pro centrum aktivity (hub)",
+    "Social sharing bundle" : "Balíček pro sdílení na sociálních sítích",
     "PHP %s or higher is required." : "Je vyžadováno PHP %s nebo novější.",
-    "PHP with a version lower than %s is required." : "Je vyžadováno PHP ve verzi nižší než %s.",
+    "PHP with a version lower than %s is required." : "Je vyžadováno PHP ve verzi starší než %s.",
     "%sbit or higher PHP required." : "Je vyžadováno PHP %sbit nebo vyšší.",
-    "Following databases are supported: %s" : "Jsou podporovány následující databáze: %s",
+    "The following architectures are supported: %s" : "Jsou podporovány následující architektury: %s",
+    "The following databases are supported: %s" : "Jsou podporovány následující databáze: %s",
     "The command line tool %s could not be found" : "Nástroj příkazového řádku %s nebyl nalezen",
-    "The library %s is not available." : "Knihovna %s není dostupná.",
+    "The library %s is not available." : "Knihovna %s není k dispozici.",
     "Library %1$s with a version higher than %2$s is required - available version %3$s." : "Je vyžadována knihovna %1$s novější verze než %2$s – verze k dispozici je %3$s.",
     "Library %1$s with a version lower than %2$s is required - available version %3$s." : "Je vyžadována knihovna %1$s verzi nižší než %2$s – dostupná verze %3$s.",
-    "Following platforms are supported: %s" : "Jsou podporovány následující systémy: %s",
+    "The following platforms are supported: %s" : "Jsou podporovány následující systémy: %s",
     "Server version %s or higher is required." : "Je potřeba verze serveru %s nebo novější.",
     "Server version %s or lower is required." : "Je potřeba verze serveru %s nebo starší.",
+    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Aby mohl přistupovat k tomuto nastavení je třeba, aby přihlášený uživatel byl správce, dílčí správce nebo obdržel speciální oprávnění",
     "Logged in user must be an admin or sub admin" : "Je třeba, aby přihlášený uživatel byl správcem či správcem pro dílčí oblast",
     "Logged in user must be an admin" : "Je třeba, aby přihlášený uživatel byl správce",
-    "Wiping of device %s has started" : "Vymazávání zařízení %s zahájeno",
-    "Wiping of device »%s« has started" : "Vymazávání zařízení „%s“ zahájeno",
+    "Wiping of device %s has started" : "Vymazávání ze zařízení %s zahájeno",
+    "Wiping of device »%s« has started" : "Vymazávání ze zařízení „%s“ zahájeno",
     "»%s« started remote wipe" : "„%s“ zahájilo vymazávání na dálku",
     "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "Přístroj či aplikace »%s« spustila proces vzdáleného vymazání. Obdržíte další e-mail poté co bude proces ukončen",
-    "Wiping of device %s has finished" : "Vymazávání zařízení %s dokončeno",
-    "Wiping of device »%s« has finished" : "Vymazávání zařízení „%s“ dokončeno",
+    "Wiping of device %s has finished" : "Vymazávání ze zařízení %s dokončeno",
+    "Wiping of device »%s« has finished" : "Vymazávání ze zařízení „%s“ dokončeno",
     "»%s« finished remote wipe" : "„%s“ dokončilo vymazání na dálku",
     "Device or application »%s« has finished the remote wipe process." : "Přístroj či aplikace „%s“ dokončila proces vymazání na dálku.",
     "Remote wipe started" : "Vymazání na dálku zahájeno",
@@ -46,7 +53,8 @@ OC.L10N.register(
     "Authentication" : "Ověření",
     "Unknown filetype" : "Neznámý typ souboru",
     "Invalid image" : "Neplatný obrázek",
-    "Avatar image is not square" : "Obrázek s avatarem není čtvercový",
+    "Avatar image is not square" : "Profilový obrázek není čtvercový",
+    "View profile" : "Zobrazit profil ",
     "today" : "dnes",
     "tomorrow" : "zítra",
     "yesterday" : "včera",
@@ -58,70 +66,87 @@ OC.L10N.register(
     "_%n month ago_::_%n months ago_" : ["před %n měsícem","před %n měsíci","před %n měsíci","před %n měsíci"],
     "next year" : "následující rok",
     "last year" : "minulý rok",
-    "_in %n year_::_in %n years_" : ["během %n roku","během %n roků","během %n roků","během %n roků"],
+    "_in %n year_::_in %n years_" : ["během %n roku","během %n let","během %n let","během %n let"],
     "_%n year ago_::_%n years ago_" : ["před rokem","před %n lety","před %n lety","před %n lety"],
     "_in %n hour_::_in %n hours_" : ["během %n hodiny","během %n hodin","během %n hodin","během %n hodin"],
     "_%n hour ago_::_%n hours ago_" : ["před %n hodinou","před %n hodinami","před %n hodinami","před %n hodinami"],
     "_in %n minute_::_in %n minutes_" : ["během %n minuty","během %n minut","během %n minut","během %n minut"],
-    "_%n minute ago_::_%n minutes ago_" : ["před %n minutou","před %n minutami","před %n minutami","před %n minutami"],
+    "_%n minute ago_::_%n minutes ago_" : ["před minutou","před %n minutami","před %n minutami","před %n minutami"],
     "in a few seconds" : "během několika sekund",
     "seconds ago" : "před pár sekundami",
     "Empty file" : "Prázdný soubor",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Modul s identifikátorem: %s neexistuje. Povolte ho v nastavení aplikací, nebo se obraťte na správce.",
+    "File already exists" : "Soubor už existuje",
+    "Invalid path" : "Neplatný popis umístění",
+    "Failed to create file from template" : "Vytvoření souboru ze šablony selhalo",
+    "Templates" : "Šablony",
     "File name is a reserved word" : "Název souboru je rezervované slovo",
-    "File name contains at least one invalid character" : "Název souboru obsahuje nejméně jeden neplatný znak",
+    "File name contains at least one invalid character" : "Název souboru obsahuje přinejmenším jeden neplatný znak",
     "File name is too long" : "Název souboru je příliš dlouhý",
-    "Dot files are not allowed" : "Názvy souborů, začínající na tečku nejsou povolené",
+    "Dot files are not allowed" : "Názvy souborů, začínající na tečku nejsou dovolené",
     "Empty filename is not allowed" : "Je třeba vyplnit název souboru",
     "App \"%s\" cannot be installed because appinfo file cannot be read." : "Aplikace „%s“ nemůže být nainstalována protože soubor appinfo nelze přečíst.",
     "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Aplikaci „%s“ nelze nainstalovat, protože není kompatibilní s touto verzí serveru.",
-    "__language_name__" : "čeština",
+    "__language_name__" : "Čeština",
     "This is an automatically sent email, please do not reply." : "Toto je automaticky odesílaný e-mail, neodpovídejte na něj.",
     "Help" : "Nápověda",
+    "Appearance and accessibility" : "Vzhled a zpřístupnění",
     "Apps" : "Aplikace",
+    "Personal settings" : "Osobní nastavení",
+    "Administration settings" : "Nastavení pro správu",
     "Settings" : "Nastavení",
     "Log out" : "Odhlásit se",
     "Users" : "Uživatelé",
+    "Email" : "E-mail",
+    "Mail %s" : "Poslat e-mail %s",
+    "Phone" : "Telefon",
+    "Call %s" : "Zavolat %s",
+    "Twitter" : "Twitter",
+    "View %s on Twitter" : "Zobrazit %s na Twitteru",
+    "Website" : "Webová stránka",
+    "Visit %s" : "Navštívit %s",
+    "Address" : "Adresa",
+    "Profile picture" : "Profilový obrázek",
+    "About" : "O uživateli",
+    "Full name" : "Celé jméno",
+    "Headline" : "Nadpis",
+    "Organisation" : "Organizace",
+    "Role" : "Role",
     "Unknown user" : "Neznámý uživatel",
-    "Overview" : "Přehled",
-    "Basic settings" : "Základní nastavení",
-    "Sharing" : "Sdílení",
-    "Security" : "Zabezpečení",
-    "Groupware" : "Software pro podporu spolupráce",
     "Additional settings" : "Další nastavení",
-    "Personal info" : "Osobní údaje",
-    "Mobile & desktop" : "Mobilní a desktop",
-    "%s enter the database username and name." : "%s zadejte databázové uživatelské jméno a jméno.",
-    "%s enter the database username." : "Zadejte uživatelské jméno %s databáze.",
-    "%s enter the database name." : "Zadejte název databáze pro %s databáze.",
-    "%s you may not use dots in the database name" : "V názvu databáze %s není možné používat tečky.",
+    "Enter the database username and name for %s" : "Zadejte uživatelské jméno v databázi a název pro %s",
+    "Enter the database username for %s" : "Zadejte uživatelské jméno v databázi pro %s",
+    "Enter the database name for %s" : "Zadejte název databáze pro %s",
+    "You cannot use dots in the database name %s" : "V názvu databáze %s není možné použít tečky",
+    "MySQL username and/or password not valid" : "Neplatné uživatelské jméno a/nebo heslo do MySQL",
+    "You need to enter details of an existing account." : "Je třeba zadat podrobnosti existujícího účtu.",
     "Oracle connection could not be established" : "Spojení s Oracle nemohlo být navázáno",
     "Oracle username and/or password not valid" : "Neplatné uživatelské jméno a/nebo heslo do Oracle",
     "PostgreSQL username and/or password not valid" : "Neplatné uživatelské jméno a/nebo heslo do PostgreSQL",
-    "You need to enter details of an existing account." : "Je třeba zadat podrobnosti existujícího účtu.",
-    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X není podporován a %s nebude na této platformě správně fungovat. Používejte pouze na vlastní nebezpečí!",
+    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "macOS není podporován a %s nebude na této platformě správně fungovat. Používejte pouze na vlastní nebezpečí!",
     "For the best results, please consider using a GNU/Linux server instead." : "Místo toho zvažte pro nejlepší funkčnost použití GNU/Linux serveru.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Zdá se, že tato instance %s je provozována v 32-bitovém PHP prostředí a v php.ini je nastavena volba open_basedir. Toto povede k problémům se soubory většími než 4 GB a silně není doporučováno.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Odstraňte z php.ini nastavení volby open_basedir nebo přejděte na 64-bitové PHP.",
     "Set an admin username." : "Nastavte uživatelské jméno správce.",
-    "Set an admin password." : "Zadejte heslo správce.",
-    "Can't create or write into the data directory %s" : "Nedaří se vytvořit nebo zapisovat do datového adresáře %s",
-    "Invalid Federated Cloud ID" : "Neplatné sdružené cloud ID",
-    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Úložiště pro sdílení %s musí implementovat rozhraní OCP\\Share_Backend",
+    "Set an admin password." : "Nastavte heslo pro účet správce.",
+    "Cannot create or write into the data directory %s" : "Nedaří se vytvořit nebo zapisovat do datového adresáře %s",
+    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Je třeba, aby podpůrná vrstva pro sdílení %s implementovala  rozhraní OCP\\Share_Backend",
     "Sharing backend %s not found" : "Úložiště sdílení %s nenalezeno",
-    "Sharing backend for %s not found" : "Úložiště  sdílení pro %s nenalezeno",
+    "Sharing backend for %s not found" : "Úložiště sdílení pro %s nenalezeno",
     "%1$s shared »%2$s« with you and wants to add:" : "%1$s sdílí „%2$s“ a dodává:",
     "%1$s shared »%2$s« with you and wants to add" : "%1$s sdílí „%2$s“ a dodává",
     "»%s« added a note to a file shared with you" : "„%s“ dodává poznámku k nasdílenému souboru ",
     "Open »%s«" : "Otevřít „%s“",
     "%1$s via %2$s" : "%1$s prostřednictvím %2$s",
     "You are not allowed to share %s" : "Nemáte povoleno sdílet %s",
-    "Can’t increase permissions of %s" : "Nelze zvýšit oprávnění %s",
-    "Files can’t be shared with delete permissions" : "Soubory nelze sdílet s oprávněními k odstranění",
-    "Files can’t be shared with create permissions" : "Soubory nelze sdílet s oprávněními k vytváření",
+    "Cannot increase permissions of %s" : "Nelze navýšit oprávnění  u %s",
+    "Files cannot be shared with delete permissions" : "Soubory nelze sdílet s oprávněními k odstranění",
+    "Files cannot be shared with create permissions" : "Soubory nelze sdílet s oprávněními k vytváření",
     "Expiration date is in the past" : "Datum skončení platnosti je v minulosti",
-    "Can’t set expiration date more than %s days in the future" : "Nelze nastavit datum skončení platnosti více než %s dní v budoucnu",
-    "%1$s shared »%2$s« with you" : "%1$s s vámi sdílí „%2$s“",
+    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Datum vypršení nelze nastavit na více než %n den do budoucnosti","Datum vypršení nelze nastavit na více než %n dny do budoucnosti","Datum vypršení nelze nastavit na více než %n dnů do budoucnosti","Datum vypršení nelze nastavit na více než %n dny do budoucnosti"],
+    "Sharing is only allowed with group members" : "Je povoleno pouze sdílení s členy skupiny",
+    "Sharing %s failed, because this item is already shared with user %s" : "Sdílení %s se nezdařilo, protože tato položka už je sdílena s uživatelem %s",
+    "%1$s shared »%2$s« with you" : "%1$s vám sdílí „%2$s“",
     "%1$s shared »%2$s« with you." : "%1$s vám nasdílel(a) „%2$s“.",
     "Click the button below to open it." : "Pro otevření klikněte na tlačítko níže.",
     "The requested share does not exist anymore" : "Požadované sdílení už neexistuje",
@@ -171,9 +196,10 @@ OC.L10N.register(
     "Oct." : "říj.",
     "Nov." : "list.",
     "Dec." : "pro.",
+    "The user limit has been reached and the user was not created." : "Bylo dosaženo limitu počtu uživatelů a uživatel proto nebyl vytvořen.",
     "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Pouze následující znaky jsou povoleny pro uživatelské jméno: „a-z“, „A-Z“, „0-9“, a „_.@-'“",
     "A valid username must be provided" : "Je třeba zadat platné uživatelské jméno",
-    "Username contains whitespace at the beginning or at the end" : "Uživatelské jméno obsahuje mezery na svém začátku nebo konci",
+    "Username contains whitespace at the beginning or at the end" : "Uživatelské jméno je chybné – na jeho začátku či konci se nachází prázdný znak (mezera, tabulátor, atp.)",
     "Username must not consist of dots only" : "Uživatelské jméno se nemůže skládat pouze ze samých teček",
     "Username is invalid because files already exist for this user" : "Uživatelské jméno není platné, protože protože pro tohoto uživatele už existují soubory",
     "A valid password must be provided" : "Je třeba zadat platné heslo",
@@ -183,79 +209,78 @@ OC.L10N.register(
     "Login canceled by app" : "Přihlášení zrušeno aplikací",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Aplikaci „%1$s“ nelze nainstalovat, protože nejsou splněny následující závislosti: %2$s",
     "a safe home for all your data" : "bezpečný domov pro všechna vaše data",
-    "File is currently busy, please try again later" : "Soubor je používán, zkuste to později",
-    "Can't read file" : "Nelze přečíst soubor",
+    "File is currently busy, please try again later" : "Soubor je nyní používán, zkuste to později",
+    "Cannot download file" : "Soubor se nedaří stáhnout",
     "Application is not enabled" : "Aplikace není povolena",
-    "Authentication error" : "Chyba ověření",
+    "Authentication error" : "Chyba při ověřování se",
     "Token expired. Please reload page." : "Platnost tokenu skončila. Načtěte stránku znovu.",
-    "No database drivers (sqlite, mysql, or postgresql) installed." : "Nejsou instalovány ovladače databází (sqlite, mysql nebo postresql).",
-    "Cannot write into \"config\" directory" : "Nelze zapisovat do adresáře „config“",
-    "Cannot write into \"apps\" directory" : "Nedaří se zapisovat do adresáře „apps“",
-    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the appstore in the config file. See %s" : "To lze obvykle vyřešit povolením zápisu webovému serveru do adresáře apps nebo zakázáním appstore v souboru s nastaveními. Viz %s",
-    "Cannot create \"data\" directory" : "Nedaří se vytvořit adresář „data“",
-    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "Toto obvykle lze vyřešit udělením oprávnění k zápisu do kořenové složky webu pro účet, pod kterým je provozován webový server. Viz %s",
-    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "Oprávnění lze obvykle napravit umožněním zápisu do kořene webu pro účet, pod kterým je provozován webový server. Viz %s.",
-    "Setting locale to %s failed" : "Nastavení jazyka na %s se nezdařilo",
-    "Please install one of these locales on your system and restart your webserver." : "Do svého systému nainstalujte alespoň jeden z těchto jazyků  a restartujte webový server.",
-    "Please ask your server administrator to install the module." : "Požádejte svého správce systému o instalaci tohoto modulu.",
+    "No database drivers (sqlite, mysql, or postgresql) installed." : "Nejsou nainstalovány ovladače databází (sqlite, mysql nebo postresql).",
+    "Cannot write into \"config\" directory." : "Nedaří se zapisovat do adresáře „config“.",
+    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Toto obvykle lze vyřešit udělením oprávnění k zápisu do kořenové složky webu pro účet, pod kterým je provozován webový server. Viz %s",
+    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Nebo, pokud chcete mít soubor config.php pouze pro čtení, nastavte v něm volbu „config_is_read_only“ na hodnotu true. Viz %s",
+    "Cannot write into \"apps\" directory." : "Nedaří se zapisovat do adresáře „apps“.",
+    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Toto je obvykle možné napravit udělením přístupu ke čtení adresáře s aplikací pro webový server nebo vypnutím katalogu s aplikacemi v souboru s nastaveními.",
+    "Cannot create \"data\" directory." : "Nedaří se vytvořit adresář „data“.",
+    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Toto obvykle lze vyřešit udělením oprávnění k zápisu do kořenové složky webu pro účet, pod kterým je provozován webový server. Viz %s",
+    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Oprávnění lze obvykle napravit umožněním zápisu do kořene webu pro účet, pod kterým je provozován webový server. Viz %s.",
+    "Your data directory is not writable." : "Adresář data není přístupný pro zápis.",
+    "Setting locale to %s failed." : "Nastavení místních a jazykových nastavení na %s se nezdařilo.",
+    "Please install one of these locales on your system and restart your web server." : "Do svého systému nainstalujte alespoň jeden z těchto jazyků a restartujte webový server.",
     "PHP module %s not installed." : "PHP modul %s není nainstalován.",
-    "PHP setting \"%s\" is not set to \"%s\"." : "Hodnota PHP nastavení „%s“ není nastavená na „%s“.",
+    "Please ask your server administrator to install the module." : "Požádejte správce serveru, který využíváte o instalaci tohoto modulu.",
+    "PHP setting \"%s\" is not set to \"%s\"." : "Hodnota v konfiguraci PHP „%s“ není nastavená na „%s“.",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "Úprava tohoto nastavení v php.ini umožní Nextcloud opět zprovoznit",
-    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload je nastaven na „%s“ namísto očekávané hodnoty „0“",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Pro nápravu nastavte v souboru php.ini parametr <code>mbstring.func_overload</code> na <code>0</code>",
-    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Je požadována verze softwarové knihovny libxml2 minimálně 2.7.0. Nyní je nainstalována verze %s.",
-    "To fix this issue update your libxml2 version and restart your web server." : "Pro opravu tohoto problému aktualizujte knihovnu libxml2 a restartujte webový server.",
+    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> je nastaveno na <code>%s</code> namísto očekávané hodnoty <code>0</code>.",
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Pro nápravu nastavte v souboru php.ini parametr <code>mbstring.func_overload</code> na <code>0</code>.",
+    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Je zapotřebí verze softwarové knihovny libxml2 přinejmenším 2.7.0. Nyní je nainstalována verze %s.",
+    "To fix this issue update your libxml2 version and restart your web server." : "Tento problém opravíte instalací novější verze knihovny libxml2 a restartem webového serveru.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP je patrně nastaveno tak, aby odstraňovalo bloky komentářů. Toto bude mít za následek znepřístupnění mnoha důležitých aplikací.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Toto je pravděpodobně způsobeno aplikacemi pro urychlení načítání jako jsou Zend OPcache nebo eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP moduly jsou nainstalovány, ale stále se tváří jako chybějící?",
-    "Please ask your server administrator to restart the web server." : "Požádejte svého správce systému o restart webového serveru.",
-    "PostgreSQL >= 9 required" : "Je vyžadováno PostgreSQL verze 9 a novější",
-    "Please upgrade your database version" : "Aktualizujte verzi své databáze",
+    "Please ask your server administrator to restart the web server." : "Požádejte správce serveru, který využíváte o restart webového serveru.",
+    "The required %s config variable is not configured in the config.php file." : "Požadovaná proměnná nastavení %s není v souboru s nastaveními config.php nastavena.",
+    "Please ask your server administrator to check the Nextcloud configuration." : "Požádejte správce serveru, který využíváte, aby zkontroloval nastavení serveru.",
+    "PostgreSQL >= 9 required." : "Je vyžadováno PostgreSQL verze 9 a novější.",
+    "Please upgrade your database version." : "Aktualizujte verzi vámi využívané databáze.",
+    "Your data directory is readable by other users." : "Váš adresář data je čitelný ostatním uživatelům.",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Změňte práva na 0770, aby obsah adresáře nemohl být vypisován ostatními uživateli.",
-    "Your data directory is readable by other users" : "Váš adresář data je čitelný ostatním uživatelům",
-    "Your data directory must be an absolute path" : "Je třeba, aby váš adresář data byl zadán jako úplný popis umístění",
-    "Check the value of \"datadirectory\" in your configuration" : "Zkontrolujte hodnotu „datadirectory“ ve svém nastavení",
-    "Your data directory is invalid" : "Váš adresář data není plantý",
+    "Your data directory must be an absolute path." : "Je třeba, aby váš adresář data byl zadán jako úplný popis umístění.",
+    "Check the value of \"datadirectory\" in your configuration." : "Zkontrolujte hodnotu „datadirectory“ ve svém nastavení.",
+    "Your data directory is invalid." : "Váš adresář data není platný.",
     "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Ověřte, že v kořeni datového adresáře je soubor s názvem „.ocdata“.",
     "Action \"%s\" not supported or implemented." : "Akce „%s“ není podporována nebo implementována.",
     "Authentication failed, wrong token or provider ID given" : "Ověření se nezdařilo, předán chybný token nebo identifikátor poskytovatele",
     "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Pro dokončení požadavku chybí parametry. Konkrétně: „%s“",
     "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "Identifikátor „%1$s“ už je používán poskytovatelem federování cloudu „%2$s“",
-    "Cloud Federation Provider with ID: \"%s\" does not exist." : "Poskytovatel sdružování cloudů s identifikátorem: „%s“ neexistuje",
+    "Cloud Federation Provider with ID: \"%s\" does not exist." : "Poskytovatel federování cloudů s identifikátorem: „%s“ neexistuje",
     "Could not obtain lock type %d on \"%s\"." : "Nedaří získat zámek typu %d na „%s“.",
     "Storage unauthorized. %s" : "Úložiště neověřeno. %s",
     "Storage incomplete configuration. %s" : "Neúplné nastavení pro úložiště. %s",
     "Storage connection error. %s" : "Chyba připojení úložiště. %s",
     "Storage is temporarily not available" : "Úložiště je dočasně nedostupné",
     "Storage connection timeout. %s" : "Překročen časový limit připojování k úložišti. %s",
-    "Create" : "Vytvořit",
-    "Change" : "Změnit",
-    "Delete" : "Smazat",
-    "Share" : "Sdílet",
-    "Unlimited" : "Neomezeně",
-    "Verifying" : "Ověřuje se",
-    "Verifying …" : "Ověřování…",
-    "Verify" : "Ověřit",
-    "Sharing %s failed, because the backend does not allow shares from type %i" : "Sdílení %s se nezdařilo, podpůrná vrstva nepodporuje typ sdílení %i",
-    "Sharing %s failed, because the file does not exist" : "Sdílení %s se nezdařilo, protože soubor neexistuje",
-    "Sharing %s failed, because you can not share with yourself" : "Sdílení %s se nezdařilo, protože nemůžete sdílet sami se sebou",
-    "Sharing %1$s failed, because the user %2$s does not exist" : "Sdílení %1$s se nezdařilo, protože uživatel %2$s neexistuje",
-    "Sharing %1$s failed, because the user %2$s is not a member of any groups that %3$s is a member of" : "Sdílení položky %1$s se nezdařilo, protože uživatel %2$s není členem žádné skupiny společné s uživatelem %3$s",
-    "Sharing %1$s failed, because this item is already shared with %2$s" : "Sdílení %1$s se nezdařilo, protože tato položka už je sdílena s %2$s",
-    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Sdílení položky %1$s se nezdařilo, protože ta je už s uživatelem %2$s sdílena",
-    "Sharing %1$s failed, because the group %2$s does not exist" : "Sdílení %1$s se nezdařilo, protože skupina %2$s neexistuje",
-    "Sharing %1$s failed, because %2$s is not a member of the group %3$s" : "Sdílení %1$s se nezdařilo, protože %2$s není členem skupiny %3$s",
-    "You need to provide a password to create a public link, only protected links are allowed" : "Pro vytvoření veřejného odkazu je nutné zadat heslo, jsou povoleny pouze chráněné odkazy",
-    "Sharing %s failed, because sharing with links is not allowed" : "Sdílení položky %s se nezdařilo, protože sdílení pomocí odkazů není povoleno",
-    "Not allowed to create a federated share with the same user" : "Není povoleno vytvořit propojené sdílení s tím samým uživatelem",
-    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable." : "Sdílení %1$s se nezdařilo, %2$s se nedaří nalézt, možná je server v tuto chvíli nedostupný.",
-    "Share type %1$s is not valid for %2$s" : "Typ sdílení %1$s není platné pro %2$s",
-    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Nedaří se nastavit datum skončení platnosti. Sdílení nemůže vypršet později než za %s po zveřejnění",
-    "Cannot set expiration date. Expiration date is in the past" : "Takové datum skončení platnosti nelze nastavit – je třeba, aby bylo v budoucnosti a ne minulosti…",
-    "Sharing failed, because the user %s is the original sharer" : "Sdílení položky se nezdařilo, protože uživatel %s je původním vlastníkem",
-    "Sharing %1$s failed, because the permissions exceed permissions granted to %2$s" : "Sdílení položky %1$s se nezdařilo, protože jsou k tomu nutná vyšší oprávnění, než jaká byla %2$s povolena.",
-    "Sharing %s failed, because resharing is not allowed" : "%s nejde sdílet, protože vám bylo nasdíleno s tím, že není umožněno sdílet dále dalším",
-    "Sharing %1$s failed, because the sharing backend for %2$s could not find its source" : "Sdílení položky %1$s se nezdařilo, protože úložiště sdílení %2$s nenalezla zdroj",
-    "Sharing %s failed, because the file could not be found in the file cache" : "Sdílení položky %s selhalo, protože soubor nebyl nalezen ve vyrovnávací paměti"
+    "This can usually be fixed by giving the webserver write access to the config directory." : "Toto je obvykle možné vyřešit udělením webovému serveru oprávnění k zápisu do adresáře s nastaveními.",
+    "%s enter the database username and name." : "%s zadejte databázové uživatelské jméno a jméno.",
+    "%s enter the database username." : "Zadejte uživatelské jméno %s databáze.",
+    "%s enter the database name." : "Zadejte název databáze pro %s databázi.",
+    "%s you may not use dots in the database name" : "V názvu databáze %s není možné používat tečky.",
+    "Cannot read file" : "Nelze přečíst soubor",
+    "Cannot write into \"config\" directory" : "Nelze zapisovat do adresáře „config“",
+    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Toto obvykle lze vyřešit udělením oprávnění k zápisu do kořenové složky webu pro účet, pod kterým je provozován webový server. Viz %s",
+    "Cannot write into \"apps\" directory" : "Nedaří se zapisovat do adresáře „apps“",
+    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the App Store in the config file." : "Toto je obvykle možné napravit udělením přístupu ke čtení adresáře s aplikací pro webový server nebo vypnutím katalogu s aplikacemi v souboru s nastaveními.",
+    "Cannot create \"data\" directory" : "Nedaří se vytvořit adresář „data“",
+    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "Toto obvykle lze vyřešit udělením oprávnění k zápisu do kořenové složky webu pro účet, pod kterým je provozován webový server. Viz %s",
+    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "Oprávnění lze obvykle napravit umožněním zápisu do kořene webu pro účet, pod kterým je provozován webový server. Viz %s.",
+    "Setting locale to %s failed" : "Nastavení místních a jazykových nastavení na %s se nezdařilo",
+    "Please install one of these locales on your system and restart your webserver." : "Do svého systému nainstalujte alespoň jeden z těchto jazyků a restartujte webový server.",
+    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload je nastaveno na „%s“ namísto očekávané hodnoty „0“",
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Pro nápravu nastavte v souboru php.ini parametr <code>mbstring.func_overload</code> na <code>0</code>",
+    "PostgreSQL >= 9 required" : "Je vyžadováno PostgreSQL verze 9 a novější",
+    "Please upgrade your database version" : "Aktualizujte verzi vámi využívané databáze",
+    "Your data directory is readable by other users" : "Váš adresář data je čitelný ostatním uživatelům",
+    "Your data directory must be an absolute path" : "Je třeba, aby váš adresář data byl zadán jako úplný popis umístění",
+    "Check the value of \"datadirectory\" in your configuration" : "Zkontrolujte hodnotu „datadirectory“ ve svém nastavení",
+    "Your data directory is invalid" : "Váš adresář data není plantý"
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
