@@ -5,6 +5,7 @@ OC.L10N.register(
     "See %s" : "Se %s",
     "Sample configuration detected" : "Eksempel for konfiguration registreret",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Der er registreret at eksempel for konfiguration er blevet kopieret. Dette kan ødelægge din installation og understøttes ikke. Læs venligst dokumentationen før der foretages ændringer i config.php",
+    "Other activities" : "Andre aktiviteter",
     "%1$s and %2$s" : "%1$s og %2$s",
     "%1$s, %2$s and %3$s" : "%1$s, %2$s og %3$s",
     "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s og %4$s",
@@ -18,6 +19,7 @@ OC.L10N.register(
     "Authentication" : "Godkendelse",
     "Unknown filetype" : "Ukendt filtype",
     "Invalid image" : "Ugyldigt billede",
+    "View profile" : "Vis profil",
     "today" : "i dag",
     "tomorrow" : "i morgen",
     "yesterday" : "i går",
@@ -37,6 +39,8 @@ OC.L10N.register(
     "_%n minute ago_::_%n minutes ago_" : ["%n minut siden","%n minutter siden"],
     "in a few seconds" : "om få sekunder",
     "seconds ago" : "sekunder siden",
+    "File already exists" : "Filen findes allerede",
+    "Templates" : "Skabeloner",
     "File name is a reserved word" : "Filnavnet er et reserveret ord",
     "File name contains at least one invalid character" : "Filnavnet indeholder mindst ét ugyldigt tegn",
     "File name is too long" : "Filnavnet er for langt",
@@ -44,17 +48,25 @@ OC.L10N.register(
     "Empty filename is not allowed" : "Tomme filnavne er ikke tilladt",
     "App \"%s\" cannot be installed because appinfo file cannot be read." : "Appen \"%s\" kan ikke installeres fordi appinfo filen ikke kan læses.",
     "__language_name__" : "Dansk",
+    "This is an automatically sent email, please do not reply." : "Dette er en automatisk sendt e-mail, svar venligst ikke.",
     "Help" : "Hjælp",
     "Apps" : "Apps",
     "Settings" : "Indstillinger",
     "Log out" : "Log ud",
     "Users" : "Brugere",
+    "Email" : "E-mail",
+    "Phone" : "Telefon",
+    "Twitter" : "Twitter",
+    "Website" : "Hjemmeside",
+    "Address" : "Adresse",
+    "Profile picture" : "Profilbillede",
+    "About" : "Om",
+    "Full name" : "Fulde navn",
+    "Headline" : "Overskrift",
+    "Organisation" : "Organisation",
+    "Role" : "Rolle",
     "Unknown user" : "Ukendt bruger",
     "Additional settings" : "Yderligere indstillinger",
-    "%s enter the database username and name." : "%s indtast brugernavn og navn til databasen.",
-    "%s enter the database username." : "%s indtast database brugernavnet.",
-    "%s enter the database name." : "%s indtast database navnet.",
-    "%s you may not use dots in the database name" : "%s du må ikke bruge punktummer i databasenavnet.",
     "Oracle connection could not be established" : "Oracle forbindelsen kunne ikke etableres",
     "Oracle username and/or password not valid" : "Oracle brugernavn og/eller kodeord er ikke gyldigt.",
     "PostgreSQL username and/or password not valid" : "PostgreSQL brugernavn og/eller kodeord er ikke gyldigt.",
@@ -70,7 +82,9 @@ OC.L10N.register(
     "Open »%s«" : "Åbn »%s«",
     "%1$s via %2$s" : "%1$s via %2$s",
     "You are not allowed to share %s" : "Du har ikke tilladelse til at dele %s",
+    "Cannot increase permissions of %s" : "Kan give yderigere rettigheder til %s",
     "Expiration date is in the past" : "Udløbsdatoen ligger tilbage i tid",
+    "Sharing %s failed, because this item is already shared with user %s" : "Deling af %s mislykkedes, fordi dette element allerede er delt med brugeren %s",
     "Click the button below to open it." : "Klik på knappen nedenunder for at åbne.",
     "Could not find category \"%s\"" : "Kunne ikke finde kategorien \"%s\"",
     "Sunday" : "Søndag",
@@ -143,10 +157,10 @@ OC.L10N.register(
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Tilpas venligst rettigheder til 0770, så mappen ikke fremvises for andre brugere.",
     "Could not obtain lock type %d on \"%s\"." : "Kunne ikke opnå en låsetype %d på \"%s\".",
     "Storage is temporarily not available" : "Lagerplads er midlertidigt ikke tilgængeligt",
-    "This can usually be fixed by giving the webserver write access to the config directory" : "Dette kan som regel ordnes ved at give webserveren skrive adgang til config mappen",
-    "Can't create or write into the data directory %s" : "Kan ikke oprette eller skrive ind i datamappen %s",
-    "Invalid Federated Cloud ID" : "Ugyldigt Federated Cloud ID",
-    "Can't read file" : "Kan ikke læse filen",
+    "%s enter the database username and name." : "%s indtast brugernavn og navn til databasen.",
+    "%s enter the database username." : "%s indtast database brugernavnet.",
+    "%s enter the database name." : "%s indtast database navnet.",
+    "%s you may not use dots in the database name" : "%s du må ikke bruge punktummer i databasenavnet.",
     "Cannot write into \"config\" directory" : "Kan ikke skrive til mappen \"config\"",
     "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Dette kan som regel ordnes ved at give webserveren skrive adgang til config mappen. Se %s",
     "Cannot write into \"apps\" directory" : "Kan ikke skrive til mappen \"apps\"",
