@@ -90,7 +90,10 @@ OC.L10N.register(
     "__language_name__" : "Deutsch (Förmlich: Sie)",
     "This is an automatically sent email, please do not reply." : "Dies ist eine automatisch versandte E-Mail, bitte nicht antworten.",
     "Help" : "Hilfe",
+    "Appearance and accessibility" : "Aussehen und Zugänglichkeit",
     "Apps" : "Apps",
+    "Personal settings" : "Persönliche Einstellungen",
+    "Administration settings" : "Administrationseinstellungen",
     "Settings" : "Einstellungen",
     "Log out" : "Abmelden",
     "Users" : "Benutzer",
@@ -111,10 +114,10 @@ OC.L10N.register(
     "Role" : "Funktion",
     "Unknown user" : "Unbekannter Benutzer",
     "Additional settings" : "Zusätzliche Einstellungen",
-    "%s enter the database username and name." : "%s geben Sie den Datenbank-Benutzernamen  und den Datenbanknamen an.",
-    "%s enter the database username." : "%s geben Sie den Datenbank-Benutzernamen an.",
-    "%s enter the database name." : "%s geben Sie den Datenbanknamen an.",
-    "%s you may not use dots in the database name" : "%s Der Datenbankname darf keine Punkte enthalten",
+    "Enter the database username and name for %s" : "Den Datenbankbenutzernamen und den Namen eingeben für %s",
+    "Enter the database username for %s" : "Den Datenbankbenutzernamen eingeben für %s",
+    "Enter the database name for %s" : "Den Datenbanknamen eingeben für %s",
+    "You cannot use dots in the database name %s" : "Sie dürfen keine Punkte im Datenbanknamen %s verwenden",
     "MySQL username and/or password not valid" : "MySQL-Benutzername und/oder Passwort ungültig",
     "You need to enter details of an existing account." : "Sie müssen Details von einem existierenden Benutzer einfügen.",
     "Oracle connection could not be established" : "Es konnte keine Verbindung zur Oracle-Datenbank hergestellt werden",
@@ -124,8 +127,8 @@ OC.L10N.register(
     "For the best results, please consider using a GNU/Linux server instead." : "Zur Gewährleistung eines optimalen Betriebs sollte stattdessen ein GNU/Linux-Server verwendet werden.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Es scheint, dass diese %s-Instanz unter einer 32-Bit-PHP-Umgebung läuft und open_basedir in der Datei php.ini konfiguriert worden ist. Von einem solchen Betrieb wird dringend abgeraten, weil es dabei zu Problemen mit Dateien kommt, deren Größe 4 GB übersteigt.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Bitte entfernen Sie die open_basedir-Einstellung in Ihrer php.ini oder wechseln Sie zu 64-Bit-PHP.",
-    "Set an admin username." : "Einen Administrator-Benutzernamen setzen.",
-    "Set an admin password." : "Ein Administrator-Passwort setzen.",
+    "Set an admin username." : "Einen Administrations-Benutzernamen setzen.",
+    "Set an admin password." : "Ein Administrationspasswort setzen.",
     "Cannot create or write into the data directory %s" : "Das Datenverzeichnis %s kann nicht erstellt oder es kann darin nicht geschrieben werden.",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Freigabe-Backend %s muss in der OCP\\Share_Backend - Schnittstelle implementiert werden",
     "Sharing backend %s not found" : "Freigabe-Backend %s nicht gefunden",
@@ -206,8 +209,8 @@ OC.L10N.register(
     "Login canceled by app" : "Anmeldung durch die App abgebrochen",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Die App „%1$s“ kann nicht installiert werden, da die folgenden Abhängigkeiten nicht erfüllt sind: %2$s",
     "a safe home for all your data" : "ein sicherer Ort für all Ihre Daten",
-    "File is currently busy, please try again later" : "Die Datei ist in Benutzung, bitte versuchen Sie es später noch einmal",
-    "Cannot read file" : "Datei kann nicht gelesen werden",
+    "File is currently busy, please try again later" : "Die Datei ist in Benutzung, bitte später erneut versuchen.",
+    "Cannot download file" : "Datei kann nicht heruntergeladen werden",
     "Application is not enabled" : "Die Anwendung ist nicht aktiviert",
     "Authentication error" : "Authentifizierungsfehler",
     "Token expired. Please reload page." : "Token abgelaufen. Bitte laden Sie die Seite neu.",
@@ -224,7 +227,7 @@ OC.L10N.register(
     "Setting locale to %s failed." : "Das Setzen der Sprache (locale) auf %s ist fehlgeschlagen.",
     "Please install one of these locales on your system and restart your web server." : "Bitte installieren Sie eine dieser Sprachen (locales) auf Ihrem System und starten Sie den Webserver neu.",
     "PHP module %s not installed." : "PHP-Modul %s nicht installiert.",
-    "Please ask your server administrator to install the module." : "Bitte kontaktieren Sie Ihren Server-Administrator und bitten Sie um die Installation des Moduls.",
+    "Please ask your server administrator to install the module." : "Bitte kontaktieren Sie Ihre Server-Administration und bitten Sie um die Installation des Moduls.",
     "PHP setting \"%s\" is not set to \"%s\"." : "PHP-Einstellung „%s“ ist nicht auf „%s“ gesetzt.",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "Eine Änderung dieser Einstellung in der php.ini kann Ihre Nextcloud wieder lauffähig machen.",
     "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> ist auf <code>%s</code> gesetzt und nicht auf den erwarteten Wert <code>0</code>.",
@@ -234,7 +237,9 @@ OC.L10N.register(
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP ist offenbar so konfiguriert, dass PHPDoc-Blöcke in der Anweisung entfernt werden. Dadurch sind mehrere Kern-Apps nicht erreichbar.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Dies wird wahrscheinlich durch Zwischenspeicher/Beschleuniger wie etwa Zend OPcache oder eAccelerator verursacht.",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP-Module wurden installiert, werden aber als noch fehlend gelistet?",
-    "Please ask your server administrator to restart the web server." : "Bitte kontaktieren Sie Ihren Server-Administrator und bitten Sie um den Neustart des Webservers.",
+    "Please ask your server administrator to restart the web server." : "Bitte kontaktieren Sie Ihre Server-Administration und bitten Sie um den Neustart des Webservers.",
+    "The required %s config variable is not configured in the config.php file." : "Die erforderliche %s Konfigurationsvariable ist in der config.php nicht konfiguriert.",
+    "Please ask your server administrator to check the Nextcloud configuration." : "Bitten Sie Ihre Server-Administration, die Nextcloud-Konfiguration zu überprüfen.",
     "PostgreSQL >= 9 required." : "PostgreSQL >= 9 benötigt.",
     "Please upgrade your database version." : "Bitte aktualisieren Sie Ihre Datenbankversion.",
     "Your data directory is readable by other users." : "Ihr Datenverzeichnis kann von anderen Benutzern gelesen werden.",
@@ -254,20 +259,16 @@ OC.L10N.register(
     "Storage connection error. %s" : "Verbindungsfehler zum Speicherplatz. %s",
     "Storage is temporarily not available" : "Speicher ist vorübergehend nicht verfügbar",
     "Storage connection timeout. %s" : "Zeitüberschreitung der Verbindung zum Speicherplatz. %s",
-    "This can usually be fixed by giving the webserver write access to the config directory" : "Dies kann normalerweise repariert werden, indem dem Webserver Schreibzugriff auf das config-Verzeichnis gegeben wird",
-    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Oder wenn Sie möchten, dass die Datei config.php schreibgeschützt bleiben soll, dann setzen Sie die Option \"config_is_read_only\" in der Datei auf True.",
     "This can usually be fixed by giving the webserver write access to the config directory." : "Dies kann normalerweise behoben werden, indem dem Webserver Schreibzugriff auf das config-Verzeichnis gegeben wird.",
-    "Can't create or write into the data directory %s" : "Das Datenverzeichnis %s kann nicht erstellt oder es kann darin nicht geschrieben werden.",
-    "Invalid Federated Cloud ID" : "Ungültige Federated-Cloud-ID",
-    "Can’t increase permissions of %s" : "Kann die Berechtigungen von %s nicht erhöhen",
-    "Files can’t be shared with delete permissions" : "Dateien mit Lösch-Berechtigungen können nicht geteilt werden",
-    "Files can’t be shared with create permissions" : "Dateien mit Erstell-Berechtigungen können nicht geteilt werden",
-    "Can’t set expiration date more than %s days in the future" : "Das Ablaufdatum kann nicht mehr als %s Tage in der Zukunft liegen",
-    "Can't read file" : "Datei kann nicht gelesen werden",
+    "%s enter the database username and name." : "%s geben Sie den Datenbank-Benutzernamen  und den Datenbanknamen an.",
+    "%s enter the database username." : "%s geben Sie den Datenbank-Benutzernamen an.",
+    "%s enter the database name." : "%s geben Sie den Datenbanknamen an.",
+    "%s you may not use dots in the database name" : "%s Der Datenbankname darf keine Punkte enthalten",
+    "Cannot read file" : "Datei kann nicht gelesen werden",
     "Cannot write into \"config\" directory" : "Schreiben in das „config“-Verzeichnis ist nicht möglich",
     "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Dies kann zumeist behoben werden, indem dem Web-Server Schreibzugriff auf das Konfigurationsverzeichnis eingeräumt wird. Siehe auch %s",
     "Cannot write into \"apps\" directory" : "Schreiben in das „apps“-Verzeichnis ist nicht möglich",
-    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the appstore in the config file." : "Dies kann normalerweise behoben werden, indem dem Webserver Schreibzugriff auf das App-Verzeichnis gegeben wird oder der App Store in der Konfigurationsdatei deaktiviert wird.",
+    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the App Store in the config file." : "Dies kann normalerweise behoben werden, indem dem Webserver Schreibzugriff auf das App-Verzeichnis gegeben wird oder der App-Store in der Konfigurationsdatei deaktiviert wird.",
     "Cannot create \"data\" directory" : "Kann das \"Daten\"-Verzeichnis nicht erstellen.",
     "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "Dies kann zumeist behoben werden, indem dem Web-Server Schreibzugriff auf das Wurzel-Verzeichnis eingeräumt wird. Siehe auch %s",
     "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "Berechtigungen können zumeist korrigiert werden indem dem Web-Server Schreibzugriff auf das Wurzel-Verzeichnis eingeräumt wird. Siehe auch %s. ",
@@ -280,7 +281,6 @@ OC.L10N.register(
     "Your data directory is readable by other users" : "Ihr Datenverzeichnis kann von anderen Benutzern gelesen werden",
     "Your data directory must be an absolute path" : "Ihr Datenverzeichnis muss einen eindeutigen Pfad haben",
     "Check the value of \"datadirectory\" in your configuration" : "Überprüfen Sie bitte die Angabe unter „datadirectory“ in Ihrer Konfiguration",
-    "Your data directory is invalid" : "Ihr Datenverzeichnis ist ungültig.",
-    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the App Store in the config file." : "Dies kann normalerweise behoben werden, indem dem Webserver Schreibzugriff auf das App-Verzeichnis gegeben wird oder der App-Store in der Konfigurationsdatei deaktiviert wird."
+    "Your data directory is invalid" : "Ihr Datenverzeichnis ist ungültig."
 },
 "nplurals=2; plural=(n != 1);");
