@@ -42,6 +42,7 @@ OC.L10N.register(
     "Unknown filetype" : "نوع فایل ناشناخته",
     "Invalid image" : "عکس نامعتبر",
     "Avatar image is not square" : "تصویر آواتار مربع نیست",
+    "View profile" : "مشاهده پروفایل",
     "today" : "امروز",
     "tomorrow" : "فردا",
     "yesterday" : "دیروز",
@@ -58,6 +59,7 @@ OC.L10N.register(
     "seconds ago" : "ثانیه‌ها پیش",
     "Empty file" : "پرونده خالی",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "ماژول با شناسه:%s وجود ندارد. لطفاً آن را در تنظیمات برنامه خود فعال کنید یا با سرپرست خود تماس بگیرید",
+    "File already exists" : "پرونده از قبل موجود است",
     "File name is a reserved word" : "این نام فایل جزو کلمات رزرو می‌باشد",
     "File name contains at least one invalid character" : "نام فایل دارای حداقل یک کاراکتر نامعتبر است",
     "File name is too long" : "نام فایل خیلی بزرگ است",
@@ -72,12 +74,18 @@ OC.L10N.register(
     "Settings" : "تنظیمات",
     "Log out" : "خروج",
     "Users" : "کاربران",
+    "Email" : "رایانامه",
+    "Phone" : "شماره تلفن",
+    "Twitter" : "توییتر",
+    "Website" : "وب‌ سایت",
+    "Address" : "نشانی",
+    "Profile picture" : "تصویر پروفایل",
+    "About" : "درباره",
+    "Full name" : "نام کامل",
+    "Headline" : "عنوان",
+    "Role" : "نقش",
     "Unknown user" : "کاربر نامعلوم",
     "Additional settings" : "تنظیمات اضافی",
-    "%s enter the database username and name." : "نام کاربری و نام پایگاه داده را وارد کنید.%s",
-    "%s enter the database username." : "%s نام کاربری پایگاه داده را وارد نمایید.",
-    "%s enter the database name." : "%s نام پایگاه داده را وارد نمایید.",
-    "%s you may not use dots in the database name" : "%s شما نباید از نقطه در نام پایگاه داده استفاده نمایید.",
     "You need to enter details of an existing account." : "شما باید جزئیات یک حساب موجود را وارد کنید.",
     "Oracle connection could not be established" : "ارتباط اراکل نمیتواند برقرار باشد.",
     "Oracle username and/or password not valid" : "نام کاربری و / یا رمزعبور اراکل معتبر نیست.",
@@ -125,7 +133,7 @@ OC.L10N.register(
     "Fr" : "جمعه",
     "Sa" : "شنبه",
     "January" : "ژانویه",
-    "February" : "فبریه",
+    "February" : "فوریه",
     "March" : "مارس",
     "April" : "آوریل",
     "May" : "می",
@@ -188,15 +196,10 @@ OC.L10N.register(
     "Storage connection error. %s" : "خطای اتصال ذخیره سازی%s",
     "Storage is temporarily not available" : "ذخیره سازی به طور موقت در دسترس نیست",
     "Storage connection timeout. %s" : "مدت زمان اتصال ذخیره سازی%s",
-    "This can usually be fixed by giving the webserver write access to the config directory" : "این امر معمولاً با دسترسی به نوشتن وب سرور به فهرست تنظیمات قابل حل است",
-    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "یا اگر ترجیح می دهید پرونده config.php را فقط بخوانید ، گزینه \"config_is_read_only\" را در آن تنظیم کنید.",
-    "Can't create or write into the data directory %s" : "%sنمی توانید در فهرست داده ایجاد یا نوشتن کنید",
-    "Invalid Federated Cloud ID" : "شناسه فدرال شده با ابر Cloud",
-    "Can’t increase permissions of %s" : "مجوزها را نمی توان افزایش داد%s",
-    "Files can’t be shared with delete permissions" : "فایلها را نمی توان با مجوزهای حذف حذف کرد",
-    "Files can’t be shared with create permissions" : "فایلها را نمی توان با ایجاد مجوزها به اشتراک گذاشت",
-    "Can’t set expiration date more than %s days in the future" : "نمی توان تاریخ انقضا را بیش%s از روزها در آینده تعیین کرد",
-    "Can't read file" : "امکان خواندن فایل وجود ندارد",
+    "%s enter the database username and name." : "نام کاربری و نام پایگاه داده را وارد کنید.%s",
+    "%s enter the database username." : "%s نام کاربری پایگاه داده را وارد نمایید.",
+    "%s enter the database name." : "%s نام پایگاه داده را وارد نمایید.",
+    "%s you may not use dots in the database name" : "%s شما نباید از نقطه در نام پایگاه داده استفاده نمایید.",
     "Cannot write into \"config\" directory" : "امکان نوشتن درون شاخه‌ی \"config\" وجود ندارد",
     "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "%sاین امر معمولاً با دسترسی به نوشتن وب سرور به فهرست تنظیمات قابل حل است. دیدن",
     "Cannot write into \"apps\" directory" : "نمی توان در فهرست \"برنامه ها\" نوشت",
