@@ -2,12 +2,11 @@ OC.L10N.register(
     "lib",
     {
     "Cannot write into \"config\" directory!" : "\"config\" 디렉터리에 기록할 수 없습니다!",
-    "This can usually be fixed by giving the webserver write access to the config directory" : "config 디렉터리에 웹 서버 쓰기 권한을 부여해서 해결할 수 있습니다",
     "See %s" : "%s 보기",
-    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "config 디렉터리에 웹 서버의 쓰기 권한을 부여해서 해결할 수 있습니다. %s 문서를 참조하십시오",
-    "The files of the app %$1s were not replaced correctly. Make sure it is a version compatible with the server." : "앱 %1$s의 파일이 올바르게 교체되지 않았습니다. 서버와 호환되는 버전인지 확인하십시오.",
+    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "앱 %1$s의 파일이 올바르게 교체되지 않았습니다. 서버와 호환되는 버전인지 확인하십시오.",
     "Sample configuration detected" : "예제 설정 감지됨",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "예제 설정이 복사된 것 같습니다. 올바르게 작동하지 않을 수도 있기 때문에 지원되지 않습니다. config.php를 변경하기 전 문서를 읽어 보십시오",
+    "Other activities" : "다른 활동",
     "%1$s and %2$s" : "%1$s 및 %2$s",
     "%1$s, %2$s and %3$s" : "%1$s, %2$s 및 %3$s",
     "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s 및 %4$s",
@@ -19,17 +18,21 @@ OC.L10N.register(
     "PHP %s or higher is required." : "PHP 버전 %s 이상이 필요합니다.",
     "PHP with a version lower than %s is required." : "PHP 버전 %s 미만이 필요합니다.",
     "%sbit or higher PHP required." : "%s비트 이상의 PHP가 필요합니다.",
-    "Following databases are supported: %s" : "다음 데이터베이스를 지원합니다: %s",
     "The command line tool %s could not be found" : "명령행 도구 %s을(를) 찾을 수 없습니다",
     "The library %s is not available." : "%s 라이브러리를 사용할 수 없습니다.",
-    "Library %s with a version higher than %s is required - available version %s." : "%s 라이브러리의 버전 %s 이상이 필요합니다. 사용 가능한 버전은 %s입니다.",
-    "Library %s with a version lower than %s is required - available version %s." : "%s 라이브러리의 버전 %s 미만이 필요합니다. 사용 가능한 버전은 %s입니다.",
-    "Following platforms are supported: %s" : "다음 플랫폼을 지원합니다: %s",
+    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "%1$s 라이브러리의 버전 %2$s 이상이 필요합니다. 사용 가능한 버전은 %3$s입니다.",
+    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "%1$s 라이브러리의 버전 %2$s 이상이 필요합니다. 사용 가능한 버전은 %3$s입니다.",
     "Server version %s or higher is required." : "서버 버전 %s 이상이 필요합니다.",
     "Server version %s or lower is required." : "서버 버전 %s 미만이 필요합니다.",
+    "Logged in user must be an admin or sub admin" : "로그인한 사용자는 관리자 또는 부 관리자여야 합니다.",
+    "Logged in user must be an admin" : "로그인한 사용자는 관리자여야 합니다.",
+    "Wiping of device %s has started" : "디바이스 %s의 완전 삭제가 시작되었습니다.",
+    "Wiping of device »%s« has started" : "디바이스 »%s«의 완전 삭제가 시작되었습니다.",
+    "Authentication" : "인증",
     "Unknown filetype" : "알 수 없는 파일 형식",
     "Invalid image" : "잘못된 사진",
     "Avatar image is not square" : "아바타 사진이 정사각형이 아님",
+    "View profile" : "프로파일 보기",
     "today" : "오늘",
     "tomorrow" : "내일",
     "yesterday" : "어제",
@@ -49,7 +52,10 @@ OC.L10N.register(
     "_%n minute ago_::_%n minutes ago_" : ["%n분 전"],
     "in a few seconds" : "몇 초 후",
     "seconds ago" : "초 전",
+    "Empty file" : "빈 파일",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "ID: %s인 모듈이 존재하지 않습니다. 앱 설정에서 확인하거나 시스템 관리자에게 연락하십시오.",
+    "File already exists" : "파일이 이미 있습니다.",
+    "Templates" : "템플릿",
     "File name is a reserved word" : "파일 이름이 예약된 단어임",
     "File name contains at least one invalid character" : "파일 이름에 잘못된 글자가 한 자 이상 있음",
     "File name is too long" : "파일 이름이 너무 김",
@@ -64,67 +70,39 @@ OC.L10N.register(
     "Settings" : "설정",
     "Log out" : "로그아웃",
     "Users" : "사용자",
+    "Email" : "이메일",
+    "Phone" : "전화 번호",
+    "Twitter" : "Twitter",
+    "Website" : "웹 사이트",
+    "Address" : "주소",
+    "Profile picture" : "프로필 사진",
+    "About" : "정보",
+    "Full name" : "전체 이름",
+    "Headline" : "표제",
+    "Organisation" : "조직",
+    "Role" : "직책",
     "Unknown user" : "알려지지 않은 사용자",
-    "Basic settings" : "기본 설정",
-    "Sharing" : "공유",
-    "Security" : "보안",
     "Additional settings" : "고급 설정",
-    "Personal info" : "개인 정보",
-    "Unlimited" : "무제한",
-    "Verifying" : "검사 중",
-    "Verifying …" : "검사 중…",
-    "Verify" : "검사",
-    "%s enter the database username and name." : "%s 데이터베이스 사용자 이름과 이름을 입력해 주십시오.",
-    "%s enter the database username." : "%s 데이터베이스 사용자 이름을 입력해 주십시오.",
-    "%s enter the database name." : "%s 데이터베이스 이름을 입력하십시오.",
-    "%s you may not use dots in the database name" : "%s 데이터베이스 이름에는 마침표를 사용할 수 없습니다",
+    "You need to enter details of an existing account." : "존재하는 계정 정보를 입력해야 합니다.",
     "Oracle connection could not be established" : "Oracle 연결을 수립할 수 없습니다.",
     "Oracle username and/or password not valid" : "Oracle 사용자 이름이나 암호가 잘못되었습니다.",
     "PostgreSQL username and/or password not valid" : "PostgreSQL 사용자 이름 또는 암호가 잘못되었습니다",
-    "You need to enter details of an existing account." : "존재하는 계정 정보를 입력해야 합니다.",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X은 지원하지 않으며 %s이(가) 이 플랫폼에서 올바르게 작동하지 않을 수도 있습니다. 본인 책임으로 사용하십시오! ",
     "For the best results, please consider using a GNU/Linux server instead." : "더 좋은 결과를 얻으려면 GNU/Linux 서버를 사용하는 것을 권장합니다.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "%s 인스턴스가 32비트 PHP 환경에서 실행 중이고 php.ini에 open_basedir이 설정되어 있습니다. 4GB 이상의 파일 처리에 문제가 생길 수 있으므로 추천하지 않습니다.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "php.ini의 open_basedir 설정을 삭제하거나 64비트 PHP로 전환하십시오.",
     "Set an admin username." : "관리자의 사용자 이름을 설정합니다.",
     "Set an admin password." : "관리자의 암호를 설정합니다.",
-    "Can't create or write into the data directory %s" : "데이터 디렉터리 %s을(를) 만들거나 기록할 수 없음",
-    "Invalid Federated Cloud ID" : "잘못된 연합 클라우드 ID",
-    "Sharing %s failed, because the backend does not allow shares from type %i" : "%s을(를) 공유할 수 없습니다. 백엔드에서 %i 형식의 공유를 허용하지 않습니다",
-    "Sharing %s failed, because the file does not exist" : "%s을(를) 공유할 수 없습니다. 파일이 존재하지 않습니다",
-    "You are not allowed to share %s" : "%s을(를) 공유할 수 있는 권한이 없습니다",
-    "Sharing %s failed, because you can not share with yourself" : "%s을(를) 공유할 수 없습니다. 자기 자신과 공유할 수 없습니다",
-    "Sharing %s failed, because the user %s does not exist" : "%s을(를) 공유할 수 없습니다. 사용자 %s이(가) 존재하지 않습니다",
-    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "%s을(를) 공유할 수 없습니다. 사용자 %s 님은 %s 님이 회원인 어떠한 그룹에도 속해 있지 않습니다",
-    "Sharing %s failed, because this item is already shared with %s" : "%s을(를) 공유할 수 없습니다. 이미 %s 님과 공유되어 있습니다",
-    "Sharing %s failed, because this item is already shared with user %s" : "%s을(를) 공유할 수 없습니다. 이 항목을 이미 %s 님과 공유하고 있습니다",
-    "Sharing %s failed, because the group %s does not exist" : "%s을(를) 공유할 수 없습니다. 그룹 %s이(가) 존재하지 않습니다",
-    "Sharing %s failed, because %s is not a member of the group %s" : "%s을(를) 공유할 수 없습니다. %s 님이 그룹 %s의 구성원이 아닙니다",
-    "You need to provide a password to create a public link, only protected links are allowed" : "공개 링크를 만들려면 암호를 입력해야 합니다. 보호된 링크만 사용 가능합니다",
-    "Sharing %s failed, because sharing with links is not allowed" : "%s을(를) 공유할 수 없습니다. 링크 공유가 허용되지 않았습니다",
-    "Not allowed to create a federated share with the same user" : "같은 사용자와 연합 공유를 만들 수 없음",
-    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "%s을(를) 공유할 수 없습니다. %s을(를) 찾을 수 없습니다. 서버에 접근하지 못할 수도 있습니다.",
-    "Share type %s is not valid for %s" : "공유 형식 %s을(를) %s에 대해서 사용할 수 없음",
-    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "만료 날짜를 설정할 수 없습니다. 최대 공유 허용 기한이 %s입니다.",
-    "Cannot set expiration date. Expiration date is in the past" : "만료 날짜를 설정할 수 없습니다. 만료 날짜가 과거입니다",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "공유 백엔드 %s에서 OCP\\Share_Backend 인터페이스를 구현해야 함",
     "Sharing backend %s not found" : "공유 백엔드 %s을(를) 찾을 수 없음",
     "Sharing backend for %s not found" : "%s의 공유 백엔드를 찾을 수 없음",
-    "Sharing failed, because the user %s is the original sharer" : "공유할 수 없습니다. 사용자 %s이(가) 원 공유자입니다",
-    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "%s을(를) 공유할 수 없습니다. %s 님에게 허용된 것 이상의 권한을 필요로 합니다",
-    "Sharing %s failed, because resharing is not allowed" : "%s을(를) 공유할 수 없습니다. 다시 공유할 수 없습니다",
-    "Sharing %s failed, because the sharing backend for %s could not find its source" : "%s을(를) 공유할 수 없습니다. %s의 공유 백엔드에서 원본 파일을 찾을 수 없습니다",
-    "Sharing %s failed, because the file could not be found in the file cache" : "%s을(를) 공유할 수 없습니다. 파일 캐시에서 찾을 수 없습니다",
     "Open »%s«" : "%s 열기",
-    "Can’t increase permissions of %s" : "%s의 권한을 늘릴 수 없습니다",
-    "Files can’t be shared with delete permissions" : "파일을 삭제 권한으로 공유할 수 없습니다",
-    "Files can’t be shared with create permissions" : "파일을 생성 권한으로 공유할 수 없습니다",
+    "%1$s via %2$s" : "%1$s(%2$s 경유)",
+    "You are not allowed to share %s" : "%s을(를) 공유할 수 있는 권한이 없습니다",
+    "Cannot increase permissions of %s" : "%s의 권한을 늘릴 수 없습니다",
     "Expiration date is in the past" : "만료 날짜가 과거입니다",
-    "Can’t set expiration date more than %s days in the future" : "만료 날짜를 %s일 이상 이후로 설정할 수 없습니다",
-    "%s shared »%s« with you" : "%s 님이 %s을(를) 공유했습니다",
-    "%s shared »%s« with you." : "%s 님이 %s을(를) 공유했습니다.",
+    "Sharing %s failed, because this item is already shared with user %s" : "%s을(를) 공유할 수 없습니다. 이 항목을 이미 %s 님과 공유하고 있습니다",
     "Click the button below to open it." : "아래 단추를 눌러서 열 수 있습니다.",
-    "%s via %s" : "%s(%s 경유)",
     "The requested share does not exist anymore" : "요청한 공유가 더 이상 존재하지 않습니다",
     "Could not find category \"%s\"" : "분류 \"%s\"을(를) 찾을 수 없습니다",
     "Sunday" : "일요일",
@@ -176,71 +154,57 @@ OC.L10N.register(
     "A valid username must be provided" : "올바른 사용자 이름을 입력해야 합니다",
     "Username contains whitespace at the beginning or at the end" : "사용자 이름의 시작이나 끝에 공백이 있습니다",
     "Username must not consist of dots only" : "사용자 이름에 마침표만 있으면 안 됩니다",
+    "Username is invalid because files already exist for this user" : "무효한 사용자이름. 이미 존재함",
     "A valid password must be provided" : "올바른 암호를 입력해야 합니다",
     "The username is already being used" : "사용자 이름이 이미 존재합니다",
     "Could not create user" : "사용자를 만들 수 없습니다",
     "User disabled" : "사용자 비활성화됨",
     "Login canceled by app" : "앱에서 로그인 취소함",
-    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "앱 \"%s\"의 다음 의존성을 만족하지 못하므로 설치할 수 없습니다: %s",
     "a safe home for all your data" : "내 모든 데이터의 안전한 저장소",
     "File is currently busy, please try again later" : "파일이 현재 사용 중, 나중에 다시 시도하십시오",
-    "Can't read file" : "파일을 읽을 수 없음",
     "Application is not enabled" : "앱이 활성화되지 않았습니다",
     "Authentication error" : "인증 오류",
     "Token expired. Please reload page." : "토큰이 만료되었습니다. 페이지를 새로 고치십시오.",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "데이터베이스 드라이버(sqlite, mysql, postgresql)가 설치되지 않았습니다.",
-    "Cannot write into \"config\" directory" : "\"config\" 디렉터리에 기록할 수 없습니다",
-    "Cannot write into \"apps\" directory" : "\"apps\" 디렉터리에 기록할 수 없습니다",
-    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the appstore in the config file. See %s" : "apps 디렉터리에 웹 서버의 쓰기 권한을 부여하거나 설정에서 앱 스토어를 비활성화해서 해결할 수 있습니다. %s 문서를 참조하십시오",
-    "Cannot create \"data\" directory" : "\"data\" 디렉터리를 만들 수 없음",
-    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "루트 디렉터리에 웹 서버의 쓰기 권한을 부여해서 해결할 수 있습니다. %s 문서를 참조하십시오",
-    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "루트 디렉터리에 웹 서버의 쓰기 권한을 부여해서 해결할 수 있습니다. %s 문서를 참조하십시오.",
-    "Setting locale to %s failed" : "로캘을 %s(으)로 설정할 수 없음",
-    "Please install one of these locales on your system and restart your webserver." : "다음 중 하나 이상의 로캘을 시스템에 설치하고 웹 서버를 다시 시작하십시오.",
-    "Please ask your server administrator to install the module." : "서버 관리자에게 모듈 설치를 요청하십시오.",
+    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "config.php 파일을 읽기 전용으로 하시려는 경우, 설정의 \"config_is_read_only\"를 true로 하십시오. %s를 참조하십시오.",
     "PHP module %s not installed." : "PHP 모듈 %s이(가) 설치되지 않았습니다.",
+    "Please ask your server administrator to install the module." : "서버 관리자에게 모듈 설치를 요청하십시오.",
     "PHP setting \"%s\" is not set to \"%s\"." : "PHP 설정 \"%s\"이(가) \"%s\"(으)로 설정되어 있지 않습니다.",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "php.ini 파일에서 설정을 변경하면 Nextcloud가 다시 실행됩니다",
-    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload 값이 \"%s\"(으)로 설정되어 있으나 \"0\"으로 설정해야 함",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "이 문제를 해결하려면 php.ini에서 <code>mbstring.func_overload</code> 값을 <code>0</code>으로 설정하십시오",
     "libxml2 2.7.0 is at least required. Currently %s is installed." : "libxml2 2.7.0 이상이 필요합니다. 현재 버전은 %s입니다.",
     "To fix this issue update your libxml2 version and restart your web server." : "이 문제를 해결하려면 libxml2 버전을 업데이트하고 웹 서버를 다시 시작하십시오.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP에서 인라인 문서 블록을 삭제하도록 설정되어 있습니다. 일부 코어 앱을 사용하지 못할 수도 있습니다.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Zend OPcache, eAccelerator 같은 캐시/가속기 문제일 수도 있습니다.",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP 모듈이 설치되었지만 여전히 없는 것으로 나타납니까?",
     "Please ask your server administrator to restart the web server." : "서버 관리자에게 웹 서버 재시작을 요청하십시오.",
-    "PostgreSQL >= 9 required" : "PostgreSQL 버전 9 이상이 필요합니다",
-    "Please upgrade your database version" : "데이터베이스 버전을 업그레이드 하십시오",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "권한을 0770으로 변경하여 다른 사용자가 읽을 수 없도록 하십시오.",
-    "Your data directory is readable by other users" : "내 데이터 디렉터리를 다른 사용자가 읽을 수 있음",
-    "Your data directory must be an absolute path" : "내 데이터 디렉터리는 절대 경로여야 함",
-    "Check the value of \"datadirectory\" in your configuration" : "설정 중 \"datadirectory\" 값을 확인하십시오",
-    "Your data directory is invalid" : "내 데이터 디렉터리가 잘못됨",
     "Ensure there is a file called \".ocdata\" in the root of the data directory." : "데이터 디렉터리의 최상위 디렉터리에 \".ocdata\" 파일이 있는지 확인하십시오.",
+    "Authentication failed, wrong token or provider ID given" : "인증이 실패하였습니다. 토큰이나 프로바이더 ID가 틀렸습니다.",
     "Could not obtain lock type %d on \"%s\"." : "잠금 형식 %d을(를) \"%s\"에 대해 얻을 수 없습니다.",
     "Storage unauthorized. %s" : "저장소가 인증되지 않았습니다. %s",
     "Storage incomplete configuration. %s" : "저장소 설정이 완전하지 않습니다. %s",
     "Storage connection error. %s" : "저장소 연결 오류입니다. %s",
     "Storage is temporarily not available" : "저장소를 임시로 사용할 수 없음",
     "Storage connection timeout. %s" : "저장소 연결 시간이 초과되었습니다. %s",
-    "Personal" : "개인",
-    "Admin" : "관리자",
-    "APCu" : "APCu",
-    "Redis" : "Redis",
-    "Encryption" : "암호화",
-    "Tips & tricks" : "팁과 추가 정보",
-    "DB Error: \"%s\"" : "DB 오류: \"%s\"",
-    "Offending command was: \"%s\"" : "잘못된 명령: \"%s\"",
-    "Offending command was: \"%s\", name: %s, password: %s" : "잘못된 명령: \"%s\", 이름: %s, 암호: %s",
-    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "%s의 권한을 설정할 수 없습니다. %s 님에게 허용된 것 이상의 권한을 필요로 합니다",
-    "Setting permissions for %s failed, because the item was not found" : "%s의 권한을 설정할 수 없습니다. 항목을 찾을 수 없습니다",
-    "Cannot clear expiration date. Shares are required to have an expiration date." : "만료 날짜를 비워 둘 수 없습니다. 공유되는 항목에는 만료 날짜가 필요합니다.",
-    "Cannot increase permissions of %s" : "%s의 권한을 늘릴 수 없습니다",
-    "Files can't be shared with delete permissions" : "파일을 삭제 권한으로 공유할 수 없습니다",
-    "Files can't be shared with create permissions" : "파일을 생성 권한으로 공유할 수 없습니다",
-    "Cannot set expiration date more than %s days in the future" : "만료 날짜를 %s일 이상 이후로 설정할 수 없습니다",
-    "No app name specified" : "앱 이름이 지정되지 않았음",
-    "App '%s' could not be installed!" : "앱 '%s'을(를) 설치할 수 없습니다!",
-    "Sync clients" : "동기화 클라이언트"
+    "%s enter the database username and name." : "%s 데이터베이스 사용자 이름과 이름을 입력해 주십시오.",
+    "%s enter the database username." : "%s 데이터베이스 사용자 이름을 입력해 주십시오.",
+    "%s enter the database name." : "%s 데이터베이스 이름을 입력하십시오.",
+    "%s you may not use dots in the database name" : "%s 데이터베이스 이름에는 마침표를 사용할 수 없습니다",
+    "Cannot write into \"config\" directory" : "\"config\" 디렉터리에 기록할 수 없습니다",
+    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "config 디렉터리에 웹 서버의 쓰기 권한을 부여해서 해결할 수 있습니다. %s 문서를 참조하십시오",
+    "Cannot write into \"apps\" directory" : "\"apps\" 디렉터리에 기록할 수 없습니다",
+    "Cannot create \"data\" directory" : "\"data\" 디렉터리를 만들 수 없음",
+    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "루트 디렉터리에 웹 서버의 쓰기 권한을 부여해서 해결할 수 있습니다. %s 문서를 참조하십시오",
+    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "루트 디렉터리에 웹 서버의 쓰기 권한을 부여해서 해결할 수 있습니다. %s 문서를 참조하십시오.",
+    "Setting locale to %s failed" : "로캘을 %s(으)로 설정할 수 없음",
+    "Please install one of these locales on your system and restart your webserver." : "다음 중 하나 이상의 로캘을 시스템에 설치하고 웹 서버를 다시 시작하십시오.",
+    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload 값이 \"%s\"(으)로 설정되어 있으나 \"0\"으로 설정해야 함",
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "이 문제를 해결하려면 php.ini에서 <code>mbstring.func_overload</code> 값을 <code>0</code>으로 설정하십시오",
+    "PostgreSQL >= 9 required" : "PostgreSQL 버전 9 이상이 필요합니다",
+    "Please upgrade your database version" : "데이터베이스 버전을 업그레이드 하십시오",
+    "Your data directory is readable by other users" : "내 데이터 디렉터리를 다른 사용자가 읽을 수 있음",
+    "Your data directory must be an absolute path" : "내 데이터 디렉터리는 절대 경로여야 함",
+    "Check the value of \"datadirectory\" in your configuration" : "설정 중 \"datadirectory\" 값을 확인하십시오",
+    "Your data directory is invalid" : "내 데이터 디렉터리가 잘못됨"
 },
 "nplurals=1; plural=0;");
