@@ -58,20 +58,20 @@ OC.L10N.register(
     "today" : "hoje",
     "tomorrow" : "amanhã",
     "yesterday" : "ontem",
-    "_in %n day_::_in %n days_" : ["em %n dia","em %n dias"],
-    "_%n day ago_::_%n days ago_" : ["%n dia atrás","%n dias atrás"],
+    "_in %n day_::_in %n days_" : ["em %n dia","em %n dias","em %n dias"],
+    "_%n day ago_::_%n days ago_" : ["%n dia atrás","%n dias atrás","%n dias atrás"],
     "next month" : "Mês que vem",
     "last month" : "último mês",
-    "_in %n month_::_in %n months_" : ["em %n mês","em %n meses"],
-    "_%n month ago_::_%n months ago_" : ["há %n mês atrás","há %n meses"],
+    "_in %n month_::_in %n months_" : ["em %n mês","em %n meses","em %n meses"],
+    "_%n month ago_::_%n months ago_" : ["há %n mês atrás","há %n meses","há %n meses"],
     "next year" : "ano que vem",
     "last year" : "último ano",
-    "_in %n year_::_in %n years_" : ["em %n ano","em %n anos"],
-    "_%n year ago_::_%n years ago_" : ["%n ano atrás","%n anos atrás"],
-    "_in %n hour_::_in %n hours_" : ["em %n hora","em %n horas"],
-    "_%n hour ago_::_%n hours ago_" : ["há %n hora atrás","há %n horas"],
-    "_in %n minute_::_in %n minutes_" : ["em %n minuto","em %n minutos"],
-    "_%n minute ago_::_%n minutes ago_" : ["há %n minuto atrás","há %n minutos"],
+    "_in %n year_::_in %n years_" : ["em %n ano","em %n anos","em %n anos"],
+    "_%n year ago_::_%n years ago_" : ["%n ano atrás","%n anos atrás","%n anos atrás"],
+    "_in %n hour_::_in %n hours_" : ["em %n hora","em %n horas","em %n horas"],
+    "_%n hour ago_::_%n hours ago_" : ["há %n hora atrás","há %n horas","há %n horas"],
+    "_in %n minute_::_in %n minutes_" : ["em %n minuto","em %n minutos","em %n minutos"],
+    "_%n minute ago_::_%n minutes ago_" : ["há %n minuto atrás","há %n minutos","há %n minutos"],
     "in a few seconds" : "Em alguns segundos",
     "seconds ago" : "segundos atrás",
     "Empty file" : "Arquivo vazio",
@@ -90,7 +90,10 @@ OC.L10N.register(
     "__language_name__" : "Português Brasileiro",
     "This is an automatically sent email, please do not reply." : "Este e-mail é enviado automaticamente. Por favor, não responda.",
     "Help" : "Ajuda",
+    "Appearance and accessibility" : "Aparência e acessibilidade",
     "Apps" : "Aplicativos",
+    "Personal settings" : "Configurações pessoais",
+    "Administration settings" : "Configurações de administração",
     "Settings" : "Configurações",
     "Log out" : "Sair",
     "Users" : "Usuários",
@@ -111,10 +114,10 @@ OC.L10N.register(
     "Role" : "Função",
     "Unknown user" : "Usuário desconhecido",
     "Additional settings" : "Configurações adicionais",
-    "%s enter the database username and name." : "%s insira o nome de usuário e o nome do banco de dados.",
-    "%s enter the database username." : "%s insira o nome de usuário do banco de dados.",
-    "%s enter the database name." : "%s insira o nome do banco de dados.",
-    "%s you may not use dots in the database name" : "%s você não pode usar pontos no nome do banco de dados",
+    "Enter the database username and name for %s" : "Digite o nome de usuário e o nome do banco de dados para %s",
+    "Enter the database username for %s" : "Digite o nome de usuário do banco de dados para %s",
+    "Enter the database name for %s" : "Digite o nome do banco de dados para %s",
+    "You cannot use dots in the database name %s" : "Você não pode usar pontos no nome do banco de dados %s",
     "MySQL username and/or password not valid" : "Nome de usuário e/ou senha do MySQL inválidos",
     "You need to enter details of an existing account." : "Você necessita entrar detalhes de uma conta existente.",
     "Oracle connection could not be established" : "Conexão Oracle não pôde ser estabelecida",
@@ -140,7 +143,7 @@ OC.L10N.register(
     "Files cannot be shared with delete permissions" : "Arquivos não podem ser compartilhados com permissões de exclusão",
     "Files cannot be shared with create permissions" : "Arquivos não podem ser compartilhados com permissões de criação",
     "Expiration date is in the past" : "Data de expiração está no passado",
-    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Não foi possível definir a data de expiração superior que %n dias no futuro","Não foi possível definir a data de expiração superior que %n dias no futuro"],
+    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Não foi possível definir a data de expiração superior que %n dias no futuro","Não foi possível definir a data de expiração superior que %n dias no futuro","Não foi possível definir a data de expiração superior que %n dias no futuro"],
     "Sharing is only allowed with group members" : "O compartilhamento só é permitido com membros do grupo ",
     "Sharing %s failed, because this item is already shared with user %s" : "Compartilhamento %s falhou, porque este item já está compartilhado com o usuário %s",
     "%1$s shared »%2$s« with you" : "%1$s compartilhou »%2$s« com você",
@@ -207,7 +210,7 @@ OC.L10N.register(
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "O aplicativo \"%1$s\" não pode ser instalado devido à estas dependências: %2$s",
     "a safe home for all your data" : "Um lar seguro para todos os seus dados",
     "File is currently busy, please try again later" : "O arquivo está ocupado, tente novamente mais tarde",
-    "Cannot read file" : "Não foi possível ler o arquivo",
+    "Cannot download file" : "Não é possível baixar o arquivo",
     "Application is not enabled" : "O aplicativo não está habilitado",
     "Authentication error" : "Erro de autenticação",
     "Token expired. Please reload page." : "O token expirou. Por favor recarregue a página.",
@@ -235,6 +238,8 @@ OC.L10N.register(
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Isso provavelmente é causado por um cache/acelerador, como Zend OPcache ou eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "Módulos do PHP foram instalados, mas eles ainda estão listados como faltantes?",
     "Please ask your server administrator to restart the web server." : "Por favor peça ao administrador do servidor para reiniciar o servidor web.",
+    "The required %s config variable is not configured in the config.php file." : "A variável %s de configuração necessária não está configurada no arquivo config.php.",
+    "Please ask your server administrator to check the Nextcloud configuration." : "Peça ao administrador do servidor para verificar a configuração do Nextcloud.",
     "PostgreSQL >= 9 required." : "PostgreSQL >= 9 é necessário.",
     "Please upgrade your database version." : "Por favor, atualize a versão do seu banco de dados.",
     "Your data directory is readable by other users." : "Seu diretório de dados pode ser lido por outros usuários.",
@@ -254,20 +259,16 @@ OC.L10N.register(
     "Storage connection error. %s" : "Erro na conexão de armazenamento. %s",
     "Storage is temporarily not available" : "Armazenamento temporariamente indisponível",
     "Storage connection timeout. %s" : "Atingido o tempo limite de conexão ao armazenamento. %s",
-    "This can usually be fixed by giving the webserver write access to the config directory" : "Isso geralmente pode ser corrigido dando o acesso de escritura ao webserver para o diretório de configuração",
-    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Ou, se você preferir manter o arquivo config.php somente para leitura, defina a opção \"config_is_read_only\" como true.",
     "This can usually be fixed by giving the webserver write access to the config directory." : "Geralmente, isso pode ser corrigido concedendo ao servidor web acesso de gravação ao diretório de configuração.",
-    "Can't create or write into the data directory %s" : "Não foi possível criar ou gravar no diretório de dados %s",
-    "Invalid Federated Cloud ID" : "ID inválida de Nuvem Federada",
-    "Can’t increase permissions of %s" : "Não posso aumentar as permissões de %s",
-    "Files can’t be shared with delete permissions" : "Os arquivos não podem ser compartilhados com permissões de exclusão",
-    "Files can’t be shared with create permissions" : "Os arquivos não podem ser compartilhados com permissões de criação",
-    "Can’t set expiration date more than %s days in the future" : "Não é possível definir a expiração mais do que %s dias no futuro",
-    "Can't read file" : "Não foi possível ler arquivo",
+    "%s enter the database username and name." : "%s insira o nome de usuário e o nome do banco de dados.",
+    "%s enter the database username." : "%s insira o nome de usuário do banco de dados.",
+    "%s enter the database name." : "%s insira o nome do banco de dados.",
+    "%s you may not use dots in the database name" : "%s você não pode usar pontos no nome do banco de dados",
+    "Cannot read file" : "Não foi possível ler o arquivo",
     "Cannot write into \"config\" directory" : "Não foi possível gravar no diretório \"config\"",
     "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Normalmente isso pode ser resolvido dando ao webserver permissão de escritura no diretório config. Veja %s",
     "Cannot write into \"apps\" directory" : "Não foi possível gravar no diretório \"apps\"",
-    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the appstore in the config file." : "Geralmente, isso pode ser corrigido concedendo ao servidor web acesso de gravação ao diretório de aplicativos ou desativando a loja de aplicativos no arquivo de configuração.",
+    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the App Store in the config file." : "Isso geralmente pode ser corrigido fornecendo ao servidor da web acesso de gravação ao diretório de aplicativos ou desativando a App Store no arquivo de configuração.",
     "Cannot create \"data\" directory" : "Não foi possível criar o diretório \"data\"",
     "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "Normalmente isso pode ser resolvido dando ao webserver permissão de escrita no diretório raiz. Veja %s",
     "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "As permissões normalmente podem ser corrigidas dando permissão de escrita do diretório raiz para o servidor web. Veja %s.",
@@ -280,7 +281,6 @@ OC.L10N.register(
     "Your data directory is readable by other users" : "O diretório de dados está legível para outros usuários",
     "Your data directory must be an absolute path" : "O diretório de dados deve ser um caminho absoluto",
     "Check the value of \"datadirectory\" in your configuration" : "Verifique o valor do \"datadirectory\" na sua configuração",
-    "Your data directory is invalid" : "Seu diretório de dados é inválido",
-    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the App Store in the config file." : "Isso geralmente pode ser corrigido fornecendo ao servidor da web acesso de gravação ao diretório de aplicativos ou desativando a App Store no arquivo de configuração."
+    "Your data directory is invalid" : "Seu diretório de dados é inválido"
 },
-"nplurals=2; plural=(n > 1);");
+"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
