@@ -2,14 +2,11 @@ OC.L10N.register(
     "lib",
     {
     "Cannot write into \"config\" directory!" : "Не могу да уписујем у „config“ директоријум!",
-    "This can usually be fixed by giving the webserver write access to the config directory" : "Ово се обично може средити давањем права веб серверу да пише у директоријум са подешавањима",
     "See %s" : "Погледајте %s",
-    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Или, ако пре желите да задржите config.php да је само за читање, поставите опцију \"config_is_read_only\" на true у њему самом.",
-    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Ово се обично може средити давањем права писања веб серверу за директоријум са подешавањима. Погледајте %s",
-    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Или, ако пре желите да задржите config.php да је само за читање, поставите опцију \"config_is_read_only\" на true у њему самом. Погледајте %s",
     "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Фајлови апликације „%1$s“ нису правилно замењени. Проверите да ли је верзија компатибилна са сервером.",
     "Sample configuration detected" : "Откривен је пример подешавања",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Откривено је да је прекопиран пример подешавања. Ово може покварити инсталацију и није подржано. Прочитајте документацију пре вршења промена у фајлу config.php",
+    "Other activities" : "Остале активности",
     "%1$s and %2$s" : "%1$s и %2$s",
     "%1$s, %2$s and %3$s" : "%1$s, %2$s и %3$s",
     "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s и %4$s",
@@ -17,16 +14,18 @@ OC.L10N.register(
     "Education Edition" : "Образовно издање",
     "Enterprise bundle" : "Комплет за предузећа",
     "Groupware bundle" : "Комплет за радне тимове",
+    "Hub bundle" : "Чвориште пакета",
     "Social sharing bundle" : "Комплет за друштвене мреже",
     "PHP %s or higher is required." : "Потребан је PHP %s или новији.",
     "PHP with a version lower than %s is required." : "Потребна је PHP верзија старија од верзије %s.",
     "%sbit or higher PHP required." : "Потребна је верзија PHP-а једнака или већа од верзије %s.",
-    "Following databases are supported: %s" : "Подржане су следеће базе података: %s",
+    "The following architectures are supported: %s" : "Подржане су следеће архитектуре: %s",
+    "The following databases are supported: %s" : "Подржане су следеће базе података: %s",
     "The command line tool %s could not be found" : "Алатку командне линије „%s“ није могуће пронаћи",
     "The library %s is not available." : "Библиотека „%s“ није доступна.",
     "Library %1$s with a version higher than %2$s is required - available version %3$s." : "Потребна је библиотека „%1$s“ верзије веће од %2$s - доступна верзија је %3$s.",
     "Library %1$s with a version lower than %2$s is required - available version %3$s." : "Потребна је библиотека „%1$s“ верзије ниже од %2$s - доступна верзија је %3$s.",
-    "Following platforms are supported: %s" : "Подржане су следеће платформе: %s",
+    "The following platforms are supported: %s" : "Подржане су следеће платформе: %s",
     "Server version %s or higher is required." : "Потребна је верзија сервера %s или виша.",
     "Server version %s or lower is required." : "Потребна је верзија сервера %s или нижа.",
     "Logged in user must be an admin or sub admin" : "Пријављени корисник мора бити администратор или подадминистратор",
@@ -47,6 +46,7 @@ OC.L10N.register(
     "Unknown filetype" : "Непознат тип фајла",
     "Invalid image" : "Неисправна слика",
     "Avatar image is not square" : "Слика аватара није квадратна",
+    "View profile" : "Погледај профил",
     "today" : "данас",
     "tomorrow" : "сутра",
     "yesterday" : "јуче",
@@ -66,7 +66,9 @@ OC.L10N.register(
     "_%n minute ago_::_%n minutes ago_" : ["пре %n минут","пре %n минута","пре %n минута"],
     "in a few seconds" : "за пар секунди",
     "seconds ago" : "пре неколико секунди",
+    "Empty file" : "Празан фајл",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Модул са идентификацијом: %s не постоји. Омогућите га у подешавањима апликација или контактирајте администратора.",
+    "File already exists" : "Фајл већ постоји",
     "File name is a reserved word" : "Назив фајла је резервисана реч",
     "File name contains at least one invalid character" : "Назив фајла садржи бар један недозвољен знак",
     "File name is too long" : "Назив фајла је предугачак",
@@ -81,31 +83,28 @@ OC.L10N.register(
     "Settings" : "Поставке",
     "Log out" : "Одјава",
     "Users" : "Корисници",
+    "Email" : "Е-пошта",
+    "Phone" : "Телефон",
+    "Twitter" : "Твитер",
+    "Website" : "Веб страна",
+    "Address" : "Адреса",
+    "Profile picture" : "Слика профила",
+    "About" : "О програму",
+    "Full name" : "Пуно име",
+    "Headline" : "Наслов",
     "Unknown user" : "Непознат корисник",
-    "Overview" : "Преглед",
-    "Basic settings" : "Основне поставке",
-    "Sharing" : "Дељење",
-    "Security" : "Безбедност",
-    "Groupware" : "Радни тимови",
     "Additional settings" : "Додатне поставке",
-    "Personal info" : "Лични подаци",
-    "Mobile & desktop" : "Мобилни и десктоп",
-    "%s enter the database username and name." : "%s унеси корисничко име базе података и име.",
-    "%s enter the database username." : "%s унеси корисничко име базе података.",
-    "%s enter the database name." : "%s унеси име базе података.",
-    "%s you may not use dots in the database name" : "%s не можете користити тачке у имену базе података",
+    "MySQL username and/or password not valid" : "MySQL корисничко име и/или лозинка нису исправни",
+    "You need to enter details of an existing account." : "Потребно је да унесете детаље постојећег налога.",
     "Oracle connection could not be established" : "Веза са базом података Oracle не може бити успостављена",
     "Oracle username and/or password not valid" : "Oracle корисничко име и/или лозинка нису исправни",
     "PostgreSQL username and/or password not valid" : "PostgreSQL корисничко име и/или лозинка нису исправни",
-    "You need to enter details of an existing account." : "Потребно је да унесете детаље постојећег налога.",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Мек ОС Икс није подржан и %s неће радити исправно на овој платформи. Користите га на сопствени ризик!",
     "For the best results, please consider using a GNU/Linux server instead." : "За најбоље резултате, размотрите употребу ГНУ/Линукс сервера.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Изгледа да %s ради у 32-битном PHP окружењу а open_basedir је подешен у php.ini фајлу. То може довести до проблема са фајловима већим од 4 GB, те стога није препоручљиво.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Уклоните open_basedir поставку из php.ini фајла или пређите на 64-битни PHP.",
     "Set an admin username." : "Поставите име за администратора.",
     "Set an admin password." : "Поставите лозинку за администратора.",
-    "Can't create or write into the data directory %s" : "Не могу креирати или уписивати у директоријум података %s",
-    "Invalid Federated Cloud ID" : "Неисправан ИД Здруженог облака",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Позадина дељења %s мора користити корисничко окружење OCP\\Share_Backend",
     "Sharing backend %s not found" : "Позадина за дељење %s није пронађена",
     "Sharing backend for %s not found" : "Позадина за дељење за %s није пронађена",
@@ -115,11 +114,9 @@ OC.L10N.register(
     "Open »%s«" : "Отвори „%s“",
     "%1$s via %2$s" : "%1$s преко %2$s",
     "You are not allowed to share %s" : "Није вам дозвољено да делите %s",
-    "Can’t increase permissions of %s" : "Не могу да повећам дозволе за %s",
-    "Files can’t be shared with delete permissions" : "Фајлови не могу бити дељени са дозволама за брисање",
-    "Files can’t be shared with create permissions" : "Фајлови не могу бити дељени са дозволама за креирање",
+    "Cannot increase permissions of %s" : "Не могу да повећам привилегије за %s",
     "Expiration date is in the past" : "Датум истека је у прошлости",
-    "Can’t set expiration date more than %s days in the future" : "Не могу да поставим датум истека више од %s дана у будућност",
+    "Sharing %s failed, because this item is already shared with user %s" : "Дељење %s није успело зато што се ова ставка већ дели са корисником %s",
     "%1$s shared »%2$s« with you" : "%1$s је поделио „%2$s“ са Вама",
     "%1$s shared »%2$s« with you." : "%1$s је поделио „%2$s“ са Вама.",
     "Click the button below to open it." : "Кликните дугме испод да га отворите.",
@@ -183,38 +180,22 @@ OC.L10N.register(
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Апликација „%1$s“ не може бити инсталирана јер следеће зависности нису испуњене: %2$s",
     "a safe home for all your data" : "сигурно место за све Ваше податке",
     "File is currently busy, please try again later" : "Фајл је тренутно заузет, покушајте поново касније",
-    "Can't read file" : "Не могу да читам фајл",
     "Application is not enabled" : "Апликација није укључена",
     "Authentication error" : "Грешка при провери идентитета",
     "Token expired. Please reload page." : "Жетон је истекао. Поново учитајте страницу.",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "Нема драјвера базе података (скулајт, мајскул или постгрескул).",
-    "Cannot write into \"config\" directory" : "Не могу уписивати у директоријуму „config“",
-    "Cannot write into \"apps\" directory" : "Не могу уписивати у директоријуму „apps“",
-    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the appstore in the config file. See %s" : "Ово се обично може поправити тако што веб серверу дате приступ уписа за директоријум где су апликације или тако што онемогућите продавницу у config фајлу. Видети %s",
-    "Cannot create \"data\" directory" : "Не могу да направим \"data\" директоријум",
-    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "Ово се обично може поправити тако што веб серверу дате право уписа за корени директоријуму. Видети %s",
-    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "Привилегије се обично могу поправити тако што веб серверу дате право уписа за корени директоријуму. Видети %s",
-    "Setting locale to %s failed" : "Постављање локалитета на %s није успело",
-    "Please install one of these locales on your system and restart your webserver." : "Инсталирајте неки од ових локалитета на ваш систем и поново покрените веб сервер.",
-    "Please ask your server administrator to install the module." : "Замолите администратора вашег сервера да инсталира тај модул.",
+    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Или, ако пре желите да задржите config.php да је само за читање, поставите опцију \"config_is_read_only\" на true у њему самом. Погледајте %s",
     "PHP module %s not installed." : "PHP модул %s није инсталиран.",
+    "Please ask your server administrator to install the module." : "Замолите администратора вашег сервера да инсталира тај модул.",
     "PHP setting \"%s\" is not set to \"%s\"." : "PHP поставка „%s“ није постављена на „%s“.",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "Некстклауд ће прорадити поново када прилагодите ово подашавање у php.ini фајлу",
-    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload је постављено на „%s“ уместо на очекивану вредност „0“",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Да би решили овај проблем поставите <code>mbstring.func_overload</code> на <code>0</code> у фајлу php.ini",
     "libxml2 2.7.0 is at least required. Currently %s is installed." : "Потребан је бар libxml2 2.7.0. Тренутно је инсталиран %s.",
     "To fix this issue update your libxml2 version and restart your web server." : "Да поправите овај проблем, ажурирајте верзију библиотеке libxml2 и рестартујте веб сервер.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP је очигледно подешен да склања уметнуте doc блокове. То ће учинити неколико кључних апликација недоступним.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Ово је вероватно изазвано кешом или акцелератором као што су ЗендОПкеш или еАкцелератор.",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP модули су инсталирани али се и даље воде као недостајући?",
     "Please ask your server administrator to restart the web server." : "Замолите вашег администратора сервера да поново покрене веб сервер.",
-    "PostgreSQL >= 9 required" : "Захтеван је ПостгреСкул >= 9",
-    "Please upgrade your database version" : "Надоградите ваше издање базе",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Промените дозволе у 0770 како директоријуми не би могли бити излистани од стране других корисника.",
-    "Your data directory is readable by other users" : "Директоријум са подацима је читљив од стране других корисника система",
-    "Your data directory must be an absolute path" : "Директоријум са подацима мора бити апсолутна путања",
-    "Check the value of \"datadirectory\" in your configuration" : "Проверите податак за \"datadirectory\" у вашој конфигурацији",
-    "Your data directory is invalid" : "Директоријум са подацима није исправан",
     "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Уверите се да фајл \".ocdata\" постоји у корену директоријума са подацима.",
     "Action \"%s\" not supported or implemented." : "Радња \"%s\" није подржана или имплементирана.",
     "Authentication failed, wrong token or provider ID given" : "Неуспела провера идентитета, добијен погрешан токен или ID провајдера",
@@ -226,35 +207,27 @@ OC.L10N.register(
     "Storage incomplete configuration. %s" : "Непотпуна конфигурација складишта. %s",
     "Storage connection error. %s" : "Грешка приликом повезивања на складиште. %s",
     "Storage is temporarily not available" : "Складиште привремено није  доступно",
-    "Storage connection timeout. %s" : "Прекорачено време за повезивање на складиште. %s",
-    "Create" : "Направи",
-    "Change" : "Измени",
-    "Delete" : "Обриши",
-    "Share" : "Подели",
-    "Unlimited" : "Неограничено",
-    "Verifying" : "Проверавам",
-    "Verifying …" : "Проверавам ...",
-    "Verify" : "Провери",
-    "Sharing %s failed, because the backend does not allow shares from type %i" : "Дељење %s није успело зато што позадина не дозвољава дељење од типа %i",
-    "Sharing %s failed, because the file does not exist" : "Дељење %s није успело зато што фајл не постоји",
-    "Sharing %s failed, because you can not share with yourself" : "Дељење %s није успело зато што не можете да делите са самим собом",
-    "Sharing %1$s failed, because the user %2$s does not exist" : "Дељење %1$s није успело зато што не постоји корисник %2$s",
-    "Sharing %1$s failed, because the user %2$s is not a member of any groups that %3$s is a member of" : "Дељење %1$s није успело зато што корисник %2$s није члан ниједне групе чији је %3$s члан",
-    "Sharing %1$s failed, because this item is already shared with %2$s" : "Дељење %1$s није успело зато што се ова ставка већ дели са %2$s",
-    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Дељење %1$s није успело зато што се ова ставка већ дели са корисником %2$s",
-    "Sharing %1$s failed, because the group %2$s does not exist" : "Дељење %1$s није успело зато што не постоји група %2$s",
-    "Sharing %1$s failed, because %2$s is not a member of the group %3$s" : "Дељење %1$s није успело зато што %2$s није члан групе %3$s",
-    "You need to provide a password to create a public link, only protected links are allowed" : "Морате да обезбедите лозинку за креирање јавне везе, дозвољене су само заштићене везе",
-    "Sharing %s failed, because sharing with links is not allowed" : "Дељење %s није успело зато што дељење са везама није дозвољено",
-    "Not allowed to create a federated share with the same user" : "Није дозвољено да направите здружено дељење са истим корисником",
-    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable." : "Дељење %1$s није успело, није могуће пронаћи %2$s, можда сервер тренутно није доступан.",
-    "Share type %1$s is not valid for %2$s" : "Тип фајла за дељење %1$s није исправан за %2$s",
-    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Не могу поставити датум трајања. Дељења не могу истицати касније од %s пошто су активирана",
-    "Cannot set expiration date. Expiration date is in the past" : "Не могу поставити датум трајања. Датум трајања употребе је у прошлости",
-    "Sharing failed, because the user %s is the original sharer" : "Дељење није успело, зато што је корисник %s већ оригинални делилац",
-    "Sharing %1$s failed, because the permissions exceed permissions granted to %2$s" : "Дељење %1$s није успело зато што дозволе превазилазе дозволе гарантоване за %2$s",
-    "Sharing %s failed, because resharing is not allowed" : "Дељење %s није успело зато што даље дељење није дозвољено",
-    "Sharing %1$s failed, because the sharing backend for %2$s could not find its source" : "Дељење %1$s није успело зато што позадина дељења за %2$s није могла да нађе извор",
-    "Sharing %s failed, because the file could not be found in the file cache" : "Дељење %s није успело зато што фајл није нађен у кешу фајлова"
+    "Storage connection timeout. %s" : "Истекло је време за повезивање на складиште. %s",
+    "This can usually be fixed by giving the webserver write access to the config directory." : "Ово се обично може средити давањем права веб серверу да пише у директоријум са подешавањима.",
+    "%s enter the database username and name." : "%s унеси корисничко име базе података и име.",
+    "%s enter the database username." : "%s унеси корисничко име базе података.",
+    "%s enter the database name." : "%s унеси име базе података.",
+    "%s you may not use dots in the database name" : "%s не можете користити тачке у имену базе података",
+    "Cannot write into \"config\" directory" : "Не могу уписивати у директоријуму „config“",
+    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Ово се обично може средити давањем права писања веб серверу за директоријум са подешавањима. Погледајте %s",
+    "Cannot write into \"apps\" directory" : "Не могу уписивати у директоријуму „apps“",
+    "Cannot create \"data\" directory" : "Не могу да направим \"data\" директоријум",
+    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "Ово се обично може поправити тако што веб серверу дате право уписа за корени директоријуму. Видети %s",
+    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "Привилегије се обично могу поправити тако што веб серверу дате право уписа за корени директоријуму. Видети %s",
+    "Setting locale to %s failed" : "Постављање локалитета на %s није успело",
+    "Please install one of these locales on your system and restart your webserver." : "Инсталирајте неки од ових локалитета на ваш систем и поново покрените веб сервер.",
+    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload је постављено на „%s“ уместо на очекивану вредност „0“",
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Да би решили овај проблем поставите <code>mbstring.func_overload</code> на <code>0</code> у фајлу php.ini",
+    "PostgreSQL >= 9 required" : "Захтеван је ПостгреСкул >= 9",
+    "Please upgrade your database version" : "Надоградите ваше издање базе",
+    "Your data directory is readable by other users" : "Директоријум са подацима је читљив од стране других корисника система",
+    "Your data directory must be an absolute path" : "Директоријум са подацима мора бити апсолутна путања",
+    "Check the value of \"datadirectory\" in your configuration" : "Проверите податак за \"datadirectory\" у вашој конфигурацији",
+    "Your data directory is invalid" : "Директоријум са подацима није исправан"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
